@@ -25,14 +25,8 @@ use Centreon\PhpCsFixer\PhpCsFixerRuleSet;
 use PhpCsFixer\{Config, Finder};
 
 $finder = Finder::create()
-    // add directories
     ->in([
         __DIR__ . '/src/Core',
-        __DIR__ . '/src/Adaptation',
-    ])
-    // add files
-    ->append([
-        __DIR__ . '/src/Centreon/Infrastructure/DatabaseConnection.php',
     ]);
 
 /**
