@@ -13,10 +13,11 @@ const {
 const getBaseConfiguration = ({
   moduleName,
   moduleFederationConfig,
-  jscTransformConfiguration
+  jscTransformConfiguration,
+  enableCoverage
 }) => ({
   cache,
-  module: getModuleConfiguration(jscTransformConfiguration),
+  module: getModuleConfiguration(jscTransformConfiguration, enableCoverage),
   optimization,
   output: {
     ...output,
@@ -33,19 +34,18 @@ const getBaseConfiguration = ({
         shared: [
           {
             '@centreon/ui-context': {
-              requiredVersion: '22.10.0',
+              requiredVersion: '24.x',
               singleton: true
             }
           },
           {
             jotai: {
-              requiredVersion: '1.x',
+              requiredVersion: '2.x',
               singleton: true
             }
           },
           {
             'jotai-suspense': {
-              requiredVersion: '0.1.x',
               singleton: true
             }
           },
@@ -63,7 +63,7 @@ const getBaseConfiguration = ({
           },
           {
             'react-i18next': {
-              requiredVersion: '11.x',
+              requiredVersion: '14.x',
               singleton: true
             }
           },
