@@ -2,7 +2,10 @@ import { User, ThemeMode, ListingVariant } from './types';
 
 const defaultUser: User = {
   alias: '',
+  canManageApiTokens: false,
   default_page: '/monitoring/resources',
+  id: undefined,
+  isAdmin: undefined,
   isExportButtonEnabled: false,
   locale: navigator.language,
   name: '',
