@@ -2,10 +2,13 @@ export { default as userAtom } from './userAtom';
 export { default as aclAtom } from './aclAtom';
 export { default as downtimeAtom } from './downtimeAtom';
 export { default as refreshIntervalAtom } from './refreshIntervalAtom';
+export { default as statisticsRefreshIntervalAtom } from './statisticsRefreshIntervalAtom';
 export { default as cloudServicesAtom } from './cloudServicesAtom';
 export { default as acknowledgementAtom } from './acknowledgementAtom';
 export { default as resourceStorageOptimizationModeAtom } from './resourceStorageOptimizationMode';
 export { default as platformNameAtom } from './platformNameAtom';
+export { default as userPermissionsAtom } from './userPermissionsAtom';
+
 export { ThemeMode, ListingVariant, DashboardGlobalRole } from './types';
 export {
   platformFeaturesAtom,
@@ -23,5 +26,6 @@ export type {
   Acl,
   DashboardRolesAndPermissions,
   FeatureFlags,
-  PlatformFeatures
+  PlatformFeatures,
+  UserPermissions
 } from './types';
