@@ -20,8 +20,11 @@ export interface DashboardRolesAndPermissions {
 
 export interface User {
   alias: string;
+  canManageApiTokens: boolean;
   dashboard?: DashboardRolesAndPermissions | null;
   default_page?: string | null;
+  id?: number;
+  isAdmin?: boolean;
   isExportButtonEnabled: boolean;
   locale: string;
   name: string;
@@ -84,6 +87,7 @@ export interface Downtime {
 export interface FeatureFlags {
   adExclusionPeriods?: boolean;
   dashboard?: boolean;
+  dashboardPlayList?: boolean;
   notification?: boolean;
   resourceStatusFilterRevamp?: boolean;
   resourceStatusTreeView?: boolean;
@@ -94,3 +98,14 @@ export interface PlatformFeatures {
   featureFlags: FeatureFlags;
   isCloudPlatform: boolean;
 }
+
+export interface PlatformVersions {
+  modules: Record<string, Version>;
+  web: Version;
+  widgets: Record<string, Version | null>;
+}
+
+export interface UserPermissions {
+  poller_statistics: boolean;
+  top_counter: boolean;
+}
