@@ -9,13 +9,14 @@ import {
   errorTimePeriodAtom,
   adjustTimePeriodDerivedAtom
 } from './timePeriodsAtoms';
-import { WrapperTimePeriodProps } from './models';
+
+import { Props } from '.';
 
 const useTimePeriod = ({
   getParameters,
   getIsError,
   adjustTimePeriodData
-}: Omit<WrapperTimePeriodProps, 'extraTimePeriods' | 'disabled'>): void => {
+}: Omit<Props, 'extraTimePeriods' | 'disabled'>): void => {
   const selectedTimePeriod = useAtomValue(selectedTimePeriodAtom);
   const customTimePeriod = useAtomValue(customTimePeriodAtom);
   const getCurrentEndStartInterval = useAtomValue(getDatesDerivedAtom);
