@@ -8,21 +8,21 @@ const useStepIconStyles = makeStyles()((theme) => ({
   avatar: {
     fontSize: theme.typography.body2.fontSize,
     height: 20,
-    width: 20,
+    width: 20
   },
   avatarActive: {
-    backgroundColor: theme.palette.primary.main,
+    backgroundColor: theme.palette.primary.main
   },
   avatarCompleted: {
-    backgroundColor: theme.palette.primary.main,
+    backgroundColor: theme.palette.primary.main
   },
   completed: {
     fontSize: theme.typography.body2.fontSize,
-    zIndex: 1,
+    zIndex: 1
   },
   root: {
-    height: 22,
-  },
+    height: 22
+  }
 }));
 
 const StepIcon = ({ active, completed, icon }: StepIconProps): JSX.Element => {
