@@ -25,19 +25,19 @@ namespace Centreon\Infrastructure\Monitoring;
 use Centreon\Domain\Acknowledgement\Acknowledgement;
 use Centreon\Domain\Contact\Interfaces\ContactInterface;
 use Centreon\Domain\Downtime\Downtime;
-use Centreon\Domain\Monitoring\HostGroup;
-use Centreon\Domain\Monitoring\ServiceGroup;
-use Centreon\Domain\RequestParameters\RequestParameters;
-use Centreon\Infrastructure\Repository\AbstractRepositoryDRB;
-use Core\Security\AccessGroup\Domain\Model\AccessGroup;
 use Centreon\Domain\Entity\EntityCreator;
 use Centreon\Domain\Monitoring\Host;
-use Centreon\Domain\Monitoring\Service;
-use Centreon\Domain\Monitoring\ResourceStatus;
+use Centreon\Domain\Monitoring\HostGroup;
 use Centreon\Domain\Monitoring\Interfaces\MonitoringRepositoryInterface;
+use Centreon\Domain\Monitoring\ResourceStatus;
+use Centreon\Domain\Monitoring\Service;
+use Centreon\Domain\Monitoring\ServiceGroup;
+use Centreon\Domain\RequestParameters\RequestParameters;
 use Centreon\Infrastructure\CentreonLegacyDB\StatementCollector;
 use Centreon\Infrastructure\DatabaseConnection;
+use Centreon\Infrastructure\Repository\AbstractRepositoryDRB;
 use Centreon\Infrastructure\RequestParameters\SqlRequestParametersTranslator;
+use Core\Security\AccessGroup\Domain\Model\AccessGroup;
 
 /**
  * Database repository for the real time monitoring of services and host.
@@ -137,112 +137,115 @@ final class MonitoringRepositoryRDB extends AbstractRepositoryDRB implements Mon
                 AND acl.group_id IN (' . implode(',', $accessGroupIds) . ') ';
         }
 
-        $request =
-            'SELECT SQL_CALC_FOUND_ROWS DISTINCT
-              1 AS REALTIME,
-              h.host_id,
-              h.name,
-              h.instance_id, 
-              h.acknowledged,
-              h.acknowledgement_type,
-              h.action_url,
-              h.active_checks,  
-              h.address,   
-              h.alias,    
-              h.check_attempt, 
-              h.check_command,  
-              h.check_freshness, 
-              h.check_interval,  
-              h.check_period,    
-              h.check_type,     
-              h.checked,       
-              h.command_line,  
-              h.default_active_checks,  
-              h.default_event_handler_enabled,
-              h.default_failure_prediction, 
-              h.default_flap_detection,    
-              h.default_notify,          
-              h.default_passive_checks,   
-              h.default_process_perfdata,  
-              h.display_name,          
-              h.enabled,               
-              h.event_handler,          
-              h.event_handler_enabled,   
-              h.execution_time,         
-              h.failure_prediction,     
-              h.first_notification_delay,  
-              h.flap_detection,          
-              h.flap_detection_on_down,  
-              h.flap_detection_on_unreachable, 
-              h.flap_detection_on_up,    
-              h.flapping,              
-              h.freshness_threshold,  
-              h.high_flap_threshold, 
-              h.icon_image,          
-              h.icon_image_alt,      
-              h.last_check,         
-              h.last_hard_state,     
-              h.last_hard_state_change, 
-              h.last_notification,      
-              h.last_state_change,     
-              h.last_time_down,         
-              h.last_time_unreachable,    
-              h.last_time_up,           
-              h.last_update,           
-              h.latency,               
-              h.low_flap_threshold,     
-              h.max_check_attempts,     
-              h.modified_attributes,     
-              h.next_check,             
-              h.next_host_notification,   
-              h.no_more_notifications,   
-              h.notes,                    
-              h.notes_url,               
-              h.notification_interval,   
-              h.notification_number,     
-              h.notification_period,     
-              h.notify,                 
-              h.notify_on_down,         
-              h.notify_on_downtime,       
-              h.notify_on_flapping,      
-              h.notify_on_recovery,      
-              h.notify_on_unreachable,    
-              h.obsess_over_host,        
-              h.output,                  
-              h.passive_checks,          
-              h.percent_state_change,     
-              h.perfdata,                
-              h.process_perfdata,         
-              h.retain_nonstatus_information, 
-              h.retain_status_information, 
-              h.retry_interval,             
-              h.scheduled_downtime_depth,   
-              h.should_be_scheduled,       
-              h.stalk_on_down,            
-              h.stalk_on_unreachable,     
-              h.stalk_on_up,             
-              h.state,                   
-              h.state_type,             
-              h.statusmap_image,         
-              h.timezone,               
-              h.real_state,
-              cv.value AS criticality,
-              i.name AS poller_name,
-              IF (h.display_name LIKE \'_Module_Meta%\', \'Meta\', h.display_name) AS display_name,
-              IF (h.display_name LIKE \'_Module_Meta%\', \'0\', h.state) AS state
+        $request = <<<SQL
+            SELECT SQL_CALC_FOUND_ROWS DISTINCT
+                1 AS REALTIME,
+                h.host_id,
+                h.name,
+                h.instance_id, 
+                h.acknowledged,
+                h.acknowledgement_type,
+                h.action_url,
+                h.active_checks,  
+                h.address,   
+                h.alias,    
+                h.check_attempt, 
+                h.check_command,  
+                h.check_freshness, 
+                h.check_interval,  
+                h.check_period,    
+                h.check_type,     
+                h.checked,       
+                h.command_line,  
+                h.default_active_checks,  
+                h.default_event_handler_enabled,
+                h.default_failure_prediction, 
+                h.default_flap_detection,    
+                h.default_notify,          
+                h.default_passive_checks,   
+                h.default_process_perfdata,  
+                h.display_name,          
+                h.enabled,               
+                h.event_handler,          
+                h.event_handler_enabled,   
+                h.execution_time,         
+                h.failure_prediction,     
+                h.first_notification_delay,  
+                h.flap_detection,          
+                h.flap_detection_on_down,  
+                h.flap_detection_on_unreachable, 
+                h.flap_detection_on_up,    
+                h.flapping,              
+                h.freshness_threshold,  
+                h.high_flap_threshold, 
+                h.icon_image,          
+                h.icon_image_alt,      
+                h.last_check,         
+                h.last_hard_state,     
+                h.last_hard_state_change, 
+                h.last_notification,      
+                h.last_state_change,     
+                h.last_time_down,         
+                h.last_time_unreachable,    
+                h.last_time_up,           
+                h.last_update,           
+                h.latency,               
+                h.low_flap_threshold,     
+                h.max_check_attempts,     
+                h.modified_attributes,     
+                h.next_check,             
+                h.next_host_notification,   
+                h.no_more_notifications,   
+                h.notes,                    
+                h.notes_url,               
+                h.notification_interval,   
+                h.notification_number,     
+                h.notification_period,     
+                h.notify,                 
+                h.notify_on_down,         
+                h.notify_on_downtime,       
+                h.notify_on_flapping,      
+                h.notify_on_recovery,      
+                h.notify_on_unreachable,    
+                h.obsess_over_host,        
+                h.output,                  
+                h.passive_checks,          
+                h.percent_state_change,     
+                h.perfdata,                
+                h.process_perfdata,         
+                h.retain_nonstatus_information, 
+                h.retain_status_information, 
+                h.retry_interval,             
+                h.scheduled_downtime_depth,   
+                h.should_be_scheduled,       
+                h.stalk_on_down,            
+                h.stalk_on_unreachable,     
+                h.stalk_on_up,             
+                h.state,                   
+                h.state_type,             
+                h.statusmap_image,         
+                h.timezone,               
+                h.real_state,
+                cv.value AS criticality,
+                i.name AS poller_name,
+                IF (h.display_name LIKE '_Module_Meta%', 'Meta', h.display_name) AS display_name,
+                IF (h.display_name LIKE '_Module_Meta%', '0', h.state) AS state
             FROM `:dbstg`.`instances` i
             INNER JOIN `:dbstg`.`hosts` h
-              ON h.instance_id = i.instance_id
-              AND h.enabled = \'1\'
-              AND h.name NOT LIKE \'_Module_BAM%\''
-            . $accessGroupFilter
-            . ' LEFT JOIN `:dbstg`.`services` srv
-              ON srv.host_id = h.host_id
-              AND srv.enabled = \'1\'
+                ON h.instance_id = i.instance_id
+                AND h.enabled = '1'
+                AND h.name NOT LIKE '_Module_BAM%'
+            {$accessGroupFilter}
+            LEFT JOIN `:dbstg`.`services` srv
+                ON srv.host_id = h.host_id
+                AND srv.enabled = '1'
             LEFT JOIN `:dbstg`.`hosts_hostgroups` hg
-              ON hg.host_id = h.host_id
+                ON hg.host_id = h.host_id
             LEFT JOIN `:dbstg`.`customvariables` cv
-            ON (cv.host_id = h.host_id AND cv.service_id IS NULL AND cv.name = \'CRITICALITY_LEVEL\')';
+                ON cv.host_id = h.host_id
+                AND (cv.service_id = 0 OR cv.service_id IS NULL)
+                AND cv.name = 'CRITICALITY_LEVEL'
+            SQL;
 
         $request = $this->translateDbName($request);
 
@@ -434,6 +437,11 @@ final class MonitoringRepositoryRDB extends AbstractRepositoryDRB implements Mon
             'name' => 'hg.name'
         ];
 
+        $hostCategoryConcordanceArray = [
+            'host_category.id' => 'host_categories.id',
+            'host_category.name' => 'host_categories.name'
+        ];
+
         // To allow to find host groups relating to host information
         $hostConcordanceArray = [
             'host.id' => 'h.host_id',
@@ -464,6 +472,12 @@ final class MonitoringRepositoryRDB extends AbstractRepositoryDRB implements Mon
             $hostGroupConcordanceArray = array_merge($hostGroupConcordanceArray, $serviceConcordanceArray);
         }
 
+        $shouldJoinHostCategory = false;
+        if (count(array_intersect($searchParameters, array_keys($hostCategoryConcordanceArray))) > 0) {
+            $shouldJoinHostCategory = true;
+            $hostGroupConcordanceArray = array_merge($hostGroupConcordanceArray, $hostCategoryConcordanceArray);
+        }
+
         //if the filter is for specific host id, remove it from search parameters
         if (null !== $hostId) {
             $shouldJoinHost = true;
@@ -501,9 +515,9 @@ final class MonitoringRepositoryRDB extends AbstractRepositoryDRB implements Mon
         }
 
         // This join will only be added if a search parameter corresponding to one of the host or Service parameter
-        if ($shouldJoinHost || $shouldJoinService) {
+        if ($shouldJoinHost || $shouldJoinService || $shouldJoinHostCategory) {
             $subRequest .=
-                ' INNER JOIN `:dbstg`.hosts_hostgroups hhg 
+                ' INNER JOIN `:dbstg`.hosts_hostgroups hhg
                     ON hhg.hostgroup_id = hg.hostgroup_id
                 INNER JOIN `:dbstg`.hosts h
                     ON h.host_id = hhg.host_id
@@ -517,6 +531,19 @@ final class MonitoringRepositoryRDB extends AbstractRepositoryDRB implements Mon
                         AND srv.enabled = \'1\'';
             }
 
+            if ($shouldJoinHostCategory) {
+                // tags table because everything is resolved (templates and so on...)
+                $subRequest .=
+                    ' INNER JOIN `:dbstg`.resources
+                        ON resources.id = h.host_id
+                    INNER JOIN `:dbstg`.resources_tags
+                        ON resources_tags.resource_id = resources.resource_id
+                    INNER JOIN `:dbstg`.tags host_categories
+                        ON host_categories.tag_id = resources_tags.tag_id
+                        AND host_categories.`type` = 3';
+
+            }
+
             if (!$this->isAdmin()) {
                 $subRequest .=
                     ' INNER JOIN `:dbstg`.`centreon_acl` acl
@@ -528,6 +555,7 @@ final class MonitoringRepositoryRDB extends AbstractRepositoryDRB implements Mon
 
         $request = 'SELECT SQL_CALC_FOUND_ROWS DISTINCT 1 AS REALTIME, hg.* FROM `:dbstg`.`hostgroups` hg ' .
             $subRequest;
+
         $request = $this->translateDbName($request);
 
         // Search
@@ -991,7 +1019,7 @@ final class MonitoringRepositoryRDB extends AbstractRepositoryDRB implements Mon
             . ' WHERE srv.enabled = \'1\'
               AND h.enabled = \'1\'
               AND srv.description = :service_description
-            GROUP BY srv.service_id, h.host_id';
+            GROUP BY srv.service_id';
 
         $request = $this->translateDbName($request);
 
@@ -1450,8 +1478,20 @@ final class MonitoringRepositoryRDB extends AbstractRepositoryDRB implements Mon
             'poller.id' => 'h.instance_id'
         ];
 
+        $hostGroupConcordanceArray = [
+            'host_group.id' => 'host_groups.id',
+            'host_group.name' => 'host_groups.name'
+        ];
+
+        $hostCategoryConcordanceArray = [
+            'host_category.id' => 'host_categories.id',
+            'host_category.name' => 'host_categories.name'
+        ];
+
         // To allow to find service groups relating to Service information
         $serviceConcordanceArray = [
+            'service.id' => 'srv.service_id',
+            'service.name' => 'srv.description',
             'service.display_name' => 'srv.display_name',
         ];
 
@@ -1469,6 +1509,18 @@ final class MonitoringRepositoryRDB extends AbstractRepositoryDRB implements Mon
             $serviceGroupConcordanceArray = array_merge($serviceGroupConcordanceArray, $serviceConcordanceArray);
         }
 
+        $shouldJoinHostGroup = false;
+        if (count(array_intersect($searchParameters, array_keys($hostGroupConcordanceArray))) > 0) {
+            $shouldJoinHostGroup = true;
+            $serviceGroupConcordanceArray = array_merge($serviceGroupConcordanceArray, $hostGroupConcordanceArray);
+        }
+
+        $shouldJoinHostCategory = false;
+        if (count(array_intersect($searchParameters, array_keys($hostCategoryConcordanceArray))) > 0) {
+            $shouldJoinHostCategory = true;
+            $serviceGroupConcordanceArray = array_merge($serviceGroupConcordanceArray, $hostCategoryConcordanceArray);
+        }
+
         $this->sqlRequestTranslator->setConcordanceArray($serviceGroupConcordanceArray);
 
         $sqlExtraParameters = [];
@@ -1501,11 +1553,22 @@ final class MonitoringRepositoryRDB extends AbstractRepositoryDRB implements Mon
         }
 
         // This join will only be added if a search parameter corresponding to one of the host or Service parameter
-        if ($shouldJoinHost || $shouldJoinService) {
+        /**
+         * 0 = service groups,
+         * 1 = host groups,
+         * 2 = service categories.
+         * 3 = host categories.
+         */
+        if (
+            $shouldJoinHost
+            || $shouldJoinService
+            || $shouldJoinHostGroup
+            || $shouldJoinHostCategory
+        ) {
             $subRequest .=
-                ' INNER JOIN `:dbstg`.services_servicegroups ssg 
+                ' INNER JOIN `:dbstg`.services_servicegroups ssg
                     ON ssg.servicegroup_id = sg.servicegroup_id
-                    INNER JOIN `:dbstg`.hosts h
+                INNER JOIN `:dbstg`.hosts h
                     ON h.host_id = ssg.host_id
                     AND h.enabled = \'1\'
                     AND h.name NOT LIKE \'\_Module\_%\'
@@ -1520,7 +1583,25 @@ final class MonitoringRepositoryRDB extends AbstractRepositoryDRB implements Mon
                     AND srv.enabled = \'1\'';
             }
 
-            if (!$this->isAdmin()) {
+            if ($shouldJoinHostGroup) {
+                $subRequest .=
+                    ' INNER JOIN `:dbstg`.resources_tags AS rtags_host_groups
+                        ON rtags_host_groups.resource_id = resources.resource_id
+                    INNER JOIN `:dbstg`.tags host_groups
+                        ON host_groups.tag_id = rtags_host_groups.tag_id
+                        AND host_groups.`type` = 1';
+            }
+
+            if ($shouldJoinHostCategory) {
+                $subRequest .=
+                    ' INNER JOIN `:dbstg`.resources_tags AS rtags_host_categories
+                        ON rtags_host_categories.resource_id = resources.resource_id
+                    INNER JOIN `:dbstg`.tags host_categories
+                        ON host_categories.tag_id = rtags_host_categories.tag_id
+                        AND host_categories.`type` = 3';
+            }
+
+            if (! $this->isAdmin()) {
                 $subRequest .=
                     ' INNER JOIN `:dbstg`.`centreon_acl` acl
                         ON acl.host_id = h.host_id
@@ -1735,9 +1816,9 @@ final class MonitoringRepositoryRDB extends AbstractRepositoryDRB implements Mon
             'SELECT DISTINCT
                 1 AS REALTIME,
 		        ssg.servicegroup_id,
-                srv.service_id, 
-                srv.display_name, 
-                srv.description, 
+                srv.service_id,
+                srv.display_name,
+                srv.description,
                 srv.host_id,
                 srv.state
             FROM `:dbstg`.`services` srv
@@ -1812,12 +1893,12 @@ final class MonitoringRepositoryRDB extends AbstractRepositoryDRB implements Mon
                     ON gcgr.acl_group_id = grp.acl_group_id
                 LEFT JOIN `:db`.contactgroup_contact_relation cgcr
                     ON cgcr.contactgroup_cg_id = gcgr.cg_cg_id
-                    AND cgcr.contact_contact_id = :contact_id 
+                    AND cgcr.contact_contact_id = :contact_id
                     OR gcr.contact_contact_id = :contact_id';
         }
 
         $subRequest .=
-            ' INNER JOIN `:dbstg`.services_servicegroups ssg 
+            ' INNER JOIN `:dbstg`.services_servicegroups ssg
                     ON ssg.servicegroup_id = sg.servicegroup_id
                 INNER JOIN `:dbstg`.hosts h
                     ON h.host_id = ssg.host_id';
@@ -1839,7 +1920,7 @@ final class MonitoringRepositoryRDB extends AbstractRepositoryDRB implements Mon
         $subRequest .= ' WHERE srv.service_id = :serviceId AND srv.host_id = :hostId';
 
         $request =
-            'SELECT SQL_CALC_FOUND_ROWS DISTINCT 1 AS REALTIME, sg.* 
+            'SELECT SQL_CALC_FOUND_ROWS DISTINCT 1 AS REALTIME, sg.*
             FROM `:dbstg`.`servicegroups` sg ' . $subRequest;
         $request = $this->translateDbName($request);
 
