@@ -296,18 +296,9 @@ class SqlRequestParametersTranslator
                 if ($mixedValue === '') {
                     $mixedValue = '.*';
                 }
-                try {
-                    $mixedValue = str_replace('/', '\/', $mixedValue);
-                    preg_match('/' . $mixedValue . '/', '');
-                    if (preg_last_error() !== PREG_NO_ERROR) {
-                        throw new RequestParametersTranslatorException('Bad regex format \'' . $mixedValue . '\'', 0);
-                    }
-                } catch (\ErrorException $exception) {
-                    throw new RequestParametersTranslatorException(
-                        message: 'Error while preg_match() the value : \'' . $mixedValue . '\'',
-                        code: 0,
-                        previous: $exception
-                    );
+                preg_match('/' . $mixedValue . '/', '');
+                if (preg_last_error() !== PREG_NO_ERROR) {
+                    throw new RequestParametersTranslatorException('Bad regex format \'' . $mixedValue . '\'', 0);
                 }
             }
             $bindKey = ':value_' . (count($this->searchValues) + 1);
@@ -469,6 +460,14 @@ class SqlRequestParametersTranslator
         return $nbRows;
     }
 
+    /**
+     * @param int $numberOfRows
+     */
+    public function setNumberOfRows(int $numberOfRows): void
+    {
+        $this->requestParameters->setTotal($numberOfRows);
+    }
+
     /**
      * Add a normalizer for a property name to be declared in the search parameters.
      * <code>
