@@ -19,12 +19,17 @@
  *
  */
 
+declare(strict_types=1);
+
 namespace CentreonLegacy\Core\Module;
 
+use Symfony\Component\Filesystem\Exception\IOException;
+use Symfony\Component\Finder\Finder;
+
 class Upgrader extends Module
 {
     /**
-     * @return bool
+     * @return int
      */
     public function upgrade()
     {
@@ -35,7 +40,12 @@ class Upgrader extends Module
         // Process all directories within the /upgrade/ path.
         // Entry name should be a version.
         $upgradesPath = $this->getModulePath($this->moduleName) . '/upgrade/';
-        $upgrades = $this->services->get('finder')->directories()->depth('== 0')->in($upgradesPath);
+        /** @var Finder $upgrades */
+        $upgrades = $this->services->get('finder');
+        $upgrades
+            ->directories()
+            ->depth('== 0')
+            ->in($upgradesPath);
         $orderedUpgrades = [];
         foreach ($upgrades as $upgrade) {
             $orderedUpgrades[] = $upgrade->getBasename();
@@ -59,12 +69,35 @@ class Upgrader extends Module
             $this->upgradePhpFiles($upgradePath, false);
         }
 
+        // make sure that if necessary route files are correctly generated.
+        $this->generateRoutes();
+
         // finally, upgrade to current version
         $this->upgradeVersion($this->moduleConfiguration['mod_release']);
 
         return $this->moduleId;
     }
 
+    /**
+     * This method intends to generate routes from available route files eg copy the
+     * RouteFile.wait.yaml to the final RouteFile.yaml.
+     *
+     * @throws \Exception
+     * @throws IOException
+     */
+    private function generateRoutes(): void
+    {
+        $generateRoutesFile = $this->getModulePath($this->moduleName) . '/php/generate_routes.php';
+
+        // routes should be generated only if generate_routes.php is available and routes directory exists
+        if (
+            $this->services->get('filesystem')->exists($generateRoutesFile)
+            && $this->services->get('filesystem')->exists($this->getModulePath($this->moduleName) . '/routes/')
+        ) {
+            $this->utils->executePhpFile($generateRoutesFile);
+        }
+    }
+
     /**
      * Upgrade module information except version.
      *
