@@ -28,7 +28,6 @@ use Centreon\Domain\Contact\Interfaces\ContactInterface;
 use Centreon\Domain\Log\LoggerTrait;
 use Core\Application\Common\UseCase\ErrorResponse;
 use Core\Application\Common\UseCase\ForbiddenResponse;
-use Core\Common\Domain\Exception\RepositoryException;
 use Core\Contact\Application\Exception\ContactTemplateException;
 use Core\Contact\Application\Repository\ReadContactTemplateRepositoryInterface;
 
@@ -43,7 +42,8 @@ class FindContactTemplates
     public function __construct(
         readonly private ReadContactTemplateRepositoryInterface $repository,
         readonly private ContactInterface $user,
-    ) {}
+    ) {
+    }
 
     /**
      * @param FindContactTemplatesPresenterInterface $presenter
@@ -51,25 +51,29 @@ class FindContactTemplates
     public function __invoke(FindContactTemplatesPresenterInterface $presenter): void
     {
         try {
+            $this->info('Find contact templates', ['user_id' => $this->user->getId()]);
             if (
                 ! $this->user->hasTopologyRole(Contact::ROLE_CONFIGURATION_CONTACT_TEMPLATES_READ)
                 && ! $this->user->hasTopologyRole(Contact::ROLE_CONFIGURATION_CONTACT_TEMPLATES_READ_WRITE)
             ) {
-                $presenter->presentResponse(
+
+                $this->error('User doesn\'t have sufficient right to list contact templates', [
+                    'user_id' => $this->user->getId(),
+                ]);
+                $presenter->setResponseStatus(
                     new ForbiddenResponse(ContactTemplateException::listingNotAllowed())
                 );
 
                 return;
             }
 
-            $presenter->presentResponse(new FindContactTemplatesResponse($this->repository->findAll()));
-        } catch (RepositoryException $exception) {
-            $presenter->presentResponse(
-                new ErrorResponse(
-                    ContactTemplateException::errorWhileSearchingForContactTemplate(),
-                    ['user_id' => $this->user->getId()],
-                    $exception
-                )
+            $presenter->present(new FindContactTemplatesResponse($this->repository->findAll()));
+        } catch (\Throwable $ex) {
+            $this->error('Error while searching for contact templates', [
+                'trace' => $ex->getTraceAsString(),
+            ]);
+            $presenter->setResponseStatus(
+                new ErrorResponse(ContactTemplateException::errorWhileSearchingForContactTemplate())
             );
 
             return;
