@@ -30,6 +30,7 @@ use Centreon\Infrastructure\RequestParameters\SqlRequestParametersTranslator;
 use Core\Dashboard\Application\Repository\ReadDashboardPerformanceMetricRepositoryInterface as RepositoryInterface;
 use Core\Dashboard\Domain\Model\Metric\PerformanceMetric;
 use Core\Dashboard\Domain\Model\Metric\ResourceMetric;
+use Core\Security\AccessGroup\Domain\Model\AccessGroup;
 
 class DbReadDashboardPerformanceMetricRepository extends AbstractRepositoryDRB implements RepositoryInterface
 {
@@ -67,7 +68,7 @@ class DbReadDashboardPerformanceMetricRepository extends AbstractRepositoryDRB i
     /**
      * @inheritDoc
      */
-    public function FindByRequestParametersAndAccessGroups(
+    public function findByRequestParametersAndAccessGroups(
         RequestParametersInterface $requestParameters,
         array $accessGroups
     ): array {
@@ -93,7 +94,7 @@ class DbReadDashboardPerformanceMetricRepository extends AbstractRepositoryDRB i
     /**
      * @inheritDoc
      */
-    public function FindByRequestParametersAndAccessGroupsAndMetricName(
+    public function findByRequestParametersAndAccessGroupsAndMetricName(
         RequestParametersInterface $requestParameters,
         array $accessGroups,
         string $metricName
@@ -141,7 +142,7 @@ class DbReadDashboardPerformanceMetricRepository extends AbstractRepositoryDRB i
      *  bindValues: array<mixed>
      * }
      */
-    private function buildSubRequestForHostFilter($hostIds): array
+    private function buildSubRequestForHostFilter(array $hostIds): array
     {
         foreach ($hostIds as $hostId) {
             $bindHostIds[':host_' . $hostId] = [$hostId => \PDO::PARAM_INT];
@@ -291,10 +292,20 @@ class DbReadDashboardPerformanceMetricRepository extends AbstractRepositoryDRB i
     /**
      * Get request and bind values information for each search filter.
      *
-     * @param array{
-     *  '$and': array<array<string,array{'$in': non-empty-array<string|int>}>>
+     * @phpstan-param array{
+     *     '$and': array<
+     *         array{
+     *                   'service.name'?: array{'$in': non-empty-array<string>},
+     *                        'host.id'?: array{'$in': non-empty-array<int>},
+     *                   'hostgroup.id'?: array{'$in': non-empty-array<int>},
+     *                'servicegroup.id'?: array{'$in': non-empty-array<int>},
+     *                'hostcategory.id'?: array{'$in': non-empty-array<int>},
+     *             'servicecategory.id'?: array{'$in': non-empty-array<int>},
+     *         }
+     *     >
      * } $search
-     * @param array $search
+     *
+     * @param array<mixed> $search
      *
      * @return array<
      *  string, array{
@@ -400,7 +411,7 @@ class DbReadDashboardPerformanceMetricRepository extends AbstractRepositoryDRB i
      * Build the SQL Query.
      *
      * @param RequestParametersInterface $requestParameters
-     * @param array $accessGroups
+     * @param AccessGroup[] $accessGroups
      * @param bool $hasMetricName
      *
      * @return string
@@ -408,7 +419,7 @@ class DbReadDashboardPerformanceMetricRepository extends AbstractRepositoryDRB i
     private function buildQuery(
         RequestParametersInterface $requestParameters,
         array $accessGroups = [],
-        $hasMetricName = false): string
+        bool $hasMetricName = false): string
     {
         $request
             = <<<'SQL'
@@ -453,7 +464,8 @@ class DbReadDashboardPerformanceMetricRepository extends AbstractRepositoryDRB i
                 SQL;
         }
 
-        $request .= $this->sqlRequestTranslator->translateSortParameterToSql();
+        $sortRequest = $this->sqlRequestTranslator->translateSortParameterToSql();
+        $request .= $sortRequest !== null ? $sortRequest : ' ORDER BY m.metric_id ASC';
         $request .= $this->sqlRequestTranslator->translatePaginationToSql();
 
         return $request;
@@ -499,7 +511,7 @@ class DbReadDashboardPerformanceMetricRepository extends AbstractRepositoryDRB i
      * @param RequestParametersInterface $requestParameters
      * @param \PDOStatement $statement
      *
-     * @return ResourceMetrics[]
+     * @return ResourceMetric[]
      */
     private function buildResourceMetrics(
         RequestParametersInterface $requestParameters,
