@@ -26,6 +26,7 @@ namespace Core\Dashboard\Infrastructure\Repository;
 use Assert\AssertionFailedException;
 use Centreon\Domain\Contact\Interfaces\ContactInterface;
 use Centreon\Domain\Log\LoggerTrait;
+use Centreon\Domain\Repository\RepositoryException;
 use Centreon\Domain\RequestParameters\Interfaces\RequestParametersInterface;
 use Centreon\Domain\RequestParameters\RequestParameters;
 use Centreon\Infrastructure\DatabaseConnection;
@@ -42,7 +43,6 @@ use Core\Dashboard\Domain\Model\Share\DashboardContactShare;
 use Core\Dashboard\Domain\Model\Share\DashboardSharingRoles;
 use Core\Dashboard\Infrastructure\Model\DashboardGlobalRoleConverter;
 use Core\Dashboard\Infrastructure\Model\DashboardSharingRoleConverter;
-use Core\Infrastructure\Common\Repository\RepositoryException;
 use Utility\SqlConcatenator;
 
 class DbReadDashboardShareRepository extends AbstractRepositoryDRB implements ReadDashboardShareRepositoryInterface
