@@ -107,7 +107,18 @@ final class PartialUpdateHostTemplate
                 return;
             }
 
-            if (! ($hostTemplate = $this->readHostTemplateRepository->findById($hostTemplateId))) {
+            if (! $this->user->isAdmin()) {
+                $this->accessGroups = $this->readAccessGroupRepository->findByContact($this->user);
+                $this->validation->accessGroups = $this->accessGroups;
+                $hostTemplate = $this->readHostTemplateRepository->findByIdAndAccessGroups(
+                    $hostTemplateId,
+                    $this->accessGroups
+                );
+            } else {
+                $hostTemplate = $this->readHostTemplateRepository->findById($hostTemplateId);
+            }
+
+            if ($hostTemplate === null) {
                 $this->error(
                     'Host template not found',
                     ['host_template_id' => $hostTemplateId]
@@ -129,11 +140,6 @@ final class PartialUpdateHostTemplate
                 return;
             }
 
-            if (! $this->user->isAdmin()) {
-                $this->accessGroups = $this->readAccessGroupRepository->findByContact($this->user);
-                $this->validation->accessGroups = $this->accessGroups;
-            }
-
             $this->updatePropertiesInTransaction($request, $hostTemplate);
 
             $presenter->setResponseStatus(new NoContentResponse());
