@@ -1,13 +1,13 @@
 <?php
 
 /*
- * Copyright 2005 - 2022 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,6 +18,7 @@
  * For more information : contact@centreon.com
  *
  */
+
 declare(strict_types=1);
 
 namespace Core\Infrastructure\Common\Api;
@@ -28,9 +29,7 @@ use Symfony\Contracts\Service\Attribute\Required;
 
 trait HttpUrlTrait
 {
-    /**
-     * @var ServerBag|null
-     */
+    /** @var ServerBag|null */
     private ?ServerBag $httpServerBag = null;
 
     /**
@@ -43,7 +42,22 @@ trait HttpUrlTrait
     }
 
     /**
-     * Get base URL (example: https://127.0.0.1/centreon)
+     * @param bool $withScheme
+     *
+     * @return string
+     */
+    public function getHost(bool $withScheme = false): string
+    {
+        $httpHost = $_SERVER['HTTP_HOST'];
+        if ($withScheme) {
+            $scheme = $_SERVER['REQUEST_SCHEME'];
+        }
+
+        return $withScheme ? sprintf('%s://%s', $scheme, $httpHost) : $httpHost;
+    }
+
+    /**
+     * Get base URL (example: https://127.0.0.1/centreon).
      *
      * @return string
      */
@@ -82,7 +96,7 @@ trait HttpUrlTrait
     }
 
     /**
-     * Get base URI (example: /centreon)
+     * Get base URI (example: /centreon).
      *
      * @return string
      */
@@ -107,18 +121,4 @@ trait HttpUrlTrait
 
         return rtrim($baseUri, '/');
     }
-
-    /**
-     * @param bool $withScheme
-     * @return string
-     */
-    public function getHost(bool $withScheme = false): string
-    {
-        $httpHost = $_SERVER['HTTP_HOST'];
-        if ($withScheme) {
-            $scheme = $_SERVER['REQUEST_SCHEME'];
-        }
-
-        return $withScheme ? sprintf("%s://%s", $scheme, $httpHost) : $httpHost;
-    }
 }
