@@ -24,27 +24,24 @@ declare(strict_types=1);
 namespace Core\MonitoringServer\Infrastructure\Repository;
 
 use Assert\AssertionFailedException;
-use Centreon\Domain\Exception\EntityNotFoundException;
 use Centreon\Domain\Log\LoggerTrait;
 use Centreon\Infrastructure\DatabaseConnection;
 use Core\Common\Infrastructure\Repository\AbstractRepositoryRDB;
+use Core\Common\Infrastructure\Repository\SqlMultipleBindTrait;
+use Core\Host\Infrastructure\Repository\HostRepositoryTrait;
 use Core\MonitoringServer\Application\Repository\ReadMonitoringServerRepositoryInterface;
 use Core\MonitoringServer\Model\MonitoringServer;
+use Utility\SqlConcatenator;
 
 /**
  * @phpstan-type MSResultSet array{
  *     id: int,
- *     name: string,
- *     engine_start_command ?: string|null,
- *     engine_stop_command ?: string|null,
- *     engine_restart_command ?: string|null,
- *     engine_reload_command ?: string|null,
- *     broker_reload_command ?: string|null
+ *     name: string
  * }
  */
 class DbReadMonitoringServerRepository extends AbstractRepositoryRDB implements ReadMonitoringServerRepositoryInterface
 {
-    use LoggerTrait;
+    use HostRepositoryTrait, LoggerTrait, SqlMultipleBindTrait;
 
     /**
      * @param DatabaseConnection $db
@@ -75,6 +72,57 @@ class DbReadMonitoringServerRepository extends AbstractRepositoryRDB implements
         return (bool) $statement->fetchColumn();
     }
 
+    /**
+     * @inheritDoc
+     */
+    public function existsByAccessGroups(int $monitoringServerId, array $accessGroups): bool
+    {
+        $this->debug(
+            'Check existence of monitoring server with',
+            ['id' => $monitoringServerId, 'access_groups' => $accessGroups]
+        );
+
+        if ($accessGroups === []) {
+            $this->debug('Access groups array is empty');
+
+            return false;
+        }
+
+        $accessGroupIds = array_map(
+            fn($accessGroup) => $accessGroup->getId(),
+            $accessGroups
+        );
+
+        if ($this->hasAccessToAllHosts($accessGroupIds)) {
+            return $this->exists($monitoringServerId);
+        }
+
+        [$bindValues, $bindQuery] = $this->createMultipleBindQuery($accessGroupIds, ':access_group_id_');
+
+        $request = $this->translateDbName(
+            <<<SQL
+                SELECT 1
+                FROM `:db`.`nagios_server` ns
+                INNER JOIN `:db`.`acl_resources_poller_relations` arpr
+                    ON arpr.`poller_id` = ns.`id`
+                INNER JOIN `:db`.`acl_res_group_relations` argr
+                    ON argr.`acl_res_id` = arpr.`acl_res_id`
+                INNER JOIN `:db`.`acl_groups` ag
+                    ON ag.`acl_group_id` = argr.`acl_group_id`
+                WHERE `id` = :monitoring_server_id
+                    AND ag.`acl_group_id` IN ({$bindQuery})
+                SQL
+        );
+        $statement = $this->db->prepare($request);
+        $statement->bindValue(':monitoring_server_id', $monitoringServerId, \PDO::PARAM_INT);
+        foreach ($bindValues as $bindParam => $bindValue) {
+            $statement->bindValue($bindParam, $bindValue, \PDO::PARAM_INT);
+        }
+        $statement->execute();
+
+        return (bool) $statement->fetchColumn();
+    }
+
     public function findByHost(int $hostId): ?MonitoringServer
     {
         $request = $this->translateDbName(
@@ -96,59 +144,44 @@ class DbReadMonitoringServerRepository extends AbstractRepositoryRDB implements
         return $data ? $this->createMonitoringServerFromArray($data) : null;
     }
 
-    public function findAll(): array
+    /**
+     * @inheritDoc
+     */
+    public function findByIds(array $ids): array
     {
-        $statement = $this->db->prepare($this->translateDbName(<<<'SQL'
-            SELECT
-                id,
-                name,
-                engine_start_command,
-                engine_stop_command,
-                engine_restart_command,
-                engine_reload_command,
-                broker_reload_command
-            FROM `:db`.`nagios_server`
-            SQL
-        ));
+        if ($ids === []) {
+
+            return $ids;
+        }
+
+        $concatenator = new SqlConcatenator();
+        $concatenator->defineSelect(
+            <<<'SQL'
+                SELECT
+                    `id`,
+                    `name`
+                FROM `:db`.`nagios_server` ns
+                WHERE ns.id IN (:ids)
+                SQL
+        );
+        $concatenator->storeBindValueMultiple(':ids', $ids, \PDO::PARAM_INT);
+        $statement = $this->db->prepare($this->translateDbName($concatenator->__toString()));
+        $concatenator->bindValuesToStatement($statement);
+
+        $statement->setFetchMode(\PDO::FETCH_ASSOC);
         $statement->execute();
 
         $monitoringServers = [];
-        foreach ($statement->fetchAll(\PDO::FETCH_ASSOC) as $result) {
-            $monitoringServers[] = $this->createMonitoringServerFromArray($result);
+        foreach ($statement as $row) {
+            /** @var MSResultSet $row */
+            $monitoringServers[] = $this->createMonitoringServerFromArray($row);
         }
 
         return $monitoringServers;
     }
 
-    public function get(int $monitoringServerId): MonitoringServer
-    {
-        $statement = $this->db->prepare($this->translateDbName(<<<'SQL'
-            SELECT
-                id,
-                name,
-                engine_start_command,
-                engine_stop_command,
-                engine_restart_command,
-                engine_reload_command,
-                broker_reload_command
-            FROM `:db`.`nagios_server`
-            WHERE id = :monitoringServerId
-            SQL
-        ));
-        $statement->bindValue(':monitoringServerId', $monitoringServerId, \PDO::PARAM_INT);
-        $statement->execute();
-        /** @var MSResultSet|false */
-        $data = $statement->fetch(\PDO::FETCH_ASSOC);
-
-        return $data
-            ? $this->createMonitoringServerFromArray($data)
-            : throw new EntityNotFoundException(sprintf('Monitoring Server [%d] does not exist', $monitoringServerId));
-    }
-
     /**
-     * @param array $result
-     *
-     * @phpstan-param MSResultSet $result
+     * @param MSResultSet $result
      *
      * @throws AssertionFailedException
      *
@@ -158,12 +191,7 @@ class DbReadMonitoringServerRepository extends AbstractRepositoryRDB implements
     {
         return new MonitoringServer(
             id: $result['id'],
-            name: $result['name'],
-            engineStartCommand: $result['engine_start_command'] ?? null,
-            engineStopCommand: $result['engine_stop_command'] ?? null,
-            engineReloadCommand: $result['engine_reload_command'] ?? null,
-            engineRestartCommand: $result['engine_restart_command'] ?? null,
-            brokerReloadCommand: $result['broker_reload_command'] ?? null
+            name: $result['name']
         );
     }
-}
\ No newline at end of file
+}
