@@ -27,7 +27,7 @@ use Centreon;
 use Centreon\Domain\Contact\Interfaces\ContactInterface;
 use Centreon\Domain\Contact\Interfaces\ContactServiceInterface;
 use Centreon\Domain\Log\LoggerTrait;
-use CentreonUserLog;
+use CentreonLog;
 use Core\Application\Configuration\User\Repository\WriteUserRepositoryInterface;
 use Core\Contact\Domain\Model\ContactGroup;
 use Core\Domain\Configuration\User\Model\NewUser;
@@ -46,7 +46,6 @@ use Core\Security\ProviderConfiguration\Domain\SecurityAccess\GroupsMapping as G
 use Core\Security\ProviderConfiguration\Domain\SecurityAccess\RolesMapping;
 use DateInterval;
 use Exception;
-use Pimple\Container;
 use Security\Domain\Authentication\Interfaces\OpenIdProviderInterface;
 use Symfony\Component\HttpFoundation\Response;
 use Symfony\Component\Routing\Generator\UrlGeneratorInterface;
@@ -81,9 +80,6 @@ class OpenIdProvider implements OpenIdProviderInterface
     /** @var Centreon */
     private Centreon $legacySession;
 
-    /** @var CentreonUserLog */
-    private CentreonUserLog $centreonLog;
-
     /**
      * Array of information store in id_token JWT Payload.
      *
@@ -105,7 +101,6 @@ class OpenIdProvider implements OpenIdProviderInterface
      * @param HttpClientInterface $client
      * @param UrlGeneratorInterface $router
      * @param ContactServiceInterface $contactService
-     * @param Container $dependencyInjector
      * @param WriteUserRepositoryInterface $userRepository
      * @param Conditions $conditions
      * @param RolesMapping $rolesMapping
@@ -116,15 +111,12 @@ class OpenIdProvider implements OpenIdProviderInterface
         private HttpClientInterface $client,
         private UrlGeneratorInterface $router,
         private ContactServiceInterface $contactService,
-        private Container $dependencyInjector,
         private WriteUserRepositoryInterface $userRepository,
         private readonly Conditions $conditions,
         private readonly RolesMapping $rolesMapping,
         private readonly GroupsMappingSecurityAccess $groupsMapping,
         private readonly AttributePathFetcher $attributePathFetcher
     ) {
-        $pearDB = $this->dependencyInjector['configuration_db'];
-        $this->centreonLog = new CentreonUserLog(-1, $pearDB);
     }
 
     /**
@@ -189,6 +181,9 @@ class OpenIdProvider implements OpenIdProviderInterface
             $this->userInformations[$customConfiguration->getUserNameBindAttribute()],
             $this->userInformations[$customConfiguration->getEmailBindAttribute()],
         );
+        if ($user->canReachFrontend()) {
+            $user->setCanReachRealtimeApi(true);
+        }
         $user->setContactTemplate($customConfiguration->getContactTemplate());
         $this->userRepository->create($user);
         $this->info('Auto import complete', [
@@ -276,7 +271,7 @@ class OpenIdProvider implements OpenIdProviderInterface
             $this->idTokenPayload = $this->extractTokenPayload($this->connectionTokenResponseContent['id_token']);
         }
         $this->verifyThatClientIsAllowedToConnectOrFail($clientIp);
-        if ($this->providerToken->isExpired() && $this->refreshToken->isExpired()) {
+        if ($this->providerToken->isExpired() && $this->refreshToken?->isExpired()) {
             throw SSOAuthenticationException::tokensExpired($this->configuration->getName());
         }
         if ($customConfiguration->getIntrospectionTokenEndpoint() !== null) {
@@ -327,8 +322,11 @@ class OpenIdProvider implements OpenIdProviderInterface
 
         // Get the status code and throw an Exception if not a 200
         $statusCode = $response->getStatusCode();
+        $content = json_decode($response->getContent(false), true, 512, JSON_THROW_ON_ERROR) ?: [];
         if ($statusCode !== Response::HTTP_OK) {
             $this->logErrorForInvalidStatusCode($statusCode, Response::HTTP_OK);
+            $this->logErrorInLoginLogFile('Refresh Token Request Error:', $content);
+            $this->logErrorFromExternalProvider($content);
             $this->logExceptionInLoginLogFile(
                 'Unable to get Refresh Token Information: %s, message: %s',
                 SSOAuthenticationException::requestForRefreshTokenFail()
@@ -336,13 +334,7 @@ class OpenIdProvider implements OpenIdProviderInterface
 
             throw SSOAuthenticationException::requestForRefreshTokenFail();
         }
-        $content = json_decode($response->getContent(false), true);
-        if (empty($content) || array_key_exists('error', $content)) {
-            $this->logErrorInLoginLogFile('Refresh Token Info:', $content);
-            $this->logErrorFromExternalProvider($content);
 
-            throw SSOAuthenticationException::errorFromExternalProvider($this->configuration->getName());
-        }
         $this->logAuthenticationDebug('Token Access Information:', $content);
         $creationDate = new \DateTimeImmutable();
         $providerTokenExpiration
@@ -479,8 +471,11 @@ class OpenIdProvider implements OpenIdProviderInterface
 
         // Get the status code and throw an Exception if not a 200
         $statusCode = $response->getStatusCode();
+        $content = json_decode($response->getContent(false), true, 512, JSON_THROW_ON_ERROR) ?: [];
         if ($statusCode !== Response::HTTP_OK) {
             $this->logErrorForInvalidStatusCode($statusCode, Response::HTTP_OK);
+            $this->logErrorInLoginLogFile('Connection Token Request Error: ', $content);
+            $this->logErrorFromExternalProvider($content);
             $this->logExceptionInLoginLogFile(
                 'Unable to get Token Access Information: %s, message: %s',
                 SSOAuthenticationException::requestForConnectionTokenFail()
@@ -488,13 +483,7 @@ class OpenIdProvider implements OpenIdProviderInterface
 
             throw SSOAuthenticationException::requestForConnectionTokenFail();
         }
-        $content = json_decode($response->getContent(false), true);
-        if (empty($content) || array_key_exists('error', $content)) {
-            $this->logErrorInLoginLogFile('Connection Token Info: ', $content);
-            $this->logErrorFromExternalProvider($content);
 
-            throw SSOAuthenticationException::errorFromExternalProvider($this->configuration->getName());
-        }
         $this->logAuthenticationDebug('Token Access Information:', $content);
         $this->connectionTokenResponseContent = $content;
     }
@@ -568,7 +557,7 @@ class OpenIdProvider implements OpenIdProviderInterface
             $response = $this->client->request(
                 'POST',
                 $customConfiguration->getBaseUrl() . '/'
-                . ltrim($customConfiguration->getIntrospectionTokenEndpoint(), '/'),
+                . ltrim($customConfiguration->getIntrospectionTokenEndpoint() ?? '', '/'),
                 [
                     'headers' => $headers,
                     'body' => $data,
@@ -588,8 +577,11 @@ class OpenIdProvider implements OpenIdProviderInterface
         }
 
         $statusCode = $response->getStatusCode();
+        $content = json_decode($response->getContent(false), true, 512, JSON_THROW_ON_ERROR) ?: [];
         if ($statusCode !== Response::HTTP_OK) {
             $this->logErrorForInvalidStatusCode($statusCode, Response::HTTP_OK);
+            $this->logErrorInLoginLogFile('Introspection Token Info: ', $content);
+            $this->logErrorFromExternalProvider($content);
             $this->logExceptionInLoginLogFile(
                 'Unable to get Introspection Information: %s, message: %s',
                 SSOAuthenticationException::requestForIntrospectionTokenFail()
@@ -597,13 +589,6 @@ class OpenIdProvider implements OpenIdProviderInterface
 
             throw SSOAuthenticationException::requestForIntrospectionTokenFail();
         }
-        $content = json_decode($response->getContent(false), true);
-        if (empty($content) || array_key_exists('error', $content)) {
-            $this->logErrorInLoginLogFile('Introspection Token Info: ', $content);
-            $this->logErrorFromExternalProvider($content);
-
-            throw SSOAuthenticationException::errorFromExternalProvider($this->configuration->getName());
-        }
 
         $this->logAuthenticationInfo('Token Introspection Information: ', $content);
 
@@ -644,9 +629,9 @@ class OpenIdProvider implements OpenIdProviderInterface
         ];
         /** @var CustomConfiguration $customConfiguration */
         $customConfiguration = $this->configuration->getCustomConfiguration();
-        $url = str_starts_with($customConfiguration->getUserInformationEndpoint(), '/')
+        $url = str_starts_with($customConfiguration->getUserInformationEndpoint() ?? '', '/')
             ? $customConfiguration->getBaseUrl() . $customConfiguration->getUserInformationEndpoint()
-            : $customConfiguration->getUserInformationEndpoint();
+            : $customConfiguration->getUserInformationEndpoint() ?? '';
         try {
             $response = $this->client->request(
                 'GET',
@@ -661,8 +646,11 @@ class OpenIdProvider implements OpenIdProviderInterface
         }
 
         $statusCode = $response->getStatusCode();
+        $content = json_decode($response->getContent(false), true, 512, JSON_THROW_ON_ERROR) ?: [];
         if ($statusCode !== Response::HTTP_OK) {
             $this->logErrorForInvalidStatusCode($statusCode, Response::HTTP_OK);
+            $this->logErrorInLoginLogFile('User Information Info: ', $content);
+            $this->logErrorFromExternalProvider($content);
             $this->logExceptionInLoginLogFile(
                 'Unable to get User Information: %s, message: %s',
                 SSOAuthenticationException::requestForUserInformationFail()
@@ -670,13 +658,6 @@ class OpenIdProvider implements OpenIdProviderInterface
 
             throw SSOAuthenticationException::requestForUserInformationFail();
         }
-        $content = json_decode($response->getContent(false), true);
-        if (empty($content) || array_key_exists('error', $content)) {
-            $this->logErrorInLoginLogFile('User Information Info: ', $content);
-            $this->logErrorFromExternalProvider($content);
-
-            throw SSOAuthenticationException::errorFromExternalProvider($this->configuration->getName());
-        }
 
         $this->logAuthenticationDebug('User Information: ', $content);
 
@@ -731,7 +712,7 @@ class OpenIdProvider implements OpenIdProviderInterface
                     $this->attributePathFetcher->fetch(
                         $accessToken,
                         $this->configuration,
-                        $authenticationConditions->getEndpoint()
+                        $authenticationConditions->getEndpoint() ?? throw new \LogicException()
                     ),
                     $this->idTokenPayload
                 )
@@ -748,7 +729,7 @@ class OpenIdProvider implements OpenIdProviderInterface
                     $this->attributePathFetcher->fetch(
                         $accessToken,
                         $this->configuration,
-                        $rolesMapping->getEndpoint()
+                        $rolesMapping->getEndpoint() ?? throw new \LogicException()
                     ),
                     $this->idTokenPayload
                 )
@@ -766,7 +747,7 @@ class OpenIdProvider implements OpenIdProviderInterface
                     $this->attributePathFetcher->fetch(
                         $accessToken,
                         $this->configuration,
-                        $groupsMapping->getEndpoint()
+                        $groupsMapping->getEndpoint() ?? throw new \LogicException()
                     ),
                     $this->idTokenPayload
                 )
@@ -796,9 +777,9 @@ class OpenIdProvider implements OpenIdProviderInterface
             $this->getUserInformationFromUserInfoEndpoint();
         }
         if (! array_key_exists($loginClaim, $this->userInformations)) {
-            $this->centreonLog->insertLog(
-                CentreonUserLog::TYPE_LOGIN,
-                '[Openid] [Error] Unable to get login from claim: ' . $loginClaim
+            CentreonLog::create()->error(
+                CentreonLog::TYPE_LOGIN,
+                '[Openid] Unable to get login from claim: ' . $loginClaim
             );
             $this->error('Login Claim not found', ['login_claim' => $loginClaim]);
 
@@ -833,9 +814,9 @@ class OpenIdProvider implements OpenIdProviderInterface
             $data['client_secret'] = $customConfiguration->getClientSecret();
         }
 
-        $url = str_starts_with($customConfiguration->getTokenEndpoint(), '/')
+        $url = str_starts_with($customConfiguration->getTokenEndpoint() ?? '', '/')
             ? $customConfiguration->getBaseUrl() . $customConfiguration->getTokenEndpoint()
-            : $customConfiguration->getTokenEndpoint();
+            : $customConfiguration->getTokenEndpoint() ?? '';
 
         // Send the request to IDP
         try {
@@ -875,10 +856,10 @@ class OpenIdProvider implements OpenIdProviderInterface
         $missingAttributes = [];
         /** @var CustomConfiguration $customConfiguration */
         $customConfiguration = $this->configuration->getCustomConfiguration();
-        if (! array_key_exists($customConfiguration->getEmailBindAttribute(), $this->userInformations)) {
+        if (! array_key_exists($customConfiguration->getEmailBindAttribute() ?? '', $this->userInformations)) {
             $missingAttributes[] = $customConfiguration->getEmailBindAttribute();
         }
-        if (! array_key_exists($customConfiguration->getUserNameBindAttribute(), $this->userInformations)) {
+        if (! array_key_exists($customConfiguration->getUserNameBindAttribute() ?? '', $this->userInformations)) {
             $missingAttributes[] = $customConfiguration->getUserNameBindAttribute();
         }
 
@@ -901,8 +882,8 @@ class OpenIdProvider implements OpenIdProviderInterface
     private function logErrorFromExternalProvider(array $content): void
     {
         $this->error(
-            'error from external provider :' . (array_key_exists('error', $content)
-                ? $content['error']
+            'error from external provider :' . (array_key_exists('error_description', $content)
+                ? $content['error_description']
                 : 'No content in response')
         );
     }
@@ -932,10 +913,10 @@ class OpenIdProvider implements OpenIdProviderInterface
      */
     private function logErrorInLoginLogFile(string $message, array $content): void
     {
-        if (array_key_exists('error', $content)) {
-            $this->centreonLog->insertLog(
-                CentreonUserLog::TYPE_LOGIN,
-                "[Openid] [Error] {$message}" . json_encode($content)
+        if (array_key_exists('error_description', $content)) {
+            CentreonLog::create()->error(
+                CentreonLog::TYPE_LOGIN,
+                "[Openid] {$message} " . $content['error_description']
             );
         }
     }
@@ -963,9 +944,9 @@ class OpenIdProvider implements OpenIdProviderInterface
         if (isset($content['provider_token'])) {
             $content['provider_token'] = mb_substr($content['provider_token'], -10);
         }
-        $this->centreonLog->insertLog(
-            CentreonUserLog::TYPE_LOGIN,
-            "[Openid] [Debug] {$message} " . json_encode($content)
+        CentreonLog::create()->debug(
+            CentreonLog::TYPE_LOGIN,
+            "[Openid] {$message} " . json_encode($content, JSON_THROW_ON_ERROR)
         );
         $this->debug('Authentication information : ', $content);
     }
@@ -978,9 +959,10 @@ class OpenIdProvider implements OpenIdProviderInterface
      */
     private function logAuthenticationInfo(string $message, ?array $content = null): void
     {
-        $this->centreonLog->insertLog(
-            CentreonUserLog::TYPE_LOGIN,
-            "[openid] [INFO] {$message}" . ($content !== null ? ' : ' . json_encode($content) : '')
+        CentreonLog::create()->info(
+            CentreonLog::TYPE_LOGIN,
+            "[Openid] {$message}" . ($content !== null ? ' : ' . json_encode($content, JSON_THROW_ON_ERROR) : ''),
+            $content ?: []
         );
 
         $this->info("{$message} : ", $content ?: []);
@@ -990,17 +972,19 @@ class OpenIdProvider implements OpenIdProviderInterface
      * Log Exception in login.log file.
      *
      * @param string $message
-     * @param \Exception $exception
+     * @param Exception $exception
      */
     private function logExceptionInLoginLogFile(string $message, Exception $exception): void
     {
-        $this->centreonLog->insertLog(
-            CentreonUserLog::TYPE_LOGIN,
+        CentreonLog::create()->error(
+            CentreonLog::TYPE_LOGIN,
             sprintf(
-                "[Openid] [Error] {$message}",
+                "[Openid] {$message}",
                 $exception::class,
                 $exception->getMessage()
-            )
+            ),
+            ['exception' => $exception],
+            $exception
         );
     }
 
