@@ -26,10 +26,8 @@ namespace Core\Security\ProviderConfiguration\Application\OpenId\UseCase\UpdateO
 use Assert\AssertionFailedException;
 use Centreon\Domain\Common\Assertion\AssertionException;
 use Centreon\Domain\Log\LoggerTrait;
-use Centreon\Domain\Repository\Interfaces\DataStorageEngineInterface;
 use Core\Application\Common\UseCase\ErrorResponse;
 use Core\Application\Common\UseCase\NoContentResponse;
-use Core\Common\Domain\Exception\RepositoryException;
 use Core\Contact\Application\Repository\ReadContactGroupRepositoryInterface;
 use Core\Contact\Application\Repository\ReadContactTemplateRepositoryInterface;
 use Core\Contact\Domain\Model\ContactGroup;
@@ -49,6 +47,9 @@ use Core\Security\ProviderConfiguration\Domain\Model\GroupsMapping;
 use Core\Security\ProviderConfiguration\Domain\Model\Provider;
 use Core\Security\ProviderConfiguration\Domain\OpenId\Model\CustomConfiguration;
 
+/**
+ * @phpstan-import-type _RoleMapping from UpdateOpenIdConfigurationRequest
+ */
 class UpdateOpenIdConfiguration
 {
     use LoggerTrait;
@@ -58,7 +59,6 @@ class UpdateOpenIdConfiguration
      * @param ReadContactTemplateRepositoryInterface $contactTemplateRepository
      * @param ReadContactGroupRepositoryInterface $contactGroupRepository
      * @param ReadAccessGroupRepositoryInterface $accessGroupRepository
-     * @param DataStorageEngineInterface $dataStorageEngine
      * @param ProviderAuthenticationFactoryInterface $providerAuthenticationFactory
      */
     public function __construct(
@@ -66,7 +66,6 @@ class UpdateOpenIdConfiguration
         private ReadContactTemplateRepositoryInterface $contactTemplateRepository,
         private ReadContactGroupRepositoryInterface $contactGroupRepository,
         private ReadAccessGroupRepositoryInterface $accessGroupRepository,
-        private DataStorageEngineInterface $dataStorageEngine,
         private ProviderAuthenticationFactoryInterface $providerAuthenticationFactory
     ) {
     }
@@ -79,9 +78,13 @@ class UpdateOpenIdConfiguration
         UpdateOpenIdConfigurationPresenterInterface $presenter,
         UpdateOpenIdConfigurationRequest $request
     ): void {
+
         $this->info('Updating OpenID Provider');
         try {
             $provider = $this->providerAuthenticationFactory->create(Provider::OPENID);
+            /**
+             * @var Configuration $configuration
+             */
             $configuration = $provider->getConfiguration();
             $configuration->update($request->isActive, $request->isForced);
             $requestArray = $request->toArray();
@@ -98,44 +101,19 @@ class UpdateOpenIdConfiguration
             $requestArray['is_active'] = $request->isActive;
 
             $configuration->setCustomConfiguration(new CustomConfiguration($requestArray));
-            $this->updateConfiguration($configuration);
+
+            $this->info('Updating OpenID Provider');
+            $this->repository->updateConfiguration($configuration);
         } catch (AssertionException|AssertionFailedException|ConfigurationException $ex) {
             $this->error(
                 'Unable to create OpenID Provider because one or several parameters are invalid',
-                [
-                    'exception' => [
-                        'type' => $ex::class,
-                        'message' => $ex->getMessage(),
-                        'file' => $ex->getFile(),
-                        'line' => $ex->getLine(),
-                        'trace' => $ex->getTraceAsString(),
-                    ],
-                ]
+                ['trace' => $ex->getTraceAsString()]
             );
             $presenter->setResponseStatus(new ErrorResponse($ex->getMessage()));
 
-            return;
-        } catch (RepositoryException $exception) {
-            $this->error(
-                'Error during Opend ID Provider Update',
-                ['exception' => $exception->getContext()]
-            );
-            $presenter->setResponseStatus(new ErrorResponse($exception->getMessage()));
-
             return;
         } catch (\Throwable $ex) {
-            $this->error(
-                'Error during Opend ID Provider Update',
-                [
-                    'exception' => [
-                        'type' => $ex::class,
-                        'message' => $ex->getMessage(),
-                        'file' => $ex->getFile(),
-                        'line' => $ex->getLine(),
-                        'trace' => $ex->getTraceAsString(),
-                    ],
-                ]
-            );
+            $this->error('Error during Opend ID Provider Update', ['trace' => $ex->getTraceAsString()]);
             $presenter->setResponseStatus(new UpdateOpenIdConfigurationErrorResponse());
 
             return;
@@ -149,7 +127,7 @@ class UpdateOpenIdConfiguration
      *
      * @param array{id: int, name: string}|null $contactTemplateFromRequest
      *
-     * @throws ConfigurationException|RepositoryException
+     * @throws \Throwable|ConfigurationException
      *
      * @return ContactTemplate|null
      */
@@ -208,7 +186,7 @@ class UpdateOpenIdConfiguration
     }
 
     /**
-     * @param array<string,bool|string|string[]|array<array{claim_value: string, access_group_id: int}>> $rolesMapping
+     * @param _RoleMapping $rolesMapping
      *
      * @throws \Throwable
      *
@@ -288,34 +266,6 @@ class UpdateOpenIdConfiguration
         return array_unique($accessGroupIds);
     }
 
-    /**
-     * Update OpenId Provider.
-     *
-     * @param Configuration $configuration
-     *
-     * @throws \Throwable
-     */
-    private function updateConfiguration(Configuration $configuration): void
-    {
-        $isAlreadyInTransaction = $this->dataStorageEngine->isAlreadyinTransaction();
-        try {
-            if (! $isAlreadyInTransaction) {
-                $this->dataStorageEngine->startTransaction();
-            }
-            $this->info('Updating OpenID Provider');
-            $this->repository->updateConfiguration($configuration);
-            if (! $isAlreadyInTransaction) {
-                $this->dataStorageEngine->commitTransaction();
-            }
-        } catch (\Throwable $ex) {
-            if (! $isAlreadyInTransaction) {
-                $this->dataStorageEngine->rollbackTransaction();
-
-                throw $ex;
-            }
-        }
-    }
-
     /**
      * Create Authentication Condition from request data.
      *
@@ -433,10 +383,13 @@ class UpdateOpenIdConfiguration
         foreach ($foundContactGroups as $foundAccessGroup) {
             $foundContactGroupsId[] = $foundAccessGroup->getId();
         }
-        $nonExistentAccessGroupsIds = array_diff($contactGroupIds, $foundContactGroupsId);
-        $this->error('Access groups not found', [
-            'access_group_ids' => implode(', ', $nonExistentAccessGroupsIds),
-        ]);
+        $nonExistentContactGroupsIds = array_diff($contactGroupIds, $foundContactGroupsId);
+
+        if (! empty($nonExistentContactGroupsIds)) {
+            $this->error('Contact groups not found', [
+                'contact_group_ids' => implode(', ', $nonExistentContactGroupsIds),
+            ]);
+        }
     }
 
     /**
