@@ -30,7 +30,22 @@ use Core\Security\ProviderConfiguration\Domain\Model\AuthorizationRule;
 use Core\Security\ProviderConfiguration\Domain\Model\ContactGroupRelation;
 use Core\Security\ProviderConfiguration\Domain\Model\GroupsMapping;
 
-class FindSAMLConfigurationResponse
+/**
+ * @phpstan-type _authorizationRules array{
+ *     claim_value: string,
+ *     access_group: array{
+ *         id: int,
+ *         name: string
+ *     }
+ * }
+ * @phpstan-type _aclConditions array{
+ *     is_enabled: bool,
+ *     apply_only_first_role: bool,
+ *     attribute_path: string,
+ *     relations: array<_authorizationRules>,
+ * }
+ */
+final class FindSAMLConfigurationResponse
 {
     /** @var bool */
     public bool $isActive = false;
@@ -62,26 +77,23 @@ class FindSAMLConfigurationResponse
     /** @var string */
     public string $userIdAttribute = '';
 
-    /** @var string */
-    public string $requestedAuthnContext = 'minimum';
-
     /** @var bool */
     public bool $logoutFrom = true;
 
     /** @var string|null */
     public ?string $logoutFromUrl = null;
 
-    /** @var array<string, array<int|string, string|null>|string|bool> */
+    /** @var _aclConditions|array{} */
     public array $aclConditions = [];
 
     /** @var array<string,bool|string|string[]> */
     public array $authenticationConditions = [];
 
     /**
-     * @var array{
+     * @var array{}|array{
      *  "is_enabled": bool,
      *  "attribute_path": string,
-     *  "endpoint": array{
+     *  "endpoint"?: array{
      *      "type": string,
      *      "custom_endpoint": string|null
      *  },
@@ -112,7 +124,7 @@ class FindSAMLConfigurationResponse
     /**
      * @param AuthorizationRule[] $authorizationRules
      *
-     * @return array<array{claim_value: string, access_group:array{id: int, name: string}}>
+     * @return array<_authorizationRules>
      */
     public static function authorizationRulesToArray(array $authorizationRules): array
     {
@@ -134,13 +146,7 @@ class FindSAMLConfigurationResponse
      * @return array{
      *  "is_enabled": bool,
      *  "attribute_path": string,
-     *  "endpoint": array{
-     *      "type": string,
-     *      "custom_endpoint":string|null
-     *  },
      *  "authorized_values": string[],
-     *  "trusted_client_addresses": string[],
-     *  "blacklist_client_addresses": string[]
      * }
      */
     public static function authenticationConditionsToArray(AuthenticationConditions $authenticationConditions): array
@@ -158,10 +164,6 @@ class FindSAMLConfigurationResponse
      * @return array{
      *  "is_enabled": bool,
      *  "attribute_path": string,
-     *  "endpoint": array{
-     *      "type": string,
-     *      "custom_endpoint": string|null
-     *  },
      *  "relations": array<array{
      *      "group_value": string,
      *      "contact_group": array{
@@ -196,7 +198,7 @@ class FindSAMLConfigurationResponse
     public static function contactGroupRelationsToArray(array $contactGroupRelations): array
     {
         return array_map(
-            fn (ContactGroupRelation $contactGroupRelation) => [
+            fn(ContactGroupRelation $contactGroupRelation) => [
                 'group_value' => $contactGroupRelation->getClaimValue(),
                 'contact_group' => [
                     'id' => $contactGroupRelation->getContactGroup()->getId(),
@@ -210,7 +212,7 @@ class FindSAMLConfigurationResponse
     /**
      * @param ACLConditions $aclConditions
      *
-     * @return array<string, array<int|string,string|null|array<mixed>>|string|bool>
+     * @return _aclConditions
      */
     public static function aclConditionsToArray(ACLConditions $aclConditions): array
     {
