@@ -26,11 +26,13 @@ namespace Core\Security\ProviderConfiguration\Domain\SecurityAccess;
 use Centreon\Domain\Log\LoggerTrait;
 use Core\Contact\Domain\Model\ContactGroup;
 use Core\Security\Authentication\Domain\Exception\AuthenticationConditionsException;
+use Core\Security\ProviderConfiguration\Domain\Exception\ConfigurationException;
 use Core\Security\ProviderConfiguration\Domain\LoginLoggerInterface;
 use Core\Security\ProviderConfiguration\Domain\Model\Configuration;
 use Core\Security\ProviderConfiguration\Domain\Model\ContactGroupRelation;
 use Core\Security\ProviderConfiguration\Domain\Model\Provider;
-use Core\Security\ProviderConfiguration\Domain\SecurityAccess\AttributePath\AttributePathFetcher;
+use Core\Security\ProviderConfiguration\Domain\OpenId\Model\CustomConfiguration as OpenIdCustomConfiguration;
+use Core\Security\ProviderConfiguration\Domain\SAML\Model\CustomConfiguration as SamlCustomConfiguration;
 
 /**
  * Configured conditions must be satisfied to be authorized and map IDP's groups and Centreon's groups.
@@ -49,11 +51,9 @@ class GroupsMapping implements SecurityAccessInterface
 
     /**
      * @param LoginLoggerInterface $loginLogger
-     * @param AttributePathFetcher $attributePathFetcher
      */
     public function __construct(
         private readonly LoginLoggerInterface $loginLogger,
-        private readonly AttributePathFetcher $attributePathFetcher
     ) {
     }
 
@@ -62,12 +62,18 @@ class GroupsMapping implements SecurityAccessInterface
      * @param array<string,mixed> $identityProviderData
      *
      * @throws AuthenticationConditionsException
-     * @throws ConfigurationException
      */
     public function validate(Configuration $configuration, array $identityProviderData): void
     {
         $this->scope = $configuration->getType();
         $customConfiguration = $configuration->getCustomConfiguration();
+        if (
+            ! $customConfiguration instanceof OpenIdCustomConfiguration
+            && ! $customConfiguration instanceof SamlCustomConfiguration
+        ) {
+            throw ConfigurationException::unexpectedCustomConfiguration($customConfiguration::class);
+        }
+
         $groupsMapping = $customConfiguration->getGroupsMapping();
 
         if (! $groupsMapping->isEnabled()) {
@@ -86,7 +92,7 @@ class GroupsMapping implements SecurityAccessInterface
         }
 
         $this->loginLogger->info($this->scope, 'Configured groups mapping attribute path found', $groupsAttributePath);
-        $this->info('Configured groups mapping attribute path found', ['groupAttributePath' => $groupsAttributePath]);
+        $this->info('Configured groups mapping attribute path found', $groupsAttributePath);
 
         $groupRelationContextDebug = array_map(
             function (ContactGroupRelation $contactGroupRelation) {
@@ -134,8 +140,8 @@ class GroupsMapping implements SecurityAccessInterface
     }
 
     /**
-     * @param array $providerGroupsMapping
-     * @param array $contactGroupRelations
+     * @param array<mixed> $providerGroupsMapping
+     * @param array<mixed> $contactGroupRelations
      *
      * @throws AuthenticationConditionsException
      */
