@@ -35,6 +35,9 @@ use Core\Security\ProviderConfiguration\Domain\Model\ContactGroupRelation;
 use Core\Security\ProviderConfiguration\Domain\Model\GroupsMapping;
 use Core\Security\ProviderConfiguration\Domain\OpenId\Model\CustomConfiguration;
 
+/**
+ * @phpstan-import-type _EndpointArray from \Core\Security\ProviderConfiguration\Domain\Model\Endpoint
+ */
 class DbWriteOpenIdConfigurationRepository extends AbstractRepositoryDRB implements WriteRepositoryInterface
 {
     use LoggerTrait;
@@ -52,39 +55,61 @@ class DbWriteOpenIdConfigurationRepository extends AbstractRepositoryDRB impleme
      */
     public function updateConfiguration(Configuration $configuration): void
     {
-        $this->info('Updating OpenID Provider in DBMS');
-        $statement = $this->db->prepare(
-            $this->translateDbName(
-                "UPDATE `:db`.`provider_configuration` SET
-                `custom_configuration` = :customConfiguration, `is_active` = :isActive, `is_forced` = :isForced
-                WHERE `name`='openid'"
-            )
-        );
+        $isAlreadyInTransaction = $this->db->inTransaction();
 
-        $statement->bindValue(
-            ':customConfiguration',
-            json_encode($this->buildCustomConfigurationFromOpenIdConfiguration($configuration))
-        );
+        try {
+            if (! $isAlreadyInTransaction) {
+                $this->db->beginTransaction();
+                $this->debug('Start transaction');
+            }
 
-        $statement->bindValue(':isActive', $configuration->isActive() ? '1' : '0');
-        $statement->bindValue(':isForced', $configuration->isForced() ? '1' : '0');
-        $statement->execute();
+            $this->info('Updating OpenID Provider in DBMS');
+            $statement = $this->db->prepare(
+                $this->translateDbName(
+                    "UPDATE `:db`.`provider_configuration` SET
+                    `custom_configuration` = :customConfiguration, `is_active` = :isActive, `is_forced` = :isForced
+                    WHERE `name`='openid'"
+                )
+            );
 
-        /** @var CustomConfiguration $customConfiguration */
-        $customConfiguration = $configuration->getCustomConfiguration();
-        $authorizationRules = $customConfiguration->getACLConditions()->getRelations();
+            $statement->bindValue(
+                ':customConfiguration',
+                json_encode($this->buildCustomConfigurationFromOpenIdConfiguration($configuration))
+            );
 
-        $this->info('Removing existing authorization rules');
-        $this->deleteAuthorizationRules();
-        $this->info('Inserting new authorization rules');
-        $this->insertAuthorizationRules($authorizationRules);
+            $statement->bindValue(':isActive', $configuration->isActive() ? '1' : '0');
+            $statement->bindValue(':isForced', $configuration->isForced() ? '1' : '0');
+            $statement->execute();
 
-        $contactGroupRelations = $customConfiguration->getGroupsMapping()->getContactGroupRelations();
+            /** @var CustomConfiguration $customConfiguration */
+            $customConfiguration = $configuration->getCustomConfiguration();
+            $authorizationRules = $customConfiguration->getACLConditions()->getRelations();
 
-        $this->info('Removing existing group mappings');
-        $this->deleteContactGroupRelations();
-        $this->info('Inserting new group mappings');
-        $this->insertContactGroupRelations($contactGroupRelations);
+            $this->info('Removing existing authorization rules');
+            $this->deleteAuthorizationRules();
+            $this->info('Inserting new authorization rules');
+            $this->insertAuthorizationRules($authorizationRules);
+
+            $contactGroupRelations = $customConfiguration->getGroupsMapping()->getContactGroupRelations();
+
+            $this->info('Removing existing group mappings');
+            $this->deleteContactGroupRelations();
+            $this->info('Inserting new group mappings');
+            $this->insertContactGroupRelations($contactGroupRelations);
+
+            if (! $isAlreadyInTransaction) {
+                $this->db->commit();
+                $this->debug('Commit transaction');
+            }
+        } catch (\Throwable $ex) {
+            $this->debug('update openId configuration error');
+            if (! $isAlreadyInTransaction) {
+                $this->debug('Roll back transaction');
+                $this->db->rollBack();
+
+                throw $ex;
+            }
+        }
     }
 
     /**
@@ -94,6 +119,7 @@ class DbWriteOpenIdConfigurationRepository extends AbstractRepositoryDRB impleme
     {
         $statement = $this->db->query("SELECT id FROM provider_configuration WHERE name='openid'");
         if ($statement !== false && ($result = $statement->fetch(\PDO::FETCH_ASSOC)) !== false) {
+            /** @var array{id:int} $result */
             $providerConfigurationId = (int) $result['id'];
             $deleteStatement = $this->db->prepare(
                 'DELETE FROM security_provider_access_group_relation
@@ -111,6 +137,7 @@ class DbWriteOpenIdConfigurationRepository extends AbstractRepositoryDRB impleme
     {
         $statement = $this->db->query("SELECT id FROM provider_configuration WHERE name='openid'");
         if ($statement !== false && ($result = $statement->fetch(\PDO::FETCH_ASSOC)) !== false) {
+            /** @var array{id:int} $result */
             $providerConfigurationId = (int) $result['id'];
             $insertStatement = $this->db->prepare(
                 'INSERT INTO security_provider_access_group_relation
@@ -188,6 +215,7 @@ class DbWriteOpenIdConfigurationRepository extends AbstractRepositoryDRB impleme
     {
         $statement = $this->db->query("SELECT id FROM provider_configuration WHERE name='openid'");
         if ($statement !== false && ($result = $statement->fetch(\PDO::FETCH_ASSOC)) !== false) {
+            /** @var array{id:int} $result */
             $providerConfigurationId = (int) $result['id'];
             $deleteStatement = $this->db->prepare(
                 'DELETE FROM security_provider_contact_group_relation
@@ -207,6 +235,7 @@ class DbWriteOpenIdConfigurationRepository extends AbstractRepositoryDRB impleme
     {
         $statement = $this->db->query("SELECT id FROM provider_configuration WHERE name='openid'");
         if ($statement !== false && ($result = $statement->fetch(\PDO::FETCH_ASSOC)) !== false) {
+            /** @var array{id:int} $result */
             $providerConfigurationId = (int) $result['id'];
             $insertStatement = $this->db->prepare(
                 'INSERT INTO security_provider_contact_group_relation
@@ -233,14 +262,21 @@ class DbWriteOpenIdConfigurationRepository extends AbstractRepositoryDRB impleme
     /**
      * @param AuthenticationConditions $authenticationConditions
      *
-     * @return array<string,array<string|null>|bool|string>
+     * @return array{
+     *     is_enabled: bool,
+     *     attribute_path: string,
+     *     endpoint: _EndpointArray|null,
+     *     authorized_values: array<string>,
+     *     trusted_client_addresses: array<string>,
+     *     blacklist_client_addresses: array<string>,
+     * }
      */
     private function authenticationConditionsToArray(AuthenticationConditions $authenticationConditions): array
     {
         return [
             'is_enabled' => $authenticationConditions->isEnabled(),
             'attribute_path' => $authenticationConditions->getAttributePath(),
-            'endpoint' => $authenticationConditions->getEndpoint()->toArray(),
+            'endpoint' => $authenticationConditions->getEndpoint()?->toArray(),
             'authorized_values' => $authenticationConditions->getAuthorizedValues(),
             'trusted_client_addresses' => $authenticationConditions->getTrustedClientAddresses(),
             'blacklist_client_addresses' => $authenticationConditions->getBlacklistClientAddresses(),
@@ -250,21 +286,30 @@ class DbWriteOpenIdConfigurationRepository extends AbstractRepositoryDRB impleme
     /**
      * @param GroupsMapping $groupsMapping
      *
-     * @return array<string,bool|string|array<string,string|null>>
+     * @return array{
+     *     is_enabled: bool,
+     *     attribute_path: string,
+     *     endpoint: _EndpointArray|null,
+     * }
      */
     private function groupsMappingToArray(GroupsMapping $groupsMapping): array
     {
         return [
             'is_enabled' => $groupsMapping->isEnabled(),
             'attribute_path' => $groupsMapping->getAttributePath(),
-            'endpoint' => $groupsMapping->getEndpoint()->toArray(),
+            'endpoint' => $groupsMapping->getEndpoint()?->toArray(),
         ];
     }
 
     /**
      * @param ACLConditions $aclConditions
      *
-     * @return array<string,bool|string|array<string,string|null>>
+     * @return array{
+     *     is_enabled: bool,
+     *     apply_only_first_role: bool,
+     *     attribute_path: string,
+     *     endpoint: _EndpointArray|null,
+     * }
      */
     private function aclConditionsToArray(ACLConditions $aclConditions): array
     {
@@ -272,7 +317,7 @@ class DbWriteOpenIdConfigurationRepository extends AbstractRepositoryDRB impleme
             'is_enabled' => $aclConditions->isEnabled(),
             'apply_only_first_role' => $aclConditions->onlyFirstRoleIsApplied(),
             'attribute_path' => $aclConditions->getAttributePath(),
-            'endpoint' => $aclConditions->getEndpoint()->toArray(),
+            'endpoint' => $aclConditions->getEndpoint()?->toArray(),
         ];
     }
 }
