@@ -25,6 +25,7 @@ namespace Core\Service\Infrastructure\Repository;
 
 use Assert\AssertionFailedException;
 use Centreon\Domain\Log\LoggerTrait;
+use Centreon\Domain\Repository\RepositoryException;
 use Centreon\Domain\RequestParameters\Interfaces\RequestParametersInterface;
 use Centreon\Infrastructure\DatabaseConnection;
 use Centreon\Infrastructure\RequestParameters\SqlRequestParametersTranslator;
@@ -109,6 +110,47 @@ class DbReadServiceRepository extends AbstractRepositoryRDB implements ReadServi
         $this->db = $db;
     }
 
+    /**
+     * @inheritDoc
+     */
+    public function exist(array $serviceIds): array
+    {
+        $this->debug('Check existence of services', ['service_ids' => $serviceIds]);
+
+        if ([] === $serviceIds) {
+            return [];
+        }
+
+        $bindValues = [];
+
+        foreach ($serviceIds as $index => $serviceId) {
+            $bindValues[":service_{$index}"] = $serviceId;
+        }
+
+        $serviceIdsList = implode(', ', array_keys($bindValues));
+
+        $request = $this->translateDbName(
+            <<<SQL
+                    SELECT
+                        service_id
+                    FROM `:db`.service
+                    WHERE service_id IN ({$serviceIdsList})
+                        AND service_register = '1'
+                SQL
+        );
+
+        $statement = $this->db->prepare($request);
+
+        foreach ($bindValues as $bindKey => $bindValue) {
+            $statement->bindValue($bindKey, $bindValue, \PDO::PARAM_INT);
+        }
+
+        $statement->setFetchMode(\PDO::FETCH_ASSOC);
+        $statement->execute();
+
+        return $statement->fetchAll(\PDO::FETCH_COLUMN);
+    }
+
     /**
      * @inheritDoc
      */
@@ -316,7 +358,14 @@ class DbReadServiceRepository extends AbstractRepositoryRDB implements ReadServi
                     AND host.host_register = '1'
                 WHERE service.service_id = :id
                     AND service.service_register = '1'
-                GROUP BY service.service_id
+                GROUP BY
+                    service.service_id,
+                    esi.esi_action_url,
+                    esi.esi_icon_image,
+                    esi.esi_icon_image_alt,
+                    esi.esi_notes,
+                    esi.esi_notes_url,
+                    esi.graph_id
             SQL;
         $statement = $this->db->prepare($this->translateDbName($request));
         $statement->bindValue(':id', $serviceId, \PDO::PARAM_INT);
@@ -330,6 +379,50 @@ class DbReadServiceRepository extends AbstractRepositoryRDB implements ReadServi
         return null;
     }
 
+    /**
+     * @inheritDoc
+     */
+    public function findByIds(int ...$serviceIds): array
+    {
+        [$bindValues, $serviceIdsQuery] = $this->createMultipleBindQuery($serviceIds, ':id_');
+        $request = <<<SQL
+            SELECT service_id,
+                   service_description,
+                   host.host_name
+            FROM `:db`.service
+            LEFT JOIN `:db`.host_service_relation hsr
+                ON hsr.service_service_id = service.service_id
+            LEFT JOIN `:db`.host
+                ON host.host_id = hsr.host_host_id
+                AND host.host_register = '1'
+            WHERE service.service_id IN ({$serviceIdsQuery})
+                AND service.service_register = '1'
+            ORDER BY service.service_id
+            SQL;
+        $statement = $this->db->prepare($this->translateDbName($request));
+        foreach ($bindValues as $bindKey => $serviceId) {
+            $statement->bindValue($bindKey, $serviceId, \PDO::PARAM_INT);
+        }
+        $statement->setFetchMode(\PDO::FETCH_ASSOC);
+        $statement->execute();
+
+        $services = [];
+        foreach ($statement as $result) {
+            /** @var array{service_id: int, service_description: string, host_name: string} $result */
+            $services[] = TinyServiceFactory::createFromDb($result);
+        }
+
+        return $services;
+    }
+
+    /**
+     * @inheritDoc
+     */
+    public function findAll(): \Traversable&\Countable
+    {
+        throw RepositoryException::notYetImplemented();
+    }
+
     /**
      * @inheritDoc
      */
@@ -426,6 +519,8 @@ class DbReadServiceRepository extends AbstractRepositoryRDB implements ReadServi
     {
         $categoryAcls = '';
         $groupAcls = '';
+        $hostGroupAcls = '';
+        $hostCategoryAcls = '';
         if ($accessGroupIds !== []) {
             if ($this->hasRestrictedAccessToServiceCategories($accessGroupIds)) {
                 $categoryAcls = <<<'SQL'
@@ -442,6 +537,21 @@ class DbReadServiceRepository extends AbstractRepositoryRDB implements ReadServi
                     )
                     SQL;
             }
+            if ($this->hasRestrictedAccessToHostCategories($accessGroupIds)) {
+                $hostCategoryAcls = <<<'SQL'
+                    AND hcr.hostcategories_hc_id IN (
+                        SELECT arhcr.hc_id
+                        FROM acl_resources_hc_relations arhcr
+                        INNER JOIN `:db`.acl_resources res
+                            ON arhcr.acl_res_id = res.acl_res_id
+                        INNER JOIN `:db`.acl_res_group_relations argr
+                            ON res.acl_res_id = argr.acl_res_id
+                        INNER JOIN `:db`.acl_groups ag
+                            ON argr.acl_group_id = ag.acl_group_id
+                        WHERE ag.acl_group_id IN (:access_group_ids)
+                    )
+                    SQL;
+            }
             if (! $this->hasAccessToAllServiceGroups($accessGroupIds)) {
                 $groupAcls = <<<'SQL'
                     AND sgr.servicegroup_sg_id in (
@@ -457,6 +567,21 @@ class DbReadServiceRepository extends AbstractRepositoryRDB implements ReadServi
                     )
                     SQL;
             }
+            if (! $this->hasAccessToAllHostGroups($accessGroupIds)) {
+                $hostGroupAcls = <<<'SQL'
+                    AND hgr.hostgroup_hg_id IN (
+                        SELECT arhgr.hg_hg_id
+                        FROM `:db`.acl_resources_hg_relations arhgr
+                        INNER JOIN `:db`.acl_resources res
+                            ON arhgr.acl_res_id = res.acl_res_id
+                        INNER JOIN `:db`.acl_res_group_relations argr
+                            ON res.acl_res_id = argr.acl_res_id
+                        INNER JOIN `:db`.acl_groups ag
+                            ON argr.acl_group_id = ag.acl_group_id
+                        WHERE ag.acl_group_id IN (:access_group_ids)
+                    )
+                    SQL;
+            }
         }
 
         $concatenator = new SqlConcatenator();
@@ -477,7 +602,7 @@ class DbReadServiceRepository extends AbstractRepositoryRDB implements ReadServi
                     GROUP_CONCAT(DISTINCT severity.sc_name) as severity_name,
                     GROUP_CONCAT(DISTINCT category.sc_id) as category_ids,
                     GROUP_CONCAT(DISTINCT hsr.host_host_id) AS host_ids,
-                    GROUP_CONCAT(DISTINCT CONCAT(sgr.servicegroup_sg_id, '-', sgr.host_host_id)) as groups
+                    GROUP_CONCAT(DISTINCT CONCAT(sgr.servicegroup_sg_id, '-', sgr.host_host_id)) as sg_host_concat
                 FROM `:db`.service
                 SQL
         );
@@ -511,6 +636,17 @@ class DbReadServiceRepository extends AbstractRepositoryRDB implements ReadServi
                     LEFT JOIN `:db`.host
                         ON host.host_id = hsr.host_host_id
                         AND host.host_register = '1'
+                    LEFT JOIN `:db`.hostgroup_relation hgr
+                        ON hgr.host_host_id = host.host_id
+                        {$hostGroupAcls}
+                    LEFT JOIN `:db`.hostgroup
+                        ON hostgroup.hg_id = hgr.hostgroup_hg_id
+                    LEFT JOIN `:db`.hostcategories_relation hcr
+                        ON hcr.host_host_id = host.host_id
+                        {$hostCategoryAcls}
+                    LEFT JOIN `:db`.hostcategories
+                        ON hostcategories.hc_id = hcr.hostcategories_hc_id
+                        AND hostcategories.level IS NULL
                     SQL
             )
             ->appendWhere(
@@ -549,6 +685,10 @@ class DbReadServiceRepository extends AbstractRepositoryRDB implements ReadServi
             'severity.name' => 'severity.sc_name',
             'group.id' => 'servicegroup.sg_id',
             'group.name' => 'servicegroup.sg_name',
+            'hostgroup.id' => 'hostgroup.hg_id',
+            'hostgroup.name' => 'hostgroup.hg_name',
+            'hostcategory.id' => 'hostcategories.hc_id',
+            'hostcategory.name' => 'hostcategories.hc_name',
         ]);
         $sqlTranslator->addNormalizer('is_activated', new BoolToEnumNormalizer());
         $sqlTranslator->translateForConcatenator($concatenator);
@@ -570,7 +710,7 @@ class DbReadServiceRepository extends AbstractRepositoryRDB implements ReadServi
                 categoryIds: $result['category_ids']
                     ? array_map('intval', explode(',', $result['category_ids']))
                     : [],
-                groups: $result['groups']
+                groups: $result['sg_host_concat']
                     ? array_map(
                         static function (string $sgRel) use ($result): ServiceGroupRelation {
                             [$sgId, $hostId] = explode('-', $sgRel);
@@ -581,7 +721,7 @@ class DbReadServiceRepository extends AbstractRepositoryRDB implements ReadServi
                                 hostId: (int) $hostId
                             );
                         },
-                        explode(',', $result['groups'])
+                        explode(',', $result['sg_host_concat'])
                     )
                     : [],
                 serviceTemplate: $result['service_template_id'] !== null
@@ -658,6 +798,44 @@ class DbReadServiceRepository extends AbstractRepositoryRDB implements ReadServi
         return (bool) $statement->fetchColumn();
     }
 
+    /**
+     * Determine if host categories are filtered for given access group ids
+     * true: accessible host categories are filtered (only specified are accessible)
+     * false: accessible host categories are not filtered (all are accessible).
+     *
+     * @param int[] $accessGroupIds
+     *
+     * @phpstan-param non-empty-array<int> $accessGroupIds
+     *
+     * @return bool
+     */
+    private function hasRestrictedAccessToHostCategories(array $accessGroupIds): bool
+    {
+        $concatenator = new SqlConcatenator();
+        $concatenator->defineSelect(
+            <<<'SQL'
+                SELECT 1
+                FROM `:db`.acl_resources_hc_relations arhcr
+                INNER JOIN `:db`.acl_resources res
+                    ON arhcr.acl_res_id = res.acl_res_id
+                INNER JOIN `:db`.acl_res_group_relations argr
+                    ON res.acl_res_id = argr.acl_res_id
+                INNER JOIN `:db`.acl_groups ag
+                    ON argr.acl_group_id = ag.acl_group_id
+                SQL
+        );
+
+        $concatenator->storeBindValueMultiple(':access_group_ids', $accessGroupIds, \PDO::PARAM_INT)
+            ->appendWhere('ag.acl_group_id IN (:access_group_ids)');
+
+        $statement = $this->db->prepare($this->translateDbName($concatenator->__toString()));
+
+        $concatenator->bindValuesToStatement($statement);
+        $statement->execute();
+
+        return (bool) $statement->fetchColumn();
+    }
+
     /**
      * Determine if accessGroups give access to all serviceGroups
      * true: all service groups are accessible
@@ -701,66 +879,6 @@ class DbReadServiceRepository extends AbstractRepositoryRDB implements ReadServi
         return false;
     }
 
-    /**
-     * @param int[] $accessGroupIds
-     *
-     * @return SqlConcatenator
-     */
-    private function getServiceRequestConcatenator(array $accessGroupIds = []): SqlConcatenator
-    {
-        $concatenator = (new SqlConcatenator())
-            ->defineFrom(
-                <<<'SQL'
-                    FROM
-                        `:db`.`service` s
-                    SQL
-            );
-
-        if ([] !== $accessGroupIds) {
-            $concatenator->appendJoins(
-                <<<'SQL'
-                    JOIN `:dbstg`.centreon_acl acl
-                        ON s.service_id = acl.service_id
-                    SQL
-            );
-            $concatenator->appendWhere(
-                <<<'SQL'
-                    WHERE acl.group_id IN (:access_group_ids)
-                    SQL
-            );
-            $concatenator->storeBindValueMultiple(':access_group_ids', $accessGroupIds, \PDO::PARAM_INT);
-        }
-
-        return $concatenator;
-    }
-
-    /**
-     * @param SqlConcatenator $concatenator
-     * @param int $serviceId
-     *
-     * @throws \PDOException
-     *
-     * @return bool
-     */
-    private function existsService(SqlConcatenator $concatenator, int $serviceId): bool
-    {
-        $concatenator->defineSelect(
-                <<<'SQL'
-                    SELECT 1
-                    SQL
-            )->appendWhere(
-                <<<'SQL'
-                    WHERE s.service_id = :service_id
-                    AND s.service_register = '1'
-                    SQL
-            )->storeBindValue(':service_id', $serviceId, \PDO::PARAM_INT);
-        $statement = $this->db->prepare($this->translateDbName($concatenator->concatAll()));
-        $concatenator->bindValuesToStatement($statement);
-        $statement->execute();
-
-        return (bool) $statement->fetchColumn();
-    }
-
     /**
      * Determine if access groups give access to all host groups
      * true: all host groups are accessible
