@@ -25,6 +25,8 @@ namespace Core\ServiceSeverity\Application\Exception;
 
 class ServiceSeverityException extends \Exception
 {
+    public const CODE_CONFLICT = 1;
+
     /**
      * @return self
      */
@@ -33,6 +35,14 @@ class ServiceSeverityException extends \Exception
         return new self(_('You are not allowed to access service severities'));
     }
 
+    /**
+     * @return self
+     */
+    public static function editNotAllowed(): self
+    {
+        return new self(_('You are not allowed to edit service severities'));
+    }
+
     /**
      * @param \Throwable $ex
      *
@@ -61,6 +71,16 @@ class ServiceSeverityException extends \Exception
         return new self(_('Error while deleting service severity'), 0, $ex);
     }
 
+    /**
+     * @param \Throwable $ex
+     *
+     * @return self
+     */
+    public static function editServiceSeverity(\Throwable $ex): self
+    {
+        return new self(_('Error while editing service severity'), 0, $ex);
+    }
+
     /**
      * @param \Throwable $ex
      *
@@ -92,7 +112,7 @@ class ServiceSeverityException extends \Exception
      */
     public static function serviceNameAlreadyExists(): self
     {
-        return new self(_('Service severity name already exists'));
+        return new self(_('Service severity name already exists'), self::CODE_CONFLICT);
     }
 
     /**
@@ -102,6 +122,9 @@ class ServiceSeverityException extends \Exception
      */
     public static function iconDoesNotExist(int $iconId): self
     {
-        return new self(sprintf(_("The service severity icon with id '%d' does not exist"), $iconId));
+        return new self(
+            sprintf(_("The service severity icon with id '%d' does not exist"), $iconId),
+            self::CODE_CONFLICT
+        );
     }
 }
