@@ -23,6 +23,7 @@ declare(strict_types=1);
 
 namespace EventSubscriber;
 
+use \Symfony\Bundle\SecurityBundle\Security;
 use Centreon\Application\ApiPlatform;
 use Centreon\Domain\Contact\Contact;
 use Centreon\Domain\Contact\Interfaces\ContactInterface;
@@ -33,11 +34,9 @@ use Centreon\Domain\RequestParameters\{
     Interfaces\RequestParametersInterface, RequestParameters, RequestParametersException
 };
 use Centreon\Domain\VersionHelper;
-use Core\Common\Domain\Exception\RepositoryException;
-use Core\Common\Infrastructure\ExceptionLogger\ExceptionLogger;
 use JMS\Serializer\Exception\ValidationFailedException;
-use Psr\Log\LogLevel;
-use Symfony\Component\DependencyInjection\ContainerInterface;
+use Psr\Log\LoggerInterface;
+use Symfony\Component\DependencyInjection\Exception\InvalidArgumentException;
 use Symfony\Component\EventDispatcher\EventSubscriberInterface;
 use Symfony\Component\HttpFoundation\Response;
 use Symfony\Component\HttpKernel\Event\{
@@ -48,7 +47,7 @@ use Symfony\Component\HttpKernel\Exception\MethodNotAllowedHttpException;
 use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
 use Symfony\Component\HttpKernel\KernelEvents;
 use Symfony\Component\Security\Core\{
-    Exception\AccessDeniedException, Security, User\UserInterface
+    Exception\AccessDeniedException
 };
 
 /**
@@ -61,12 +60,6 @@ use Symfony\Component\Security\Core\{
  */
 class CentreonEventSubscriber implements EventSubscriberInterface
 {
-    /**
-     * If no version has been defined in the configuration,
-     * this version will be used by default.
-     */
-    public const DEFAULT_API_VERSION = '21.10';
-
     /**
      * If no API header name has been defined in the configuration,
      * this name will be used by default.
@@ -75,19 +68,23 @@ class CentreonEventSubscriber implements EventSubscriberInterface
 
     /**
      * @param RequestParametersInterface $requestParameters
-     * @param ContainerInterface $container
      * @param Security $security
      * @param ApiPlatform $apiPlatform
      * @param ContactInterface $contact
-     * @param ExceptionLogger $exceptionLogger
+     * @param LoggerInterface $logger
+     * @param string $apiVersionLatest
+     * @param string $apiHeaderName
+     * @param string $translationPath
      */
     public function __construct(
-        private RequestParametersInterface $requestParameters,
-        private ContainerInterface $container,
-        private Security $security,
-        private ApiPlatform $apiPlatform,
-        private ContactInterface $contact,
-        readonly private ExceptionLogger $exceptionLogger,
+        readonly private RequestParametersInterface $requestParameters,
+        readonly private Security $security,
+        readonly private ApiPlatform $apiPlatform,
+        readonly private ContactInterface $contact,
+        readonly private LoggerInterface $logger,
+        readonly private string $apiVersionLatest,
+        readonly private string $apiHeaderName,
+        readonly private string $translationPath,
     ) {
     }
 
@@ -118,20 +115,11 @@ class CentreonEventSubscriber implements EventSubscriberInterface
      *
      * @param ResponseEvent $event
      *
-     * @throws \Symfony\Component\DependencyInjection\Exception\InvalidArgumentException
+     * @throws InvalidArgumentException
      */
     public function addApiVersion(ResponseEvent $event): void
     {
-        $defaultApiVersion = self::DEFAULT_API_VERSION;
-        $defaultApiHeaderName = self::DEFAULT_API_HEADER_NAME;
-
-        if ($this->container->hasParameter('api.version.latest')) {
-            $defaultApiVersion = $this->container->getParameter('api.version.latest');
-        }
-        if ($this->container->hasParameter('api.header')) {
-            $defaultApiHeaderName = $this->container->getParameter('api.header');
-        }
-        $event->getResponse()->headers->add([$defaultApiHeaderName => $defaultApiVersion]);
+        $event->getResponse()->headers->add([$this->apiHeaderName => $this->apiVersionLatest]);
     }
 
     /**
@@ -233,16 +221,11 @@ class CentreonEventSubscriber implements EventSubscriberInterface
      *
      * @param RequestEvent $event
      *
-     * @throws \Symfony\Component\DependencyInjection\Exception\InvalidArgumentException
+     * @throws InvalidArgumentException
      */
     public function defineApiVersionInAttributes(RequestEvent $event): void
     {
-        if ($this->container->hasParameter('api.version.latest')) {
-            $latestVersion = $this->container->getParameter('api.version.latest');
-        } else {
-            $latestVersion = self::DEFAULT_API_VERSION;
-        }
-        $event->getRequest()->attributes->set('version.latest', $latestVersion);
+        $event->getRequest()->attributes->set('version.latest', $this->apiVersionLatest);
         $event->getRequest()->attributes->set('version.is_latest', false);
 
         $event->getRequest()->attributes->set('version.is_beta', false);
@@ -261,10 +244,10 @@ class CentreonEventSubscriber implements EventSubscriberInterface
 
             if (
                 $requestApiVersion === 'latest'
-                || VersionHelper::compare($requestApiVersion, $latestVersion, VersionHelper::EQUAL)
+                || VersionHelper::compare($requestApiVersion, $this->apiVersionLatest, VersionHelper::EQUAL)
             ) {
                 $event->getRequest()->attributes->set('version.is_latest', true);
-                $requestApiVersion = $latestVersion;
+                $requestApiVersion = $this->apiVersionLatest;
             }
             if ($requestApiVersion === 'beta') {
                 $event->getRequest()->attributes->set('version.is_beta', true);
@@ -332,6 +315,7 @@ class CentreonEventSubscriber implements EventSubscriberInterface
                 $statusCode = $event->getThrowable()->getCode()
                     ?: Response::HTTP_INTERNAL_SERVER_ERROR;
             }
+            $this->logException($event->getThrowable());
             // Manage exception outside controllers
             $event->setResponse(
                 new Response(
@@ -364,10 +348,7 @@ class CentreonEventSubscriber implements EventSubscriberInterface
                         true
                     ),
                 ]);
-            } elseif (
-                $event->getThrowable() instanceof \PDOException
-                || $event->getThrowable() instanceof RepositoryException
-            ) {
+            } elseif ($event->getThrowable() instanceof \PDOException) {
                 $errorMessage = json_encode([
                     'code' => $errorCode,
                     'message' => 'An error has occurred in a repository',
@@ -389,11 +370,11 @@ class CentreonEventSubscriber implements EventSubscriberInterface
                     'message' => $event->getThrowable()->getMessage(),
                 ]);
             }
+            $this->logException($event->getThrowable());
             $event->setResponse(
                 new Response($errorMessage, $httpCode)
             );
         }
-        $this->logException($event->getThrowable());
     }
 
     /**
@@ -422,15 +403,10 @@ class CentreonEventSubscriber implements EventSubscriberInterface
     private function logException(\Throwable $exception): void
     {
         if (! $exception instanceof HttpExceptionInterface || $exception->getCode() >= 500) {
-            $level = LogLevel::CRITICAL;
+            $this->logger->critical($exception->getMessage(), ['context' => $exception]);
         } else {
-            $level = LogLevel::ERROR;
+            $this->logger->error($exception->getMessage(), ['context' => $exception]);
         }
-        $this->exceptionLogger->log(
-            throwable: $exception,
-            context: ['internal_error' => $exception],
-            level: $level
-        );
     }
 
     /**
@@ -445,7 +421,7 @@ class CentreonEventSubscriber implements EventSubscriberInterface
 
         putenv('LANG=' . $lang);
         setlocale(LC_ALL, $lang);
-        bindtextdomain('messages', $this->container->getParameter('translation_path'));
+        bindtextdomain('messages', $this->translationPath);
         bind_textdomain_codeset('messages', Contact::DEFAULT_CHARSET);
         textdomain('messages');
     }
@@ -470,6 +446,9 @@ class CentreonEventSubscriber implements EventSubscriberInterface
      */
     private function initGlobalContact(ContactInterface $user): void
     {
+        if (! $this->contact instanceof Contact) {
+            return;
+        }
         $this->contact->setId($user->getId())
             ->setName($user->getName())
             ->setAlias($user->getAlias())
