@@ -1,5 +1,7 @@
 import { Given, Then, When } from '@badeball/cypress-cucumber-preprocessor';
 
+import { CopyToContainerContentType } from '@centreon/js-config/cypress/e2e/commands';
+
 import { checkIfConfigurationIsExported, insertFixture } from '../../commons';
 
 const dateBeforeLogin = new Date();
@@ -33,58 +35,52 @@ const getCentreonStableMinorVersions = (
   if (Cypress.env('WEB_IMAGE_OS').includes('alma')) {
     commandResult = cy
       .execInContainer({
-        command: `bash -e <<EOF
-          dnf config-manager --set-disabled 'centreon-*-unstable*' 'centreon-*-testing*' 'mariadb*'
-EOF`,
-        name: Cypress.env('dockerName')
+        command: `dnf config-manager --set-disabled 'centreon-*-unstable*' 'centreon-*-testing*' 'mariadb*'`,
+        name: 'web'
       })
-      .exec(
-        `docker exec -i ${Cypress.env(
-          'dockerName'
-        )} sh -c "dnf --showduplicates list centreon-web | grep centreon-web | grep '${majorVersion}' | awk '{ print \\$2 }' | tr '\n' ' '"`
-      );
+      .execInContainer({
+        command: `dnf --showduplicates list centreon-web | grep centreon-web | grep '${majorVersion}' | awk '{ print $2 }' | tr '\n' ' '`,
+        name: 'web'
+      });
   } else {
     commandResult = cy
       .execInContainer({
-        command: `bash -e <<EOF
-          mv /etc/apt/sources.list.d/centreon-unstable.list /etc/apt/sources.list.d/centreon-unstable.list.bak
-          mv /etc/apt/sources.list.d/centreon-testing.list /etc/apt/sources.list.d/centreon-testing.list.bak
-          apt-get update
-EOF`,
-        name: Cypress.env('dockerName')
+        command: [
+          `mv /etc/apt/sources.list.d/centreon-unstable.list /etc/apt/sources.list.d/centreon-unstable.list.bak`,
+          `mv /etc/apt/sources.list.d/centreon-testing.list /etc/apt/sources.list.d/centreon-testing.list.bak`,
+          `apt-get update`
+        ],
+        name: 'web'
       })
-      .exec(
-        `docker exec -i ${Cypress.env(
-          'dockerName'
-        )} sh -c "apt list -a centreon-web | grep '${majorVersion}' | awk '{ print \\$2 }'"`
-      );
+      .execInContainer({
+        command: `apt list -a centreon-web | grep '${majorVersion}' | awk '{ print $2 }'`,
+        name: 'web'
+      });
   }
 
-  return commandResult.then(({ stdout }): Cypress.Chainable<Array<number>> => {
+  return commandResult.then(({ output }): Cypress.Chainable<Array<number>> => {
     const stableVersions: Array<number> = [];
 
     const versionsRegex = /\d+\.\d+\.(\d+)/g;
 
-    [...stdout.matchAll(versionsRegex)].forEach((result) => {
-      cy.log(`available version found : ${majorVersion}.${result[1]}`);
+    [...output.matchAll(versionsRegex)].forEach((result) => {
+      cy.log(`available version found: ${majorVersion}.${result[1]}`);
       stableVersions.push(Number(result[1]));
     });
 
     if (Cypress.env('WEB_IMAGE_OS').includes('alma')) {
       cy.execInContainer({
-        command: `bash -e <<EOF
-            dnf config-manager --set-enabled 'centreon-*'
-EOF`,
-        name: Cypress.env('dockerName')
+        command: "dnf config-manager --set-enabled 'centreon-*'",
+        name: 'web'
       });
     } else {
       cy.execInContainer({
-        command: `bash -e <<EOF
-            mv /etc/apt/sources.list.d/centreon-unstable.list.bak /etc/apt/sources.list.d/centreon-unstable.list
-            mv /etc/apt/sources.list.d/centreon-testing.list.bak /etc/apt/sources.list.d/centreon-testing.list
-            apt-get update
-EOF`,
-        name: Cypress.env('dockerName')
+        command: [
+          `mv /etc/apt/sources.list.d/centreon-unstable.list.bak /etc/apt/sources.list.d/centreon-unstable.list`,
+          `mv /etc/apt/sources.list.d/centreon-testing.list.bak /etc/apt/sources.list.d/centreon-testing.list`,
+          `apt-get update`
+        ],
+        name: 'web'
       });
     }
     const lastStableMinorVersion = [...new Set(stableVersions)]
@@ -102,45 +98,41 @@ const installCentreon = (version: string): Cypress.Chainable => {
 
   if (Cypress.env('WEB_IMAGE_OS').includes('alma')) {
     cy.execInContainer({
-      command: `bash -e <<EOF
-        dnf config-manager --set-disabled 'centreon-*-unstable*' 'centreon-*-testing*' 'mariadb*'
-        dnf install -y centreon-web-${version}
-        dnf install -y centreon-broker-cbd
-        echo 'date.timezone = Europe/Paris' > /etc/php.d/centreon.ini
-        /etc/init.d/mysql start
-        mkdir -p /run/php-fpm
-        systemctl start php-fpm
-        systemctl start httpd
-        mysql -e "GRANT ALL ON *.* to 'root'@'localhost' IDENTIFIED BY 'centreon' WITH GRANT OPTION"
-        dnf config-manager --set-enabled 'centreon-*'
-EOF`,
-      name: Cypress.env('dockerName')
+      command: [
+        `dnf config-manager --set-disabled 'centreon-*-unstable*' 'centreon-*-testing*' 'mariadb*'`,
+        `dnf install -y centreon-web-${version}`,
+        `dnf install -y centreon-broker-cbd`,
+        `echo 'date.timezone = Europe/Paris' > /etc/php.d/centreon.ini`,
+        `/etc/init.d/mysql start`,
+        `mkdir -p /run/php-fpm`,
+        `systemctl start php-fpm || systemctl restart php-fpm`,
+        `systemctl start httpd || systemctl restart httpd`,
+        `mysql -e "GRANT ALL ON *.* to 'root'@'localhost' IDENTIFIED BY 'centreon' WITH GRANT OPTION"`,
+        `dnf config-manager --set-enabled 'centreon-*'`
+      ],
+      name: 'web'
     });
   } else {
     cy.execInContainer({
-      command: `bash -e <<EOF
-        mv /etc/apt/sources.list.d/centreon-unstable.list /etc/apt/sources.list.d/centreon-unstable.list.bak
-        mv /etc/apt/sources.list.d/centreon-testing.list /etc/apt/sources.list.d/centreon-testing.list.bak
-        apt-get update
-        apt-get install -y \\
-          centreon-poller=${version}-${Cypress.env('WEB_IMAGE_OS')} \\
-          centreon-web-apache=${version}-${Cypress.env('WEB_IMAGE_OS')} \\
-          centreon-web=${version}-${Cypress.env('WEB_IMAGE_OS')} \\
-          centreon-common=${version}-${Cypress.env('WEB_IMAGE_OS')}
-        mkdir -p /usr/lib/centreon-connector
-        echo "date.timezone = Europe/Paris" >> /etc/php/8.1/mods-available/centreon.ini
-        sed -i 's#^datadir_set=#datadir_set=1#' /etc/init.d/mysql
-        service mysql start
-        mkdir -p /run/php
-        systemctl start php8.1-fpm
-        systemctl start apache2
-        mysql -e "GRANT ALL ON *.* to 'root'@'localhost' IDENTIFIED BY 'centreon' WITH GRANT OPTION"
-        mv /etc/apt/sources.list.d/centreon-unstable.list.bak /etc/apt/sources.list.d/centreon-unstable.list
-        mv /etc/apt/sources.list.d/centreon-testing.list.bak /etc/apt/sources.list.d/centreon-testing.list
-        apt-get update
-        usermod -a -G centreon-broker www-data # temporary fix (MON-20769)
-EOF`,
-      name: Cypress.env('dockerName')
+      command: [
+        `mv /etc/apt/sources.list.d/centreon-unstable.list /etc/apt/sources.list.d/centreon-unstable.list.bak`,
+        `mv /etc/apt/sources.list.d/centreon-testing.list /etc/apt/sources.list.d/centreon-testing.list.bak`,
+        `apt-get update`,
+        `apt-get install -y centreon-poller=${version}-${Cypress.env('WEB_IMAGE_OS')} centreon-web-apache=${version}-${Cypress.env('WEB_IMAGE_OS')} centreon-web=${version}-${Cypress.env('WEB_IMAGE_OS')} centreon-common=${version}-${Cypress.env('WEB_IMAGE_OS')}`,
+        `mkdir -p /usr/lib/centreon-connector`,
+        `echo "date.timezone = Europe/Paris" >> /etc/php/8.1/mods-available/centreon.ini`,
+        `sed -i 's#^datadir_set=#datadir_set=1#' /etc/init.d/mysql`,
+        `service mysql start`,
+        `mkdir -p /run/php`,
+        `systemctl start php8.1-fpm`,
+        `systemctl start apache2`,
+        `mysql -e "GRANT ALL ON *.* to 'root'@'localhost' IDENTIFIED BY 'centreon' WITH GRANT OPTION"`,
+        `mv /etc/apt/sources.list.d/centreon-unstable.list.bak /etc/apt/sources.list.d/centreon-unstable.list`,
+        `mv /etc/apt/sources.list.d/centreon-testing.list.bak /etc/apt/sources.list.d/centreon-testing.list`,
+        `apt-get update`,
+        `usermod -a -G centreon-broker www-data` // temporary fix (MON-20769)
+      ],
+      name: 'web'
     });
   }
 
@@ -221,12 +213,12 @@ EOF`,
     .setUserTokenApiV1()
     .applyPollerConfiguration()
     .execInContainer({
-      command: `bash -e <<EOF
-        systemctl restart cbd
-        systemctl restart centengine
-        systemctl restart gorgoned
-EOF`,
-      name: Cypress.env('dockerName')
+      command: [
+        `systemctl restart cbd`,
+        `systemctl restart centengine`,
+        `systemctl restart gorgoned`
+      ],
+      name: 'web'
     });
 };
 
@@ -234,54 +226,57 @@ const updatePlatformPackages = (): Cypress.Chainable => {
   return cy
     .copyToContainer({
       destination: '/tmp/packages-update-centreon',
-      source: './fixtures/packages'
+      source: './fixtures/packages',
+      type: CopyToContainerContentType.Directory
     })
     .getWebVersion()
     .then(({ major_version }) => {
       if (Cypress.env('WEB_IMAGE_OS').includes('alma')) {
         return cy.execInContainer({
-          command: `bash -e <<EOF
-          rm -f /tmp/packages-update-centreon/centreon-${major_version}*.rpm /tmp/packages-update-centreon/centreon-central-${major_version}*.rpm
-          dnf install -y /tmp/packages-update-centreon/*.rpm
-EOF`,
-          name: Cypress.env('dockerName')
+          command: [
+            `rm -f /tmp/packages-update-centreon/centreon{,-central,-mariadb,-mysql}-${major_version}*.rpm`,
+            'dnf install -y /tmp/packages-update-centreon/*.rpm'
+          ],
+          name: 'web'
         });
       }
 
       return cy.execInContainer({
-        command: `bash -e <<EOF
-        rm -f /tmp/packages-update-centreon/centreon_${major_version}*.deb /tmp/packages-update-centreon/centreon-central_${major_version}*.deb
-        apt-get update
-        apt-get install -y /tmp/packages-update-centreon/centreon-*.deb
-EOF`,
-        name: Cypress.env('dockerName')
+        command: [
+          `rm -f /tmp/packages-update-centreon/centreon{,-central,-mariadb,-mysql}_${major_version}*.deb`,
+          'apt-get update',
+          'apt-get install -y /tmp/packages-update-centreon/centreon-*.deb'
+        ],
+        name: 'web'
       });
     })
     .execInContainer({
-      command: `bash -e <<EOF
-        systemctl restart cbd
-        systemctl restart centengine
-        systemctl restart gorgoned
-EOF`,
-      name: Cypress.env('dockerName')
+      command: [
+        'systemctl restart cbd',
+        'systemctl restart centengine',
+        'systemctl restart gorgoned'
+      ],
+      name: 'web'
     });
 };
 
 const checkPlatformVersion = (platformVersion: string): Cypress.Chainable => {
   const command = Cypress.env('WEB_IMAGE_OS').includes('alma')
-    ? `rpm -qa | grep centreon-web | cut -d '-' -f3`
-    : `apt list --installed centreon-web | awk '{ print \\$2 }' | cut -d '-' -f1`;
+    ? `rpm -qa | grep centreon-web | cut -d '-' -f3 | tr -d '\n'`
+    : `apt list --installed centreon-web | awk '{ print $2 }' | cut -d '-' -f1 | tr -d '\n'`;
 
   return cy
-    .exec(`docker exec -i ${Cypress.env('dockerName')} sh -c "${command}"`)
-    .then(({ stdout }): Cypress.Chainable<null> | null => {
-      const isExpected = platformVersion === stdout;
+    .execInContainer({
+      command,
+      name: 'web'
+    })
+    .then(({ output }): Cypress.Chainable<null> | null => {
+      const isExpected = platformVersion === output;
       if (isExpected) {
         return null;
       }
-
       throw new Error(
-        `The platform version is not the correct one (expected: ${platformVersion}, actual: ${stdout}).`
+        `The platform version is not the correct one (expected: ${platformVersion}, actual: ${output}).`
       );
     });
 };
@@ -306,78 +301,23 @@ const insertResources = (): Cypress.Chainable => {
   return cy.wrap(Promise.all(files.map(insertFixture)));
 };
 
-const prepareUpdateFileForUpgrade = (): Cypress.Chainable => {
-  return cy.getWebVersion().then(({ major_version, minor_version }) => {
-    const targetUpdateFile = `/usr/share/centreon/www/install/php/Update-${major_version}.${minor_version}.php`;
-
-    // Check if the version-specific file already exists
-    return cy.execInContainer({
-      command: `ls ${targetUpdateFile} || echo "File not found"`,
-      name: Cypress.env('dockerName')
-    }).then((fileCheckResult) => {
-      // If version-specific file already exists, no action needed
-      if (!fileCheckResult.stdout.includes("File not found")) {
-        cy.log(`Version-specific update file already exists in container: ${targetUpdateFile}`);
-        return cy.wrap(null);
-      }
-      
-      // If version-specific file does not exist => copy content from Update-next.php
-      return cy.exec(`ls ../../www/install/php/Update-next.php || echo ""`)
-      .then((result) => {
-        const updateNextFile = result.stdout.trim();
-        if (!updateNextFile) {
-          cy.log("Update-next.php file not found");
-          return cy.wrap(null);
-        }
-
-        // Copy the Update-next.php content to container with proper name
-        return cy.copyToContainer({
-          source: updateNextFile,
-          destination: targetUpdateFile
-        })
-        .then(() => {
-          // Check if file was copied successfully
-          return cy.execInContainer({
-            command: `ls -la ${targetUpdateFile} || echo "File not found after copy"`,
-            name: Cypress.env('dockerName')
-          }).then((lsResult) => {
-
-            if (lsResult.stdout.includes("File not found")) {
-              cy.log("WARNING: Copy operation did not create the target file");
-              return cy.wrap(null);
-            }
-
-            // Change version in the file
-            return cy.execInContainer({
-              command: `sed -i "s/version = '';/version = '${major_version}.${minor_version}';/g" ${targetUpdateFile}`,
-              name: Cypress.env('dockerName')
-            });
-          });
-        });
-      });
-    });
-  });
-};
-
 When('administrator updates packages to current version', () => {
   updatePlatformPackages();
 });
 
 When('administrator runs the update procedure', () => {
-  prepareUpdateFileForUpgrade()
-  .then(() => {
-    cy.visit('/');
+  cy.visit('/');
 
-    cy.wait('@getStep1', { timeout: 60000 }).then(() => {
-      cy.get('.btc.bt_info').should('be.visible').click();
-    });
+  cy.wait('@getStep1').then(() => {
+    cy.get('.btc.bt_info').should('be.visible').click();
+  });
 
-    cy.wait('@getStep2').then(() => {
-      cy.get('span[style]').each(($span) => {
-        cy.wrap($span).should('have.text', 'Loaded');
-      });
-      cy.get('.btc.bt_info').should('be.visible').click();
+  cy.wait('@getStep2').then(() => {
+    cy.get('span[style]').each(($span) => {
+      cy.wrap($span).should('have.text', 'Loaded');
     });
+    cy.get('.btc.bt_info').should('be.visible').click();
+  });
 
   cy.wait('@getStep3');
   cy.contains('Release notes');
@@ -393,26 +333,24 @@ When('administrator runs the update procedure', () => {
   // button is disabled during 3s in order to read documentation
   cy.get('#next', { timeout: 15000 }).should('be.enabled').click();
 
-    cy.wait('@generatingCache')
-      .get('span[style]', { timeout: 15000 })
-      .each(($span) => {
-        cy.wrap($span).should('have.text', 'OK');
-      });
-    cy.get('.btc.bt_info', { timeout: 15000 }).should('be.visible').click();
+  cy.wait('@generatingCache')
+    .get('span[style]', { timeout: 15000 })
+    .each(($span) => {
+      cy.wrap($span).should('have.text', 'OK');
+    });
+  cy.get('.btc.bt_info', { timeout: 15000 }).should('be.visible').click();
 
-    cy.wait('@getStep5');
-    cy.contains('Congratulations');
+  cy.wait('@getStep5');
+  cy.contains('Congratulations');
 
   // disable statistics if checkbox is available (only on upgrade to new major version)
-  cy.get('body')
-    .then(($body) => {
-      if ($body.find('#send_statistics').length) {
-        cy.get('#send_statistics').uncheck({ force: true });
-      }
-    });
-
-    cy.get('.btc.bt_success').should('be.visible').click();
+  cy.get('body').then(($body) => {
+    if ($body.find('#send_statistics').length) {
+      cy.get('#send_statistics').uncheck({ force: true });
+    }
   });
+
+  cy.get('.btc.bt_success').should('be.visible').click();
 });
 
 Then(
@@ -491,7 +429,7 @@ Then('legacy services grid page should still work', () => {
 });
 
 Given('a successfully updated platform', () => {
-  cy.waitForContainerAndSetToken();
+  cy.setUserTokenApiV1();
 
   cy.loginByTypeOfUser({
     jsonName: 'admin'
