@@ -23,17 +23,15 @@ declare(strict_types=1);
 namespace Tests\Core\Security\Authentication\Application\UseCase\LoginSession;
 
 use Core\Infrastructure\Common\Presenter\PresenterFormatterInterface;
-use PHPUnit\Framework\TestCase;
 use Centreon\Domain\Menu\Model\Page;
-use Symfony\Component\HttpFoundation\Request;
+use Core\Security\Authentication\Application\UseCase\Login\ThirdPartyLoginForm;
 use Core\Application\Common\UseCase\ErrorResponse;
 use Symfony\Component\HttpFoundation\RequestStack;
-use Core\Application\Common\UseCase\PresenterInterface;
 use Centreon\Domain\Contact\Interfaces\ContactInterface;
 use Centreon\Domain\Menu\Interfaces\MenuServiceInterface;
 use Core\Application\Common\UseCase\UnauthorizedResponse;
 use Core\Security\ProviderConfiguration\Domain\Model\Provider;
-use Symfony\Component\HttpFoundation\Session\SessionInterface;
+use Symfony\Component\HttpFoundation\Session\Session;
 use Core\Security\Authentication\Domain\Model\NewProviderToken;
 use Security\Domain\Authentication\Exceptions\ProviderException;
 use Core\Security\Authentication\Application\UseCase\Login\Login;
@@ -51,27 +49,22 @@ use Core\Security\Authentication\Application\Repository\WriteSessionRepositoryIn
 use Core\Security\Authentication\Application\Provider\ProviderAuthenticationFactoryInterface;
 use Core\Security\Authentication\Application\Repository\WriteSessionTokenRepositoryInterface;
 use Centreon\Domain\Authentication\Exception\AuthenticationException as LegacyAuthenticationException;
+use Symfony\Component\HttpFoundation\Session\Storage\MockArraySessionStorage;
+use Symfony\Component\Routing\Generator\UrlGeneratorInterface;
 
 beforeEach(function () {
     $this->provider = $this->createMock(ProviderAuthenticationInterface::class);
     $this->contact = $this->createMock(ContactInterface::class);
     $this->menuService = $this->createMock(MenuServiceInterface::class);
     $this->dataStorageEngine = $this->createMock(DataStorageEngineInterface::class);
-    $this->session = $this->createMock(SessionInterface::class);
-    $this->session
-        ->expects($this->any())
-        ->method('getId')
-        ->willReturn('session_abcd');
-    $this->request = $this->createMock(Request::class);
-    $this->request
-        ->expects($this->any())
-        ->method('getSession')
-        ->willReturn($this->session);
     $this->requestStack = $this->createMock(RequestStack::class);
+
+    $session = new Session(new MockArraySessionStorage());
+    $session->setId('session_abcd');
     $this->requestStack
-        ->expects($this->any())
-        ->method('getCurrentRequest')
-        ->willReturn($this->request);
+            ->expects($this->any())
+            ->method('getSession')
+            ->willReturn($session);
 
     $this->providerFactory = $this->createMock(ProviderAuthenticationFactoryInterface::class);
     $this->readTokenRepository = $this->createMock(ReadTokenRepositoryInterface::class);
@@ -80,9 +73,10 @@ beforeEach(function () {
     $this->writeSessionRepository = $this->createMock(WriteSessionRepositoryInterface::class);
     $this->aclUpdater = $this->createMock(AclUpdaterInterface::class);
     $this->defaultRedirectUri = '/monitoring/resources';
+    $this->thirdPartyLoginForm = new ThirdPartyLoginForm($this->createMock(UrlGeneratorInterface::class));
     $this->useCase = new Login(
         $this->providerFactory,
-        $this->session,
+        $this->requestStack,
         $this->dataStorageEngine,
         $this->writeSessionRepository,
         $this->readTokenRepository,
@@ -90,7 +84,8 @@ beforeEach(function () {
         $this->writeSessionTokenRepository,
         $this->aclUpdater,
         $this->menuService,
-        $this->defaultRedirectUri
+        $this->defaultRedirectUri,
+        $this->thirdPartyLoginForm,
     );
 
     $this->authenticationRequest = LoginRequest::createForLocal("admin", "password", '127.0.0.1');
@@ -103,7 +98,7 @@ beforeEach(function () {
 it('should present an error response when the provider configuration is not found', function () {
     $useCase = new Login(
         $this->providerFactory,
-        $this->session,
+        $this->requestStack,
         $this->dataStorageEngine,
         $this->writeSessionRepository,
         $this->readTokenRepository,
@@ -111,7 +106,8 @@ it('should present an error response when the provider configuration is not foun
         $this->writeSessionTokenRepository,
         $this->aclUpdater,
         $this->menuService,
-        $this->defaultRedirectUri
+        $this->defaultRedirectUri,
+        $this->thirdPartyLoginForm,
     );
 
     $this->providerFactory
@@ -128,7 +124,7 @@ it('should present an error response when the provider configuration is not foun
 it('should present an UnauthorizedResponse when the authentication fails', function () {
     $useCase = new Login(
         $this->providerFactory,
-        $this->session,
+        $this->requestStack,
         $this->dataStorageEngine,
         $this->writeSessionRepository,
         $this->readTokenRepository,
@@ -136,7 +132,8 @@ it('should present an UnauthorizedResponse when the authentication fails', funct
         $this->writeSessionTokenRepository,
         $this->aclUpdater,
         $this->menuService,
-        $this->defaultRedirectUri
+        $this->defaultRedirectUri,
+        $this->thirdPartyLoginForm,
     );
 
     $this->provider
@@ -157,7 +154,7 @@ it('should present an UnauthorizedResponse when the authentication fails', funct
 it('should present a PasswordExpiredResponse when the user password is expired', function () {
     $useCase = new Login(
         $this->providerFactory,
-        $this->session,
+        $this->requestStack,
         $this->dataStorageEngine,
         $this->writeSessionRepository,
         $this->readTokenRepository,
@@ -165,7 +162,8 @@ it('should present a PasswordExpiredResponse when the user password is expired',
         $this->writeSessionTokenRepository,
         $this->aclUpdater,
         $this->menuService,
-        $this->defaultRedirectUri
+        $this->defaultRedirectUri,
+        $this->thirdPartyLoginForm,
     );
 
     $this->provider
@@ -186,7 +184,7 @@ it('should present a PasswordExpiredResponse when the user password is expired',
 it('should present an UnauthorizedResponse when user is not authorized to log in', function () {
     $useCase = new Login(
         $this->providerFactory,
-        $this->session,
+        $this->requestStack,
         $this->dataStorageEngine,
         $this->writeSessionRepository,
         $this->readTokenRepository,
@@ -194,7 +192,8 @@ it('should present an UnauthorizedResponse when user is not authorized to log in
         $this->writeSessionTokenRepository,
         $this->aclUpdater,
         $this->menuService,
-        $this->defaultRedirectUri
+        $this->defaultRedirectUri,
+        $this->thirdPartyLoginForm,
     );
     $useCase($this->authenticationRequest, $this->presenter);
     expect($this->presenter->getResponseStatus())->toBeInstanceOf(UnauthorizedResponse::class);
@@ -204,7 +203,7 @@ it('should present an UnauthorizedResponse when user is not authorized to log in
 it("should present an UnauthorizedResponse when user doesn't exist", function () {
     $useCase = new Login(
         $this->providerFactory,
-        $this->session,
+        $this->requestStack,
         $this->dataStorageEngine,
         $this->writeSessionRepository,
         $this->readTokenRepository,
@@ -212,7 +211,8 @@ it("should present an UnauthorizedResponse when user doesn't exist", function ()
         $this->writeSessionTokenRepository,
         $this->aclUpdater,
         $this->menuService,
-        $this->defaultRedirectUri
+        $this->defaultRedirectUri,
+        $this->thirdPartyLoginForm,
     );
     $this->provider
         ->expects($this->once())
@@ -236,7 +236,7 @@ it("should present an UnauthorizedResponse when user doesn't exist", function ()
 it('should create a user when auto import is enabled', function () {
     $useCase = new Login(
         $this->providerFactory,
-        $this->session,
+        $this->requestStack,
         $this->dataStorageEngine,
         $this->writeSessionRepository,
         $this->readTokenRepository,
@@ -244,7 +244,8 @@ it('should create a user when auto import is enabled', function () {
         $this->writeSessionTokenRepository,
         $this->aclUpdater,
         $this->menuService,
-        $this->defaultRedirectUri
+        $this->defaultRedirectUri,
+        $this->thirdPartyLoginForm,
     );
     $this->contact
         ->expects($this->once())
@@ -277,7 +278,7 @@ it('should create a user when auto import is enabled', function () {
 it('should create authentication tokens when user is correctly authenticated', function () {
     $useCase = new Login(
         $this->providerFactory,
-        $this->session,
+        $this->requestStack,
         $this->dataStorageEngine,
         $this->writeSessionRepository,
         $this->readTokenRepository,
@@ -285,7 +286,8 @@ it('should create authentication tokens when user is correctly authenticated', f
         $this->writeSessionTokenRepository,
         $this->aclUpdater,
         $this->menuService,
-        $this->defaultRedirectUri
+        $this->defaultRedirectUri,
+        $this->thirdPartyLoginForm,
     );
 
     $this->contact
@@ -336,7 +338,7 @@ it('should create authentication tokens when user is correctly authenticated', f
 it('should present the default page when user is correctly authenticated', function () {
     $useCase = new Login(
         $this->providerFactory,
-        $this->session,
+        $this->requestStack,
         $this->dataStorageEngine,
         $this->writeSessionRepository,
         $this->readTokenRepository,
@@ -344,7 +346,8 @@ it('should present the default page when user is correctly authenticated', funct
         $this->writeSessionTokenRepository,
         $this->aclUpdater,
         $this->menuService,
-        $this->defaultRedirectUri
+        $this->defaultRedirectUri,
+        $this->thirdPartyLoginForm,
     );
 
     $this->contact
@@ -381,7 +384,7 @@ it('should present the default page when user is correctly authenticated', funct
 it('should present the custom redirection page when user is authenticated', function () {
     $useCase = new Login(
         $this->providerFactory,
-        $this->session,
+        $this->requestStack,
         $this->dataStorageEngine,
         $this->writeSessionRepository,
         $this->readTokenRepository,
@@ -389,7 +392,8 @@ it('should present the custom redirection page when user is authenticated', func
         $this->writeSessionTokenRepository,
         $this->aclUpdater,
         $this->menuService,
-        $this->defaultRedirectUri
+        $this->defaultRedirectUri,
+        $this->thirdPartyLoginForm,
     );
 
     $page = new Page(1, '/my_custom_page', 60101, true);
