@@ -68,6 +68,7 @@ use Core\ViewImg\Application\Repository\ReadViewImgRepositoryInterface;
 use Exception;
 
 beforeEach(closure: function (): void {
+    $this->readServiceTemplateRepository = $this->createMock(ReadServiceTemplateRepositoryInterface::class);
     $this->writeServiceTemplateRepository = $this->createMock(WriteServiceTemplateRepositoryInterface::class);
     $this->readHostTemplateRepository = $this->createMock(ReadHostTemplateRepositoryInterface::class);
     $this->readServiceCategoryRepository = $this->createMock(ReadServiceCategoryRepositoryInterface::class);
@@ -450,6 +451,7 @@ it('should present a NoContentResponse when everything has gone well for an admi
     $this->readServiceTemplateRepository
         ->expects($this->once())
         ->method('findParents')
+        ->with($request->id)
         ->willReturn($serviceTemplateInheritances);
 
     $macroA = new Macro($serviceTemplate->getId(), 'MACROA', 'A');
@@ -495,7 +497,8 @@ it('should present a NoContentResponse when everything has gone well for an admi
 
     $this->parametersValidation
         ->expects($this->once())
-        ->method('assertIsValidServiceTemplate');
+        ->method('assertIsValidServiceTemplate')
+        ->with($request->serviceTemplateParentId);
 
     $this->parametersValidation
         ->expects($this->once())
@@ -539,11 +542,59 @@ it('should present a NoContentResponse when everything has gone well for an admi
 
     $this->writeServiceTemplateRepository
         ->expects($this->once())
-        ->method('update');
+        ->method('update')
+        ->with($serviceTemplate);
 
     ($this->useCase)($request, $this->presenter);
 
-    expect($this->presenter->getResponseStatus())->toBeInstanceOf(NoContentResponse::class);
+    expect($serviceTemplate->getName())->toBe($request->name)
+        ->and($serviceTemplate->getAlias())->toBe($request->alias)
+        ->and($serviceTemplate->getCommandArguments())->toBe($request->commandArguments)
+        ->and($serviceTemplate->getEventHandlerArguments())->toBe($request->eventHandlerArguments)
+        ->and(
+            NotificationTypeConverter::toBits(
+                $serviceTemplate->getNotificationTypes()
+            )
+        )->toBe(NotificationTypeConverter::toBits($notificationTypes))
+        ->and($serviceTemplate->isContactAdditiveInheritance())->toBe(false)
+        ->and($serviceTemplate->isContactGroupAdditiveInheritance())->toBe(false)
+        ->and($serviceTemplate->getActiveChecks())->toBe(
+            \Core\ServiceTemplate\Application\Model\YesNoDefaultConverter::fromInt($request->activeChecksEnabled)
+        )->and($serviceTemplate->getPassiveCheck())->toBe(
+            \Core\ServiceTemplate\Application\Model\YesNoDefaultConverter::fromInt($request->passiveCheckEnabled)
+        )->and($serviceTemplate->getVolatility())->toBe(
+            \Core\ServiceTemplate\Application\Model\YesNoDefaultConverter::fromInt($request->volatility)
+        )->and($serviceTemplate->getCheckFreshness())->toBe(
+            \Core\ServiceTemplate\Application\Model\YesNoDefaultConverter::fromInt($request->checkFreshness)
+        )->and($serviceTemplate->getEventHandlerEnabled())->toBe(
+            \Core\ServiceTemplate\Application\Model\YesNoDefaultConverter::fromInt($request->eventHandlerEnabled)
+        )->and($serviceTemplate->getFlapDetectionEnabled())->toBe(
+            \Core\ServiceTemplate\Application\Model\YesNoDefaultConverter::fromInt($request->flapDetectionEnabled)
+        )->and($serviceTemplate->getNotificationsEnabled())->toBe(
+            \Core\ServiceTemplate\Application\Model\YesNoDefaultConverter::fromInt($request->notificationsEnabled)
+        )->and($serviceTemplate->getComment())->toBe($request->comment)
+        ->and($serviceTemplate->getNote())->toBe($request->note)
+        ->and($serviceTemplate->getNoteUrl())->toBe($request->noteUrl)
+        ->and($serviceTemplate->getActionUrl())->toBe($request->actionUrl)
+        ->and($serviceTemplate->getIconAlternativeText())->toBe($request->iconAlternativeText)
+        ->and($serviceTemplate->getGraphTemplateId())->toBe($request->graphTemplateId)
+        ->and($serviceTemplate->getServiceTemplateParentId())->toBe($request->serviceTemplateParentId)
+        ->and($serviceTemplate->getCommandId())->toBe($request->commandId)
+        ->and($serviceTemplate->getEventHandlerId())->toBe($request->eventHandlerId)
+        ->and($serviceTemplate->getNotificationTimePeriodId())->toBe($request->notificationTimePeriodId)
+        ->and($serviceTemplate->getCheckTimePeriodId())->toBe($request->checkTimePeriodId)
+        ->and($serviceTemplate->getIconId())->toBe($request->iconId)
+        ->and($serviceTemplate->getSeverityId())->toBe($request->severityId)
+        ->and($serviceTemplate->getMaxCheckAttempts())->toBe($request->maxCheckAttempts)
+        ->and($serviceTemplate->getNormalCheckInterval())->toBe($request->normalCheckInterval)
+        ->and($serviceTemplate->getRetryCheckInterval())->toBe($request->retryCheckInterval)
+        ->and($serviceTemplate->getFreshnessThreshold())->toBe($request->freshnessThreshold)
+        ->and($serviceTemplate->getLowFlapThreshold())->toBe($request->lowFlapThreshold)
+        ->and($serviceTemplate->getHighFlapThreshold())->toBe($request->highFlapThreshold)
+        ->and($serviceTemplate->getNotificationInterval())->toBe($request->notificationInterval)
+        ->and($serviceTemplate->getRecoveryNotificationDelay())->toBe($request->recoveryNotificationDelay)
+        ->and($serviceTemplate->getFirstNotificationDelay())->toBe($request->firstNotificationDelay)
+        ->and($serviceTemplate->getAcknowledgementTimeout())->toBe($request->acknowledgementTimeout);
 });
 
 it('should present a NoContentResponse when everything has gone well for a non-admin user', function (): void {
