@@ -1,164 +1,159 @@
 <?php
+
 /*
- * Copyright 2005-2015 CENTREON
- * Centreon is developped by : Julien Mathis and Romain Le Merlus under
- * GPL Licence 2.0.
+ * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
  *
- * This program is free software; you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation ; either version 2 of the License.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, see <http://www.gnu.org/licenses>.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
- * Linking this program statically or dynamically with other modules is making a
- * combined work based on this program. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
- *
- * As a special exception, the copyright holders of this program give CENTREON
- * permission to link this program with independent modules to produce an executable,
- * regardless of the license terms of these independent modules, and to copy and
- * distribute the resulting executable under terms of CENTREON choice, provided that
- * CENTREON also meet, for each linked independent module, the terms  and conditions
- * of the license of that module. An independent module is a module which is not
- * derived from this program. If you modify this program, you may extend this
- * exception to your version of the program, but you are not obliged to do so. If you
- * do not wish to do so, delete this exception statement from your version.
- *
- * For more information : command@centreon.com
+ * For more information : contact@centreon.com
  *
  */
 
+declare(strict_types=1);
+
 namespace CentreonClapi;
 
-require_once "centreonObject.class.php";
-require_once "centreonContact.class.php";
-require_once "Centreon/Object/Ldap/ConfigurationLdap.php";
-require_once "Centreon/Object/Ldap/ObjectLdap.php";
-require_once "Centreon/Object/Ldap/ServerLdap.php";
+require_once 'centreonObject.class.php';
+require_once 'centreonContact.class.php';
+require_once 'Centreon/Object/Ldap/ConfigurationLdap.php';
+require_once 'Centreon/Object/Ldap/ObjectLdap.php';
+require_once 'Centreon/Object/Ldap/ServerLdap.php';
 
 /**
- * Class for managing ldap servers
- *
- * @author shotamchay
+ * Class for managing ldap servers.
  */
 class CentreonLDAP extends CentreonObject
 {
-    protected $db;
-    protected $baseParams;
-    const NB_ADD_PARAM = 2;
-    const AR_NOT_EXIST = "LDAP configuration ID not found";
+    public const NB_ADD_PARAM = 2;
+    public const AR_NOT_EXIST = 'LDAP configuration ID not found';
 
-    public $aDepends = array(
+    public array $aDepends = [
         'CG',
-        'CONTACTTPL'
-    );
+        'CONTACTTPL',
+    ];
 
+    /** @var \CentreonDB */
+    protected $db;
+
+    protected string $action;
+
+    /** @var array<string,string> */
+    protected array $baseParams = [
+        'alias' => '',
+        'bind_dn' => '',
+        'bind_pass' => '',
+        'group_base_search' => '',
+        'group_filter' => '',
+        'group_member' => '',
+        'group_name' => '',
+        'ldap_auto_import' => '',
+        'ldap_contact_tmpl' => '',
+        'ldap_default_cg' => '',
+        'ldap_dns_use_domain' => '',
+        'ldap_connection_timeout' => '',
+        'ldap_search_limit' => '',
+        'ldap_search_timeout' => '',
+        'ldap_srv_dns' => '',
+        'ldap_store_password' => '',
+        'ldap_template' => '',
+        'protocol_version' => '',
+        'user_base_search' => '',
+        'user_email' => '',
+        'user_filter' => '',
+        'user_firstname' => '',
+        'user_lastname' => '',
+        'user_name' => '',
+        'user_pager' => '',
+        'user_group' => '',
+        'ldap_auto_sync' => '',
+        'ldap_sync_interval' => '',
+    ];
+
+    /** @var string[] */
+    protected array $serverParams = ['host_address', 'host_port', 'host_order', 'use_ssl', 'use_tls'];
 
     /**
      * CentreonLDAP constructor.
+     *
      * @param \Pimple\Container $dependencyInjector
      */
     public function __construct(\Pimple\Container $dependencyInjector)
     {
         parent::__construct($dependencyInjector);
         $this->object = new \Centreon_Object_Ldap($dependencyInjector);
-        $this->baseParams = array(
-            'alias' => '',
-            'bind_dn' => '',
-            'bind_pass' => '',
-            'group_base_search' => '',
-            'group_filter' => '',
-            'group_member' => '',
-            'group_name' => '',
-            'ldap_auto_import' => '',
-            'ldap_contact_tmpl' => '',
-            'ldap_default_cg' => '',
-            'ldap_dns_use_domain' => '',
-            'ldap_connection_timeout' => '',
-            'ldap_search_limit' => '',
-            'ldap_search_timeout' => '',
-            'ldap_srv_dns' => '',
-            'ldap_store_password' => '',
-            'ldap_template' => '',
-            'protocol_version' => '',
-            'user_base_search' => '',
-            'user_email' => '',
-            'user_filter' => '',
-            'user_firstname' => '',
-            'user_lastname' => '',
-            'user_name' => '',
-            'user_pager' => '',
-            'user_group' => ''
-        );
-        $this->serverParams = array('host_address', 'host_port', 'host_order', 'use_ssl', 'use_tls');
-        $this->action = "LDAP";
+        $this->action = 'LDAP';
     }
 
     /**
-     * Checks if configuration name is unique
+     * Get Ldap Configuration Id.
      *
      * @param string $name
-     * @param int $arId
-     * @return boolean
-     */
-    protected function isUnique($name = "", $arId = 0)
-    {
-        $stmt = $this->db->query(
-            "SELECT ar_name FROM auth_ressource WHERE ar_name = ? AND ar_id != ?",
-            array($name, $arId)
-        );
-        $res = $stmt->fetchAll();
-        if (count($res)) {
-            return false;
-        }
-        return true;
-    }
-
-    /**
-     * Get Ldap Configuration Id
      *
-     * @param string $name
-     * @return mixed | returns null if no ldap id is found
      * @throws CentreonClapiException
+     *
+     * @return mixed returns null if no ldap id is found
      */
     public function getLdapId($name)
     {
-        $res = $this->db->query("SELECT ar_id FROM auth_ressource WHERE ar_name = ?", array($name));
+        $res = $this->db->prepare(
+            <<<'SQL'
+                SELECT ar_id
+                FROM auth_ressource
+                WHERE ar_name = :name
+                SQL
+        );
+        $res->bindValue(':name', $name, \PDO::PARAM_STR);
+        $res->execute();
+
         $row = $res->fetch();
-        if (!isset($row['ar_id'])) {
-            return null;
+        if (! isset($row['ar_id'])) {
+            return;
         }
         $ldapId = $row['ar_id'];
         unset($res);
+
         return $ldapId;
     }
 
     /**
      * @param $id
+     *
      * @return mixed
      */
     public function getLdapServers($id)
     {
-        $query = "SELECT host_address, host_port FROM auth_ressource_host  WHERE auth_ressource_id = ?";
-        $res = $this->db->query($query, array($id));
-        $row = $res->fetchAll();
-        return $row;
+        $res = $this->db->prepare(
+            <<<'SQL'
+                SELECT host_address, host_port
+                FROM auth_ressource_host
+                WHERE auth_ressource_id = :id
+                SQL
+        );
+        $res->bindValue(':id', $id, \PDO::PARAM_INT);
+        $res->execute();
+
+        return $res->fetchAll();
     }
 
     /**
      * @param array $params
      * @param array $filters
      */
-    public function show($params = array(), $filters = array())
+    public function show($params = [], $filters = []): void
     {
-        $sql = "SELECT ar_id, ar_name, ar_description, ar_enable
+        $sql = 'SELECT ar_id, ar_name, ar_description, ar_enable
         	FROM auth_ressource
-        	ORDER BY ar_name";
+        	ORDER BY ar_name';
         $res = $this->db->query($sql);
         $row = $res->fetchAll();
         echo "id;name;description;status\n";
@@ -171,59 +166,61 @@ class CentreonLDAP extends CentreonObject
     }
 
     /**
-     * @param null $arName
+     * @param string|null $arName
+     *
      * @throws CentreonClapiException
      */
-    public function showserver($arName = null)
+    public function showserver($arName = null): void
     {
-        if (is_null($arName) || !$arName) {
+        if (! $arName) {
             throw new CentreonClapiException(self::MISSINGPARAMETER);
         }
         $arId = $this->getLdapId($arName);
         if (is_null($arId)) {
             throw new CentreonClapiException(self::OBJECT_NOT_FOUND . ' ' . $arName);
         }
-        $sql = "SELECT ldap_host_id, host_address, host_port, use_ssl, use_tls, host_order
+        $sql = 'SELECT ldap_host_id, host_address, host_port, use_ssl, use_tls, host_order
                 FROM auth_ressource_host
-                WHERE auth_ressource_id = :auth_ressource_id 
-                ORDER BY host_order";
+                WHERE auth_ressource_id = :auth_ressource_id
+                ORDER BY host_order';
         $statement = $this->db->prepare($sql);
         $statement->bindValue(':auth_ressource_id', (int) $arId, \PDO::PARAM_INT);
         $statement->execute();
         $row = $statement->fetchAll(\PDO::FETCH_ASSOC);
         echo "id;address;port;ssl;tls;order\n";
         foreach ($row as $srv) {
-            echo $srv['ldap_host_id'] . $this->delim .
-                $srv['host_address'] . $this->delim .
-                $srv['host_port'] . $this->delim .
-                $srv['use_ssl'] . $this->delim .
-                $srv['use_tls'] . $this->delim .
-                $srv['host_order'] . "\n";
+            echo $srv['ldap_host_id'] . $this->delim
+                . $srv['host_address'] . $this->delim
+                . $srv['host_port'] . $this->delim
+                . $srv['use_ssl'] . $this->delim
+                . $srv['use_tls'] . $this->delim
+                . $srv['host_order'] . "\n";
         }
     }
 
     /**
-     * Add a new ldap configuration
+     * Add a new ldap configuration.
      *
      * @param string $parameters
+     *
      * @throws CentreonClapiException
      */
-    public function add($parameters)
+    public function add($parameters): void
     {
-        if (!isset($parameters)) {
+        if (! isset($parameters)) {
             throw new CentreonClapiException(self::MISSINGPARAMETER);
         }
         $params = explode($this->delim, $parameters);
         if (count($params) < self::NB_ADD_PARAM) {
             throw new CentreonClapiException(self::MISSINGPARAMETER);
         }
-        list($name, $description) = $params;
-        if (!$this->isUnique($name)) {
+        [$name, $description] = $params;
+        if (! $this->isUnique($name)) {
             throw new CentreonClapiException(self::NAMEALREADYINUSE . ' (' . $name . ')');
         }
         $stmt = $this->db->prepare(
             "INSERT INTO auth_ressource (ar_name, ar_description, ar_enable, ar_type)
-            VALUES (:arName, :description, '1', '')"
+            VALUES (:arName, :description, '1', 'ldap')"
         );
         $stmt->bindValue(':arName', $name, \PDO::PARAM_STR);
         $stmt->bindValue(':description', $description, \PDO::PARAM_STR);
@@ -231,29 +228,29 @@ class CentreonLDAP extends CentreonObject
     }
 
     /**
-     * Add server to ldap configuration
+     * Add server to ldap configuration.
      *
      * @param string $parameters
-     * @return void
+     *
      * @throws CentreonClapiException
      */
-    public function addserver($parameters)
+    public function addserver($parameters): void
     {
-        if (!isset($parameters)) {
+        if (! isset($parameters)) {
             throw new CentreonClapiException(self::MISSINGPARAMETER);
         }
         $params = explode($this->delim, $parameters);
         if (count($params) < 5) {
             throw new CentreonClapiException(self::MISSINGPARAMETER);
         }
-        list($arName, $address, $port, $ssl, $tls) = $params;
-        if (!is_numeric($port)) {
+        [$arName, $address, $port, $ssl, $tls] = $params;
+        if (! is_numeric($port)) {
             throw new CentreonClapiException('Incorrect port parameters');
         }
-        if (!is_numeric($ssl)) {
+        if (! is_numeric($ssl)) {
             throw new CentreonClapiException('Incorrect ssl parameters');
         }
-        if (!is_numeric($tls)) {
+        if (! is_numeric($tls)) {
             throw new CentreonClapiException('Incorrect tls parameters');
         }
 
@@ -264,65 +261,86 @@ class CentreonLDAP extends CentreonObject
         }
 
         $serverList = $this->getLdapServers($arId);
-        $newServer = array('host_address' => $address, 'host_port' => $port);
-        if (in_array($newServer, $serverList)) {
+        $newServer = ['host_address' => $address, 'host_port' => $port];
+        if (in_array($newServer, $serverList, true)) {
             throw new CentreonClapiException(self::OBJECTALREADYEXISTS . ' ' . $address);
         }
 
-        $this->db->query(
-            "INSERT INTO auth_ressource_host (auth_ressource_id, host_address, host_port, use_ssl, use_tls)
-             VALUES (:arId, :address, :port, :ssl, :tls)",
-            array(
-                ':arId' => $arId,
-                ':address' => $address,
-                ':port' => $port,
-                ':ssl' => $ssl,
-                ':tls' => $tls
-            )
+        $statement = $this->db->prepare(
+            <<<'SQL'
+                INSERT INTO auth_ressource_host (auth_ressource_id, host_address, host_port, use_ssl, use_tls)
+                VALUES (:arId, :address, :port, :ssl, :tls)
+                SQL
         );
+
+        $statement->bindValue(':arId', $arId, \PDO::PARAM_INT);
+        $statement->bindValue(':address', $address, \PDO::PARAM_STR);
+        $statement->bindValue(':port', $port, \PDO::PARAM_INT);
+        $statement->bindValue(':ssl', $ssl, \PDO::PARAM_INT);
+        $statement->bindValue(':tls', $tls, \PDO::PARAM_INT);
+        $statement->execute();
     }
 
     /**
-     * Delete configuration
+     * Delete configuration.
      *
      * @param int $parameters
+     * @param null|mixed $arName
+     *
      * @throws CentreonClapiException
      */
-    public function del($arName = null)
+    public function del($arName = null): void
     {
-        if (!isset($arName)) {
+        if (! isset($arName)) {
             throw new CentreonClapiException(self::MISSINGPARAMETER);
         }
         $arId = $this->getLdapId($arName);
         if (is_null($arId)) {
             throw new CentreonClapiException(self::OBJECT_NOT_FOUND . ' ' . $arName);
         }
-        $this->db->query("DELETE FROM auth_ressource WHERE ar_id = ?", array($arId));
+
+        $statement = $this->db->prepare(
+            <<<'SQL'
+                DELETE FROM auth_ressource
+                WHERE ar_id = :arId
+                SQL
+        );
+        $statement->bindValue(':arId', $arId, \PDO::PARAM_INT);
+        $statement->execute();
     }
 
     /**
      * @param $serverId
+     *
      * @throws CentreonClapiException
      */
-    public function delserver($serverId)
+    public function delserver($serverId): void
     {
-        if (!isset($serverId)) {
+        if (! isset($serverId)) {
             throw new CentreonClapiException(self::MISSINGPARAMETER);
         }
-        if (!is_numeric($serverId)) {
+        if (! is_numeric($serverId)) {
             throw new CentreonClapiException('Incorrect server id parameters');
         }
 
-        $this->db->query("DELETE FROM auth_ressource_host WHERE ldap_host_id = ?", array($serverId));
+        $statement = $this->db->prepare(
+            <<<'SQL'
+                DELETE FROM auth_ressource_host
+                WHERE ldap_host_id = :serverId
+                SQL
+        );
+        $statement->bindValue(':serverId', $serverId, \PDO::PARAM_INT);
+        $statement->execute();
     }
 
     /**
-     * Set parameters
+     * Set parameters.
      *
      * @param string $parameters
+     *
      * @throws CentreonClapiException
      */
-    public function setparam($parameters = array())
+    public function setparam($parameters = []): void
     {
         if (empty($parameters)) {
             throw new CentreonClapiException(self::MISSINGPARAMETER);
@@ -333,51 +351,70 @@ class CentreonLDAP extends CentreonObject
         }
         $arId = $this->getLdapId($params[0]);
         if (is_null($arId)) {
-            throw new CentreonClapiException(self::OBJECT_NOT_FOUND . ":" . $params[0]);
+            throw new CentreonClapiException(self::OBJECT_NOT_FOUND . ':' . $params[0]);
         }
-        if (in_array(strtolower($params[1]), array('name', 'description', 'enable'))) {
-            if (strtolower($params[1]) == 'name') {
-                if (!$this->isUnique($params[2], $arId)) {
+        if (in_array(mb_strtolower($params[1]), ['name', 'description', 'enable'], true)) {
+            if (mb_strtolower($params[1]) === 'name') {
+                if (! $this->isUnique($params[2], $arId)) {
                     throw new CentreonClapiException(self::NAMEALREADYINUSE . ' (' . $params[2] . ')');
                 }
             }
-            $this->db->query(
-                "UPDATE auth_ressource SET ar_" . $params[1] . " = ? WHERE ar_id = ?",
-                array($params[2], $arId)
+            $statement = $this->db->prepare(
+                <<<SQL
+                    UPDATE auth_ressource
+                    SET ar_{$params[1]} = :param
+                    WHERE ar_id = :arId
+                    SQL
             );
-        } elseif (isset($this->baseParams[strtolower($params[1])])) {
-            if (strtolower($params[1]) == 'ldap_contact_tmpl') {
+            $statement->bindValue(':param', $params[2], \PDO::PARAM_STR);
+            $statement->bindValue(':arId', $arId, \PDO::PARAM_INT);
+            $statement->execute();
+        } elseif (isset($this->baseParams[mb_strtolower($params[1])])) {
+            if (mb_strtolower($params[1]) === 'ldap_contact_tmpl') {
                 if (empty($params[2])) {
                     throw new CentreonClapiException(self::MISSINGPARAMETER);
                 }
                 $contactObj = new CentreonContact($this->dependencyInjector);
                 $params[2] = $contactObj->getContactID($params[2]);
             }
-            if (strtolower($params[1]) === 'ldap_default_cg' && !empty($params[2])) {
+            if (mb_strtolower($params[1]) === 'ldap_default_cg' && ! empty($params[2])) {
                 $contactGroupObj = new CentreonContactGroup($this->dependencyInjector);
                 $params[2] = $contactGroupObj->getContactGroupID($params[2]);
             }
-            $this->db->query(
-                "DELETE FROM auth_ressource_info WHERE ari_name = ? AND ar_id = ?",
-                array($params[1], $arId)
+            $statement = $this->db->prepare(
+                <<<'SQL'
+                    DELETE FROM auth_ressource_info
+                    WHERE ari_name = :name AND ar_id = :arId
+                    SQL
             );
-            $this->db->query(
-                "INSERT INTO auth_ressource_info (ari_value, ari_name, ar_id)
-                 VALUES (?, ?, ?)",
-                array($params[2], $params[1], $arId)
+            $statement->bindValue(':name', $params[1], \PDO::PARAM_STR);
+            $statement->bindValue(':arId', $arId, \PDO::PARAM_INT);
+            $statement->execute();
+
+            $statement = $this->db->prepare(
+                <<<'SQL'
+                    INSERT INTO auth_ressource_info (ari_value, ari_name, ar_id)
+                    VALUES (:value, :name, :arId)
+                    SQL
             );
+            $statement->bindValue(':value', $params[2], \PDO::PARAM_STR);
+            $statement->bindValue(':name', $params[1], \PDO::PARAM_STR);
+            $statement->bindValue(':arId', $arId, \PDO::PARAM_INT);
+            $statement->execute();
+
         } else {
             throw new CentreonClapiException(self::UNKNOWNPARAMETER);
         }
     }
 
     /**
-     * Set server param
+     * Set server param.
+     *
+     * @param null|mixed $parameters
      *
-     * @param null $parameters
      * @throws CentreonClapiException
      */
-    public function setparamserver($parameters = null)
+    public function setparamserver($parameters = null): void
     {
         if (is_null($parameters)) {
             throw new CentreonClapiException(self::MISSINGPARAMETER);
@@ -386,31 +423,36 @@ class CentreonLDAP extends CentreonObject
         if (count($params) < 3) {
             throw new CentreonClapiException(self::MISSINGPARAMETER);
         }
-        list($serverId, $key, $value) = $params;
-        if (!in_array(strtolower($key), $this->serverParams)) {
+        [$serverId, $key, $value] = $params;
+        $key = mb_strtolower($key);
+        if (! in_array($key, $this->serverParams, true)) {
             throw new CentreonClapiException(self::UNKNOWNPARAMETER);
         }
-        $this->db->query(
-            "UPDATE auth_ressource_host SET " . strtolower($key)
-            . " = ? WHERE ldap_host_id = ?",
-            array($value, $serverId)
+        $statement = $this->db->prepare(
+            <<<SQL
+                UPDATE auth_ressource_host
+                SET {$key} = :value WHERE ldap_host_id = :id
+                SQL
         );
+        $statement->bindValue(':value', $value, is_int($value) ? \PDO::PARAM_INT : \PDO::PARAM_STR);
+        $statement->bindValue(':id', $serverId, \PDO::PARAM_INT);
+        $statement->execute();
     }
 
-
     /**
-     * @param null $filterName
+     * @param mixed|null $filterName
+     *
      * @return bool|int|void
      */
     public function export($filterName = null)
     {
-        if (!$this->canBeExported($filterName)) {
+        if (! $this->canBeExported($filterName)) {
             return 0;
         }
 
         $labelField = $this->object->getUniqueLabelField();
-        $filters = array();
-        if (!is_null($filterName)) {
+        $filters = [];
+        if (! is_null($filterName)) {
             $filters[$labelField] = $filterName;
         }
 
@@ -426,17 +468,16 @@ class CentreonLDAP extends CentreonObject
         );
 
         foreach ($ldapList as $ldap) {
-            echo $this->action . $this->delim . "ADD" . $this->delim
+            echo $this->action . $this->delim . 'ADD' . $this->delim
                 . $ldap['ar_name'] . $this->delim
                 . $ldap['ar_description'] . $this->delim . "\n";
 
-            echo $this->action . $this->delim . "SETPARAM" . $this->delim
+            echo $this->action . $this->delim . 'SETPARAM' . $this->delim
                 . $ldap['ar_name'] . $this->delim
                 . 'enable' . $this->delim
                 . $ldap['ar_enable'] . $this->delim . "\n";
 
-
-            $filters = array('`auth_ressource_id`' => $ldap['ar_id']);
+            $filters = ['`auth_ressource_id`' => $ldap['ar_id']];
 
             $ldapServerLabelField = $serverLdapObj->getUniqueLabelField();
             $ldapServerList = $serverLdapObj->getList(
@@ -449,7 +490,7 @@ class CentreonLDAP extends CentreonObject
             );
 
             foreach ($ldapServerList as $server) {
-                echo $this->action . $this->delim . "ADDSERVER" . $this->delim
+                echo $this->action . $this->delim . 'ADDSERVER' . $this->delim
                     . $ldap['ar_name'] . $this->delim
                     . $server['host_address'] . $this->delim
                     . $server['host_port'] . $this->delim
@@ -457,8 +498,7 @@ class CentreonLDAP extends CentreonObject
                     . $server['use_tls'] . $this->delim . "\n";
             }
 
-
-            $filters = array('`ar_id`' => $ldap['ar_id']);
+            $filters = ['`ar_id`' => $ldap['ar_id']];
 
             $ldapConfigurationLabelField = $configurationLdapObj->getUniqueLabelField();
             $ldapConfigurationList = $configurationLdapObj->getList(
@@ -471,10 +511,10 @@ class CentreonLDAP extends CentreonObject
             );
 
             foreach ($ldapConfigurationList as $configuration) {
-                if ($configuration['ari_name'] != 'ldap_dns_use_ssl' &&
-                    $configuration['ari_name'] != 'ldap_dns_use_tls'
+                if ($configuration['ari_name'] !== 'ldap_dns_use_ssl'
+                    && $configuration['ari_name'] !== 'ldap_dns_use_tls'
                 ) {
-                    if ($configuration['ari_name'] == 'ldap_contact_tmpl') {
+                    if ($configuration['ari_name'] === 'ldap_contact_tmpl') {
                         $contactObj = new \Centreon_Object_Contact($this->dependencyInjector);
                         $contactName = $contactObj->getParameters($configuration['ari_value'], 'contact_name');
                         $configuration['ari_value'] = $contactName['contact_name'];
@@ -482,11 +522,11 @@ class CentreonLDAP extends CentreonObject
                     if ($configuration['ari_name'] === 'ldap_default_cg') {
                         $contactGroupObj = new \Centreon_Object_Contact_Group($this->dependencyInjector);
                         $contactGroupName = $contactGroupObj->getParameters($configuration['ari_value'], 'cg_name');
-                        $configuration['ari_value'] = !empty($contactGroupName['cg_name'])
+                        $configuration['ari_value'] = ! empty($contactGroupName['cg_name'])
                             ? $contactGroupName['cg_name']
                             : null;
                     }
-                    echo $this->action . $this->delim . "SETPARAM" . $this->delim
+                    echo $this->action . $this->delim . 'SETPARAM' . $this->delim
                         . $ldap['ar_name'] . $this->delim
                         . $configuration['ari_name'] . $this->delim
                         . $configuration['ari_value'] . $this->delim . "\n";
@@ -494,4 +534,30 @@ class CentreonLDAP extends CentreonObject
             }
         }
     }
+
+    /**
+     * Checks if configuration name is unique.
+     *
+     * @param string $name
+     * @param int $arId
+     *
+     * @return bool
+     */
+    protected function isUnique($name = '', $arId = 0)
+    {
+        $stmt = $this->db->prepare(
+            <<<'SQL'
+                SELECT ar_name
+                FROM auth_ressource
+                WHERE ar_name = :name AND ar_id != :id
+                SQL
+        );
+        $stmt->bindValue(':name', $name, \PDO::PARAM_STR);
+        $stmt->bindValue(':id', $arId, \PDO::PARAM_INT);
+        $stmt->execute();
+
+        $res = $stmt->fetchAll();
+
+        return ! (count($res));
+    }
 }
