@@ -349,6 +349,10 @@ class CentreonStatistics
             $data['dashboards'] = $this->getAdditionalDashboardsInformation();
         }
 
+        if ($this->featureFlags?->isEnabled('dashboard_playlist')) {
+            $data['playlists'] = $this->getAdditionalDashboardPlaylistsInformation();
+        }
+
         $data['user_filter'] = $this->getAdditionalUserFiltersInformation();
 
         return $data;
@@ -396,7 +400,7 @@ class CentreonStatistics
     }
 
     /**
-     * @return array<string,array<string,array<string,int|null>>>
+     * @return array<string,array<string, array{widget_number: int, metric_number?: int}>>
      */
     private function getAdditionalDashboardsInformation(): array
     {
@@ -404,38 +408,109 @@ class CentreonStatistics
         $dashboardsInformations = $this->dbConfig->query(
             <<<'SQL'
                 SELECT `dashboard_id`,
-                    `name` AS `widget_type`,
+                    `name` AS `widget_name`,
                     `widget_settings`
                 FROM
                     `dashboard_panel`
                 SQL
         );
+
+        $extractMetricInformationFromWidgetSettings = function (array $widgetSettings): int|null
+        {
+            return \array_key_exists('metrics', $widgetSettings['data'])
+                ? \count($widgetSettings['data']['metrics'])
+                : null;
+        };
+
         $dashboardId = '';
         foreach ($dashboardsInformations as $dashboardsInformation) {
-            $widgetType = (string) $dashboardsInformation['widget_type'];
+            $widgetName = (string) $dashboardsInformation['widget_name'];
             $widgetSettings = \json_decode((string) $dashboardsInformation['widget_settings'], true);
 
             if ($dashboardId !== (string) $dashboardsInformation['dashboard_id']) {
                 $dashboardId = (string) $dashboardsInformation['dashboard_id'];
                 $data[$dashboardId] = [];
             }
-            if (\array_key_exists($widgetType, $data[$dashboardId])) {
-                $data[$dashboardId][$widgetType]['widget_number'] += 1;
-                if ($data[$dashboardId][$widgetType]['metric_number'] !== null) {
-                    $data[$dashboardId][$widgetType]['metric_number'] += \count($widgetSettings['data']['metrics']);
+
+            if (\array_key_exists($widgetName, $data[$dashboardId])) {
+                $data[$dashboardId][$widgetName]['widget_number'] += 1;
+
+                if ($data[$dashboardId][$widgetName]['metric_number'] !== null) {
+                    $data[$dashboardId][$widgetName]['metric_number'] += $extractMetricInformationFromWidgetSettings($widgetSettings);
                 }
             } else {
-                $data[$dashboardId][$widgetType]['widget_number'] = 1;
-                $data[$dashboardId][$widgetType]['metric_number'] =
-                (\is_array($widgetSettings['data']) && [] === $widgetSettings['data'])
-                    ? null
-                    : \count($widgetSettings['data']['metrics']);
+                $data[$dashboardId][$widgetName]['widget_number'] = 1;
+                $data[$dashboardId][$widgetName]['metric_number'] = $extractMetricInformationFromWidgetSettings($widgetSettings);
             }
         }
 
         return $data;
     }
 
+    /**
+     * @return array<string,array{rotation_time: int, dashboards_count: int, shared_users_groups_count: int}>
+     */
+    private function getAdditionalDashboardPlaylistsInformation(): array
+    {
+        $data = [];
+        $statement = $this->dbConfig->query(
+            <<<SQL
+                SELECT
+                    dp.name,
+                    dp.rotation_time,
+                    COALESCE(viewer_contacts.viewer_count, 0) AS viewer_contacts,
+                    COALESCE(editor_contacts.editor_count, 0) AS editor_contacts,
+                    COALESCE(viewer_contactgroups.viewer_group_count, 0) AS viewer_contactgroups,
+                    COALESCE(editor_contactgroups.editor_group_count, 0) AS editor_contactgroups,
+                    COALESCE(dashboard_rels.dashboard_count, 0) AS dashboard_count
+                FROM
+                    dashboard_playlist dp
+                LEFT JOIN (
+                    SELECT playlist_id, COUNT(*) AS viewer_count
+                    FROM dashboard_playlist_contact_relation
+                    WHERE role = 'viewer'
+                    GROUP BY playlist_id
+                ) AS viewer_contacts ON dp.id = viewer_contacts.playlist_id
+                LEFT JOIN (
+                    SELECT playlist_id, COUNT(*) AS editor_count
+                    FROM dashboard_playlist_contact_relation
+                    WHERE role = 'editor'
+                    GROUP BY playlist_id
+                ) AS editor_contacts ON dp.id = editor_contacts.playlist_id
+                LEFT JOIN (
+                    SELECT playlist_id, COUNT(*) AS viewer_group_count
+                    FROM dashboard_playlist_contactgroup_relation
+                    WHERE role = 'viewer'
+                    GROUP BY playlist_id
+                ) AS viewer_contactgroups ON dp.id = viewer_contactgroups.playlist_id
+                LEFT JOIN (
+                    SELECT playlist_id, COUNT(*) AS editor_group_count
+                    FROM dashboard_playlist_contactgroup_relation
+                    WHERE role = 'editor'
+                    GROUP BY playlist_id
+                ) AS editor_contactgroups ON dp.id = editor_contactgroups.playlist_id
+                LEFT JOIN (
+                    SELECT playlist_id, COUNT(*) AS dashboard_count
+                    FROM dashboard_playlist_relation
+                    GROUP BY playlist_id
+                ) AS dashboard_rels ON dp.id = dashboard_rels.playlist_id
+            SQL
+        );
+
+        while (false !== ($record = $statement->fetch(\PDO::FETCH_ASSOC))) {
+            $data[$record['name']] = [
+                'rotation_time' => $record['rotation_time'],
+                'dashboards_count' => $record['dashboard_count'],
+                'shared_viewer_contacts' => $record['viewer_contacts'],
+                'shared_editor_contacts' => $record['editor_contacts'],
+                'shared_viewer_contactgroups' => $record['viewer_contactgroups'],
+                'shared_editor_contactgroups' => $record['editor_contactgroups'],
+            ];
+        }
+
+        return $data;
+    }
+
     /**
      * @return array{
      *     nb_users: int,
