@@ -5,6 +5,7 @@ const internalTranslationEndpoint = `${internalLegacyEndpoint}?object=centreon_i
 const baseEndpoint = './api/latest';
 const userEndpoint = `${baseEndpoint}/configuration/users/current/parameters`;
 const parametersEndpoint = `${baseEndpoint}/administration/parameters`;
+const userPermissionsEndpoint = `${baseEndpoint}/users/acl/permissions`;
 const aclEndpoint = `${baseEndpoint}/users/acl/actions`;
 
 export {
@@ -12,5 +13,6 @@ export {
   externalTranslationEndpoint,
   internalTranslationEndpoint,
   aclEndpoint,
-  userEndpoint
+  userEndpoint,
+  userPermissionsEndpoint
 };
