@@ -1,8 +1,7 @@
 import { replace } from 'ramda';
 
-import { Method, TestQueryProvider } from '@centreon/ui';
+import { TestQueryProvider, Method } from '@centreon/ui';
 
-import { labelSave } from '../Local/translatedLabels';
 import {
   accessGroupsEndpoint,
   authenticationProvidersEndpoint,
@@ -33,8 +32,8 @@ import {
   labelGroupsMapping,
   labelIdentityProvider
 } from '../translatedLabels';
+import { labelSave } from '../Local/translatedLabels';
 
-import { retrievedSAMLConfiguration } from './defaults';
 import {
   labelBothIdentityProviderAndCentreonUI,
   labelCentreonUIOnly,
@@ -46,11 +45,11 @@ import {
   labelFullNameAttribute,
   labelLogoutUrl,
   labelRemoteLoginUrl,
-  labelRequestedAuthnContext,
   labelRequired,
   labelSAMLOnly,
   labelUserIdAttribute
 } from './translatedLabels';
+import { retrievedSAMLConfiguration } from './defaults';
 
 import SAMLConfigurationForm from '.';
 
@@ -144,7 +143,6 @@ describe('SAMLConfiguration', () => {
       'have.value',
       retrievedSAMLConfiguration.user_id_attribute
     );
-    cy.findByTestId(labelRequestedAuthnContext).should('have.value', 'minimum');
     cy.findByLabelText(labelCentreonUIOnly).should('not.be.checked');
     cy.findByLabelText(labelBothIdentityProviderAndCentreonUI).should(
       'be.checked'
