@@ -14,11 +14,7 @@ import {
   RolesMapping,
   RolesMappingToApi
 } from '../Openid/models';
-import {
-  RequestedAuthnContextValue,
-  SAMLConfiguration,
-  SAMLConfigurationToAPI
-} from '../SAML/models';
+import { SAMLConfiguration, SAMLConfigurationToAPI } from '../SAML/models';
 import {
   WebSSOConfiguration,
   WebSSOConfigurationToAPI
@@ -269,7 +265,6 @@ export const adaptSAMLConfigurationToAPI = ({
   logoutFrom,
   logoutFromUrl,
   remoteLoginUrl,
-  requestedAuthnContext,
   userIdAttribute
 }: SAMLConfiguration): SAMLConfigurationToAPI => ({
   authentication_conditions: adaptSAMLAuthentificationConditions(
@@ -287,8 +282,6 @@ export const adaptSAMLConfigurationToAPI = ({
   logout_from: logoutFrom,
   logout_from_url: logoutFromUrl,
   remote_login_url: remoteLoginUrl,
-  requested_authn_context:
-    requestedAuthnContext || RequestedAuthnContextValue.Minimum,
   roles_mapping: adaptSAMLRolesMapping(rolesMapping),
   user_id_attribute: userIdAttribute
 });
