@@ -13,11 +13,11 @@ import { labelSearch } from '../translatedLabels';
 const Filter = (): JSX.Element => {
   const { t } = useTranslation();
 
-  const serSearchVAlue = useSetAtom(searchAtom);
+  const setSearchValue = useSetAtom(searchAtom);
 
   const searchDebounced = useRef(
     debounce<(search) => void>((debouncedSearch): void => {
-      serSearchVAlue(debouncedSearch);
+      setSearchValue(debouncedSearch);
     }, 500)
   );
 
