@@ -1,18 +1,22 @@
-import { useState, useMemo } from 'react';
+import { useMemo } from 'react';
 
-import { isNil, equals } from 'ramda';
 import { useAtomValue, useSetAtom } from 'jotai';
-import { useNavigate } from 'react-router-dom';
+import { isNil } from 'ramda';
 import { useTranslation } from 'react-i18next';
+import type { TFunction } from 'react-i18next';
+import { useNavigate } from 'react-router-dom';
 import type { NavigateFunction } from 'react-router-dom';
 import type { JsonDecoder } from 'ts.data.json';
-import type { TFunction } from 'react-i18next';
 
 import { useFetchQuery } from '@centreon/ui';
-import { userAtom, refreshIntervalAtom } from '@centreon/ui-context';
+import {
+  statisticsRefreshIntervalAtom,
+  userAtom,
+  userPermissionsAtom
+} from '@centreon/ui-context';
 
-import type { Filter } from '../../Resources/Filter/models';
 import { applyFilterDerivedAtom } from '../../Resources/Filter/filterAtoms';
+import type { Filter } from '../../Resources/Filter/models';
 
 interface AdapterProps<Input> {
   applyFilter: (update: Filter) => void;
@@ -50,24 +54,27 @@ const useResourceCounters: UseRessourceCounters = ({
   const navigate = useNavigate();
   const { t } = useTranslation();
 
-  const [isAllowed, setIsAllowed] = useState<boolean>(true);
+  const userPermissions = useAtomValue(userPermissionsAtom);
 
-  const refetchInterval = useAtomValue(refreshIntervalAtom);
+  const refetchInterval = useAtomValue(statisticsRefreshIntervalAtom);
   const { use_deprecated_pages } = useAtomValue(userAtom);
   const applyFilter = useSetAtom(applyFilterDerivedAtom);
 
+  const isAllowed = useMemo(
+    () => userPermissions?.top_counter || false,
+    [userPermissions?.top_counter]
+  );
+
   const { isLoading, data } = useFetchQuery({
-    catchError: ({ statusCode }): void => {
-      if (equals(statusCode, 401)) {
-        setIsAllowed(false);
-      }
-    },
     decoder,
     getEndpoint: () => endPoint,
     getQueryKey: () => [endPoint, queryName],
     httpCodesBypassErrorSnackbar: [401],
     queryOptions: {
-      refetchInterval: refetchInterval * 1000
+      enabled: isAllowed,
+      refetchInterval: refetchInterval * 1000,
+      refetchOnMount: false,
+      suspense: false
     }
   });
 
