@@ -36,6 +36,7 @@ const useUser = (): (() => null | Promise<void>) => {
         }
 
         const {
+          id,
           alias,
           isExportButtonEnabled,
           locale,
@@ -45,13 +46,18 @@ const useUser = (): (() => null | Promise<void>) => {
           use_deprecated_pages: useDeprecatedPages,
           default_page: defaultPage,
           user_interface_density,
-          dashboard
+          dashboard,
+          isAdmin,
+          canManageApiTokens
         } = retrievedUser as User;
 
         setUser({
           alias,
+          canManageApiTokens,
           dashboard,
           default_page: defaultPage || '/monitoring/resources',
+          id,
+          isAdmin,
           isExportButtonEnabled,
           locale: locale || 'en',
           name,
