@@ -1,6 +1,6 @@
 import {
-  KeyboardEvent,
-  RefObject,
+  type KeyboardEvent,
+  type RefObject,
   Suspense,
   lazy,
   useEffect,
@@ -49,7 +49,7 @@ import {
   LoadingSkeleton,
   Filter as MemoizedFilter,
   SearchField,
-  SelectEntry,
+  type SelectEntry,
   getData,
   useRequest
 } from '@centreon/ui';
@@ -65,7 +65,7 @@ import {
 } from '../translatedLabels';
 
 import {
-  DynamicCriteriaParametersAndValues,
+  type DynamicCriteriaParametersAndValues,
   getAutocompleteSuggestions,
   getDynamicCriteriaParametersAndValue,
   replaceMiddleSpace
@@ -73,6 +73,7 @@ import {
 import FilterLoadingSkeleton from './FilterLoadingSkeleton';
 import SearchHelp from './SearchHelp';
 import { selectedStatusByResourceTypeAtom } from './criteriasNewInterface/basicFilter/atoms';
+import { escapeRegExpSpecialChars } from './criteriasNewInterface/utils';
 import {
   applyCurrentFilterDerivedAtom,
   applyFilterDerivedAtom,
@@ -93,7 +94,7 @@ import {
 import useBackToVisualizationByAll from './useBackToVisualizationByAll';
 import useFilterByModule from './useFilterByModule';
 
-const renderEndAdornmentFilter = (onClear) => (): JSX.Element => {
+export const renderEndAdornmentFilter = (onClear) => (): JSX.Element => {
   const { t } = useTranslation();
   const { classes } = useStyles();
 
@@ -209,7 +210,7 @@ const Filter = (): JSX.Element => {
 
     const lastValue = last(values);
 
-    const selectedValues = remove(-1, 1, values);
+    const selectedValues = remove(-1, 1, values).map(escapeRegExpSpecialChars);
 
     sendDynamicCriteriaValueRequests({
       endpoint: buildAutocompleteEndpoint({
@@ -227,7 +228,7 @@ const Filter = (): JSX.Element => {
           ],
           regex: {
             fields: ['name'],
-            value: lastValue || ''
+            value: escapeRegExpSpecialChars(lastValue || '')
           }
         }
       })
@@ -502,7 +503,7 @@ const Filter = (): JSX.Element => {
 
     const updatedFilter =
       standardFilterById[filterId] ||
-      customFilters?.find(propEq('id', filterId));
+      customFilters?.find(propEq(filterId, 'id'));
 
     applyFilter(updatedFilter);
   };
@@ -531,7 +532,7 @@ const Filter = (): JSX.Element => {
   ];
 
   const canDisplaySelectedFilter = find(
-    propEq('id', currentFilter.id),
+    propEq(currentFilter.id, 'id'),
     options
   );
 
