@@ -1,20 +1,20 @@
 import {
   MutableRefObject,
-  ReactNode,
   useEffect,
   useMemo,
   useRef,
-  useState
+  useState,
+  ReactNode
 } from 'react';
 
-import { useAtomValue } from 'jotai';
+import { useAtomValue, useSetAtom } from 'jotai';
 import { isNil, not, or, path } from 'ramda';
 import { makeStyles } from 'tss-react/mui';
 
 import { Paper, Theme } from '@mui/material';
 
+import { useRequest } from '@centreon/ui';
 import type { ListingModel } from '@centreon/ui';
-import { getXAxisTickFormat, useRequest } from '@centreon/ui';
 import { userAtom } from '@centreon/ui-context';
 
 import PerformanceGraph from '..';
@@ -31,7 +31,14 @@ import {
   GraphOptionId,
   NewLines
 } from '../models';
-import { resourceDetailsUpdatedAtom } from '../TimePeriods/timePeriodAtoms';
+import {
+  adjustTimePeriodDerivedAtom,
+  customTimePeriodAtom,
+  getDatesDerivedAtom,
+  graphQueryParametersDerivedAtom,
+  resourceDetailsUpdatedAtom,
+  selectedTimePeriodAtom
+} from '../TimePeriods/timePeriodAtoms';
 import { useIntersection } from '../useGraphIntersection';
 
 import { graphOptionsAtom } from './graphOptionsAtoms';
@@ -49,16 +56,9 @@ const useStyles = makeStyles()((theme: Theme) => ({
   }
 }));
 
-interface Parameters {
-  end;
-  start;
-  timelineEventsLimit;
-}
-
 interface Props {
   filterLines?: ({ lines, resource }: FilterLines) => NewLines;
   graphHeight: number;
-  graphTimeParameters: Parameters;
   interactWithGraph: boolean;
   limitLegendRows?: boolean;
   renderAdditionalGraphAction?: ReactNode;
@@ -73,8 +73,7 @@ const ExportablePerformanceGraphWithTimeline = <T,>({
   interactWithGraph,
   renderAdditionalGraphAction,
   renderAdditionalLines,
-  filterLines,
-  graphTimeParameters
+  filterLines
 }: Props): JSX.Element => {
   const { classes } = useStyles();
   const [timeline, setTimeline] = useState<Array<TimelineEvent>>();
@@ -90,15 +89,17 @@ const ExportablePerformanceGraphWithTimeline = <T,>({
 
   const { alias } = useAtomValue(userAtom);
   const graphOptions = useAtomValue(graphOptionsAtom);
+  const getGraphQueryParameters = useAtomValue(graphQueryParametersDerivedAtom);
+  const selectedTimePeriod = useAtomValue(selectedTimePeriodAtom);
+  const customTimePeriod = useAtomValue(customTimePeriodAtom);
   const resourceDetailsUpdated = useAtomValue(resourceDetailsUpdatedAtom);
+  const getIntervalDates = useAtomValue(getDatesDerivedAtom);
   const details = useAtomValue(detailsAtom);
-
-  const { end, start, timelineEventsLimit } = graphTimeParameters || {};
+  const adjustTimePeriod = useSetAtom(adjustTimePeriodDerivedAtom);
 
   const graphContainerRef = useRef<HTMLElement | null>(null);
 
   const { setElement, isInViewport } = useIntersection();
-  const xAxisTickFormat = getXAxisTickFormat({ end, start });
 
   const displayEventAnnotations = path<boolean>(
     [GraphOptionId.displayEvents, 'value'],
@@ -118,10 +119,14 @@ const ExportablePerformanceGraphWithTimeline = <T,>({
       return;
     }
 
+    const [start, end] = getIntervalDates(selectedTimePeriod);
+
     sendGetTimelineRequest({
       endpoint: timelineEndpoint,
       parameters: {
-        limit: timelineEventsLimit,
+        limit:
+          selectedTimePeriod?.timelineEventsLimit ||
+          customTimePeriod.timelineLimit,
         search: {
           conditions: [
             {
@@ -145,7 +150,7 @@ const ExportablePerformanceGraphWithTimeline = <T,>({
     }
 
     retrieveTimeline();
-  }, [endpoint, displayEventAnnotations, end, start]);
+  }, [endpoint, selectedTimePeriod, customTimePeriod, displayEventAnnotations]);
 
   useEffect(() => {
     setElement(graphContainerRef.current);
@@ -156,8 +161,18 @@ const ExportablePerformanceGraphWithTimeline = <T,>({
       return undefined;
     }
 
-    return `${endpoint}?start=${start}&end=${end}`;
-  }, [details, end, start]);
+    const graphQuerParameters = getGraphQueryParameters({
+      endDate: customTimePeriod.end,
+      startDate: customTimePeriod.start,
+      timePeriod: selectedTimePeriod
+    });
+
+    return `${endpoint}${graphQuerParameters}`;
+  }, [
+    customTimePeriod.start.toISOString(),
+    customTimePeriod.end.toISOString(),
+    details
+  ]);
 
   const addCommentToTimeline = ({ date, comment }): void => {
     const [id] = crypto.getRandomValues(new Uint16Array(1));
@@ -185,23 +200,22 @@ const ExportablePerformanceGraphWithTimeline = <T,>({
         ref={graphContainerRef as MutableRefObject<HTMLDivElement>}
       >
         <PerformanceGraph<T>
-          canAdjustTimePeriod
           toggableLegend
+          adjustTimePeriod={adjustTimePeriod}
+          customTimePeriod={customTimePeriod}
           displayEventAnnotations={displayEventAnnotations}
-          end={end}
           endpoint={graphEndpoint}
           filterLines={filterLines}
           getPerformanceGraphRef={getPerformanceGraphRef}
           graphActions={
             <MemoizedGraphActions
-              end={end}
+              customTimePeriod={customTimePeriod}
               open={interactWithGraph}
               performanceGraphRef={
                 performanceGraphRef as unknown as MutableRefObject<HTMLDivElement | null>
               }
               renderAdditionalGraphActions={renderAdditionalGraphAction}
               resource={resource}
-              start={start}
               timeline={timeline}
             />
           }
@@ -212,9 +226,11 @@ const ExportablePerformanceGraphWithTimeline = <T,>({
           renderAdditionalLines={renderAdditionalLines}
           resource={resource as Resource}
           resourceDetailsUpdated={resourceDetailsUpdated}
-          start={start}
           timeline={timeline}
-          xAxisTickFormat={xAxisTickFormat}
+          xAxisTickFormat={
+            selectedTimePeriod?.dateTimeFormat ||
+            customTimePeriod.xAxisTickFormat
+          }
           onAddComment={addCommentToTimeline}
         />
       </div>
