@@ -1,13 +1,10 @@
 import { Shape } from '@visx/visx';
 import { equals, negate } from 'ramda';
 import { makeStyles } from 'tss-react/mui';
-import { useSetAtom } from 'jotai';
 
 import { alpha, useTheme } from '@mui/material';
 
-import { useMemoComponent, useTimeShiftZones } from '@centreon/ui';
-
-import { updatedGraphIntervalAtom } from '../../ExportableGraphWithTimeline/atoms';
+import { useMemoComponent } from '@centreon/ui';
 
 import { useTimeShiftContext, TimeShiftDirection } from '.';
 
@@ -33,20 +30,9 @@ const TimeShiftZone = ({
   const theme = useTheme();
   const { classes } = useStyles();
 
-  const { graphHeight, graphWidth, marginLeft, marginTop, end, start } =
+  const { graphHeight, graphWidth, marginLeft, marginTop, shiftTime } =
     useTimeShiftContext();
 
-  const { end: newEnd, start: newStart } = useTimeShiftZones({
-    direction,
-    graphInterval: { end, start }
-  });
-
-  const setGraphInterval = useSetAtom(updatedGraphIntervalAtom);
-
-  const getNewInterval = (): void => {
-    setGraphInterval({ end: newEnd, start: newStart });
-  };
-
   return useMemoComponent({
     Component: (
       <Shape.Bar
@@ -64,7 +50,7 @@ const TimeShiftZone = ({
             : graphWidth) + marginLeft
         }
         y={marginTop}
-        onClick={getNewInterval}
+        onClick={(): void => shiftTime?.(direction)}
         onMouseLeave={onDirectionHover(null)}
         onMouseOver={onDirectionHover(direction)}
       />
