@@ -1,5 +1,3 @@
-import dayjs from 'dayjs';
-
 import { PopoverOrigin, PopoverPosition } from '@mui/material';
 
 import {
@@ -52,10 +50,8 @@ export interface PickersData {
   disabledPickerEndInput?: boolean;
   disabledPickerStartInput?: boolean;
   getIsErrorDatePicker?: (value: boolean) => void;
-  maxDatePickerEndInput?: Date | dayjs.Dayjs;
+  maxDatePickerEndInput?: Date;
   maxDatePickerStartInput?: Date;
   minDatePickerEndInput?: Date;
   minDatePickerStartInput?: Date;
-  onCloseEndPicker?: (isClosed: boolean) => void;
-  onCloseStartPicker?: (isClosed: boolean) => void;
 }
