@@ -1,31 +1,32 @@
-import { renderHook } from '@testing-library/react-hooks/dom';
-import { Provider, createStore, useAtomValue } from 'jotai';
 /* eslint-disable no-underscore-dangle */
 /* eslint-disable @typescript-eslint/no-unused-expressions */
+import { renderHook } from '@testing-library/react-hooks/dom';
+import { Provider, createStore, useAtomValue } from 'jotai';
 import * as Ramda from 'ramda';
 import { BrowserRouter as Router } from 'react-router-dom';
 
 import { Method, TestQueryProvider } from '@centreon/ui';
 import {
   ListingVariant,
-  aclAtom,
   platformFeaturesAtom,
   userAtom
 } from '@centreon/ui-context';
 
+import Resources from '..';
 import { selectedVisualizationAtom } from '../Actions/actionsAtoms';
+import { Type } from '../Actions/model';
+import { panelWidthStorageAtom } from '../Details/detailsAtoms';
 import useDetails from '../Details/useDetails';
+import { applyFilterDerivedAtom } from '../Filter/filterAtoms';
+import { allFilter } from '../Filter/models';
 import useFilter from '../Filter/useFilter';
 import { Visualization } from '../models';
 import {
   labelAcknowledged,
   labelAll,
-  labelCancel,
-  labelChecksDisabled,
-  labelDowntime,
+  labelDisplayView,
   labelInDowntime,
-  labelOnlyPassiveChecksEnabled,
-  labelStartTime,
+  labelMoreActions,
   labelViewByHost,
   labelViewByService
 } from '../translatedLabels';
@@ -34,9 +35,8 @@ import {
   defaultSelectedColumnIds,
   defaultSelectedColumnIdsforViewByHost
 } from './columns';
-import { selectedColumnIdsAtom } from './listingAtoms';
+import { enabledAutorefreshAtom, selectedColumnIdsAtom } from './listingAtoms';
 import {
-  acls,
   columnToSort,
   columns,
   entities,
@@ -50,6 +50,64 @@ import useLoadDetails from './useLoadResources/useLoadDetails';
 
 import Listing from '.';
 
+const pageNavigationCalls = [
+  { expectedCall: 1, param: 'page=2&limit=30' },
+  { expectedCall: 4, param: 'page=1&limit=30' },
+  { expectedCall: 1, param: 'page=4&limit=30' }
+];
+
+const listingActionsData = [
+  {
+    conditionsInListing: [
+      { rule: 'be.visible', testId: 'PlayArrowIcon' },
+      { rule: 'be.visible', testId: 'RefreshIcon' }
+    ],
+    conditionsInMoreActions: [
+      {
+        rule: 'not.exist',
+        testId: 'RefreshInMoreActions'
+      },
+      {
+        rule: 'not.exist',
+        testId: 'AutorefreshInMoreActions'
+      }
+    ],
+    height: 590,
+    panelWidth: 750,
+    type: Type.medium
+  },
+  {
+    conditionsInListing: [
+      { rule: 'not.exist', testId: 'PlayArrowIcon' },
+      { rule: 'not.exist', testId: 'RefreshIcon' }
+    ],
+    conditionsInMoreActions: [
+      {
+        rule: 'be.visible',
+        testId: 'RefreshInMoreActions'
+      },
+      {
+        rule: 'be.visible',
+        testId: 'AutorefreshInMoreActions'
+      }
+    ],
+    height: 590,
+    panelWidth: 900,
+    type: Type.small
+  }
+];
+
+const interceptRequest = ({ dataPath, alias, path }): void => {
+  cy.fixture(dataPath).then((data) => {
+    cy.interceptAPIRequest({
+      alias,
+      method: Method.GET,
+      path,
+      response: data
+    });
+  });
+};
+
 const configureUserAtomViewMode = (
   listingVariant: ListingVariant = ListingVariant.compact
 ): void => {
@@ -60,28 +118,10 @@ const configureUserAtomViewMode = (
   userData.result.current.user_interface_density = listingVariant;
 };
 
-const openCalendar = (label): void => {
-  cy.findByLabelText(label)
-    .find('input')
-    .then(($input) => {
-      if ($input.attr('readonly')) {
-        cy.wrap($input).click();
-      } else {
-        cy.findByLabelText(label).findByRole('button').click();
-      }
-    });
-};
-
 before(() => {
   configureUserAtomViewMode();
 });
 
-const store = createStore();
-
-store.set(selectedVisualizationAtom, Visualization.All);
-store.set(platformFeaturesAtom, getPlatformFeatures({}));
-store.set(aclAtom, acls);
-
 const ListingTest = (): JSX.Element => {
   useFilter();
   useLoadDetails();
@@ -94,6 +134,11 @@ const ListingTest = (): JSX.Element => {
   );
 };
 
+const store = createStore();
+
+store.set(selectedVisualizationAtom, Visualization.All);
+store.set(platformFeaturesAtom, getPlatformFeatures({}));
+
 const ListingTestWithJotai = (): JSX.Element => (
   <Provider store={store}>
     <TestQueryProvider>
@@ -129,50 +174,92 @@ const interceptRequestsAndMountBeforeEach = (
     )
   });
 
-  cy.viewport(1200, 1000);
+  cy.adjustViewport();
 };
 
-['dark', 'light'].forEach((mode) => {
-  describe(`Resource Listing: rows and picto colors on ${mode} theme`, () => {
-    beforeEach(() => {
-      const userData = renderHook(() => useAtomValue(userAtom));
-      userData.result.current.themeMode = mode;
-
-      store.set(selectedColumnIdsAtom, ['resource', 'state', 'information']);
-      cy.interceptAPIRequest({
-        alias: 'filterRequest',
-        method: Method.GET,
-        path: '**/events-view*',
-        response: fakeData
-      });
-
-      cy.fixture('resources/listing/listingWithInDowntimeAndAck.json').then(
-        (data) => {
-          cy.interceptAPIRequest({
-            alias: 'listing',
-            method: Method.GET,
-            path: '**/resources?*',
-            response: data
-          });
-        }
-      );
-      cy.mount({
-        Component: (
-          <Router>
-            <ListingTestWithJotai />
-          </Router>
-        )
-      });
-    });
-
-    it('displays listing when some resources are in downtime/acknowledged', () => {
-      cy.waitForRequest('@filterRequest');
-      cy.waitForRequest('@listing');
-
-      cy.contains('Memory').should('be.visible');
-      cy.makeSnapshot();
-    });
+const mountResourcePage = (): void => {
+  cy.interceptAPIRequest({
+    alias: 'filterRequest',
+    method: Method.GET,
+    path: './api/latest/users/filters/events-view?*',
+    response: fakeData
   });
+
+  interceptRequest({
+    alias: 'listingRequest',
+    dataPath: 'resources/resourceListing.json',
+    path: `./api/latest/monitoring/resources?*`
+  });
+
+  interceptRequest({
+    alias: 'detailsRequest',
+    dataPath: 'resources/anomalyDetectionDetails.json',
+    path: `./api/latest/monitoring/resources/anomaly-detection/1`
+  });
+
+  cy.mount({
+    Component: (
+      <Provider store={store}>
+        <Router>
+          <TestQueryProvider>
+            <Resources />
+          </TestQueryProvider>
+        </Router>
+      </Provider>
+    )
+  });
+};
+
+describe('Responsivity listing actions', () => {
+  beforeEach(() => {
+    cy.viewport(1650, 590);
+    store.set(applyFilterDerivedAtom, allFilter);
+    store.set(selectedVisualizationAtom, Visualization.All);
+    store.set(enabledAutorefreshAtom, false);
+    store.set(platformFeaturesAtom, getPlatformFeatures({}));
+
+    mountResourcePage();
+  });
+  listingActionsData.forEach(
+    ({
+      panelWidth,
+      conditionsInListing,
+      type,
+      conditionsInMoreActions,
+      height
+    }) => {
+      it(`Displays the listing actions correctly for responsiveness cases when the size is ${type}`, () => {
+        const collection =
+          document?.getElementById('cy-root')?.children[0]?.children[0];
+        collection.style.height = '590px';
+        store.set(panelWidthStorageAtom, panelWidth);
+
+        cy.waitForRequest('@filterRequest');
+        cy.waitForRequest('@listingRequest');
+
+        cy.contains('ad').click();
+
+        cy.waitForRequest('@detailsRequest');
+
+        cy.findByText(labelDisplayView).should('not.exist');
+
+        conditionsInListing.forEach(({ rule, testId }) => {
+          cy.findByTestId(testId).should(rule);
+        });
+
+        cy.findByLabelText(labelMoreActions).click();
+
+        conditionsInMoreActions.forEach(({ testId, rule }) => {
+          cy.findByTestId(testId).should(rule);
+        });
+
+        cy.makeSnapshotWithCustomResolution({
+          resolution: { height, width: 1650 },
+          title: `listing actions when the size is ${type}`
+        });
+      });
+    }
+  );
 });
 
 describe('Resource Listing', () => {
@@ -234,6 +321,18 @@ describe('Resource Listing', () => {
 
     cy.makeSnapshot();
   });
+
+  it('reorders columns when a drag handle is focused and an arrow is pressed', () => {
+    interceptRequestsAndMountBeforeEach();
+    cy.waitFiltersAndListingRequests();
+
+    cy.moveSortableElementUsingAriaLabel({
+      ariaLabel: 'Parent Drag handle',
+      direction: 'right'
+    });
+
+    cy.makeSnapshot();
+  });
 });
 
 describe('Resource Listing: Visualization by Service', () => {
@@ -243,6 +342,8 @@ describe('Resource Listing: Visualization by Service', () => {
   });
 
   it('sends a request with types "service,metaservice"', () => {
+    cy.findByTestId('tree view').should('be.visible');
+
     cy.findByLabelText(labelViewByService).click();
 
     cy.waitForRequest('@dataToListingTable').then(({ request }) => {
@@ -437,6 +538,7 @@ describe('Resource Listing: Visualization by all resources', () => {
 
 describe('column sorting', () => {
   beforeEach(() => {
+    cy.adjustViewport();
     columnToSort.forEach(() => {
       cy.interceptAPIRequest({
         alias: `dataToListingTable`,
@@ -460,8 +562,6 @@ describe('column sorting', () => {
         </Router>
       )
     });
-
-    cy.viewport(1200, 1000);
   });
 
   columnToSort.forEach(({ label }) => {
@@ -476,17 +576,13 @@ describe('column sorting', () => {
 
       cy.waitForRequest(`@dataToListingTable`);
 
+      cy.get('div[class*="MuiTable-root"]').parent().scrollTo('top');
+
       cy.makeSnapshot();
     });
   });
 });
 
-const pageNavigationCalls = [
-  { expectedCall: 1, param: 'page=2&limit=30' },
-  { expectedCall: 4, param: 'page=1&limit=30' },
-  { expectedCall: 1, param: 'page=4&limit=30' }
-];
-
 describe('Listing request', () => {
   beforeEach(() => {
     interceptRequestsAndMountBeforeEach();
@@ -722,7 +818,7 @@ describe('Display additional columns', () => {
 
       cy.findByLabelText('Add columns').click();
 
-      const column = Ramda.find(Ramda.propEq('id', columnId), columns);
+      const column = Ramda.find(Ramda.propEq(columnId, 'id'), columns);
       const columnLabel = column?.label as string;
 
       const columnShortLabel = column?.shortLabel as string;
@@ -763,130 +859,49 @@ describe('Tree view : Feature Flag', () => {
 
     cy.findByTestId('tree view').should('not.exist');
 
-    cy.makeSnapshot();
-  });
-  it('displays the tree view icons if the feature is enabled', () => {
-    store.set(
-      platformFeaturesAtom,
-      getPlatformFeatures({ enableTreeView: true })
-    );
-    interceptRequestsAndMountBeforeEach();
-
-    cy.contains('E0').should('be.visible');
-
-    cy.findByTestId('tree view').should('be.visible');
-
     cy.makeSnapshot();
   });
 });
 
-describe('Checks icon', () => {
-  beforeEach(() => {
-    store.set(selectedColumnIdsAtom, ['checks', ...defaultSelectedColumnIds]);
-    cy.interceptAPIRequest({
-      alias: 'filterRequest',
-      method: Method.GET,
-      path: '**/events-view*',
-      response: fakeData
-    });
-    cy.fixture('resources/listing/checksIcon.json').then((data) => {
+['dark', 'light'].forEach((mode) => {
+  describe(`Resource Listing: rows and picto colors on ${mode} theme`, () => {
+    beforeEach(() => {
+      const userData = renderHook(() => useAtomValue(userAtom));
+      userData.result.current.themeMode = mode;
+
+      store.set(selectedColumnIdsAtom, ['resource', 'state', 'information']);
       cy.interceptAPIRequest({
-        alias: 'getListing',
+        alias: 'filterRequest',
         method: Method.GET,
-        path: '**/resources?*',
-        response: data
+        path: '**/events-view*',
+        response: fakeData
+      });
+
+      cy.fixture('resources/listing/listingWithInDowntimeAndAck.json').then(
+        (data) => {
+          cy.interceptAPIRequest({
+            alias: 'listing',
+            method: Method.GET,
+            path: '**/resources?*',
+            response: data
+          });
+        }
+      );
+      cy.mount({
+        Component: (
+          <Router>
+            <ListingTestWithJotai />
+          </Router>
+        )
       });
     });
 
-    cy.mount({
-      Component: (
-        <Router>
-          <ListingTestWithJotai />
-        </Router>
-      )
-    });
-  });
+    it('displays listing when some resources are in downtime/acknowledged', () => {
+      cy.waitForRequest('@filterRequest');
+      cy.waitForRequest('@listing');
 
-  [
-    {
-      condition: 'active and  passive checks are false',
-      iconTitle: labelChecksDisabled,
-      testId: 'SyncDisabledIcon'
-    },
-    {
-      condition: 'active checks is false',
-      iconTitle: labelOnlyPassiveChecksEnabled,
-      testId: 'SyncProblemIcon'
-    }
-  ].forEach(({ iconTitle, condition, testId }) => {
-    it(`displays the check icon ${iconTitle} when the ${condition} `, () => {
-      cy.waitForRequest('@getListing');
-      cy.findByTestId(testId).should('be.visible');
-      cy.makeSnapshot(`displays the check icon ${iconTitle} when ${condition}`);
+      cy.contains('Memory').should('be.visible');
+      cy.makeSnapshot();
     });
   });
 });
-
-describe('downtime picker', () => {
-  const now = new Date(Date.UTC(2024, 6, 27, 4, 4, 33));
-  const timezone = 'UTC';
-  const expectedInitialInputValue = '07/27/2024 04:04 AM';
-  const expectedFinalInputValue = '07/20/2024 04:04 AM';
-
-  beforeEach(() => {
-    interceptRequestsAndMountBeforeEach();
-
-    cy.waitFiltersAndListingRequests();
-    cy.clock(now);
-  });
-
-  it('checks the datepicker in downtime when selecting a date', () => {
-    const userData = renderHook(() => useAtomValue(userAtom));
-
-    userData.result.current.timezone = timezone;
-
-    cy.findByLabelText('Select row 4').trigger('mouseover');
-    cy.findByTestId('Set downtime on E4').click();
-
-    cy.contains('Downtime set by');
-    cy.contains(labelCancel);
-    cy.contains(labelDowntime);
-
-    cy.findByLabelText(labelStartTime)
-      .find('input')
-      .should('have.value', expectedInitialInputValue);
-
-    openCalendar(labelStartTime);
-
-    cy.findByRole('gridcell', { name: '27' }).should(
-      'have.attr',
-      'aria-selected',
-      'true'
-    );
-
-    cy.findByRole('gridcell', { name: '20' }).click({
-      waitForAnimations: false
-    });
-
-    cy.findByRole('button', { name: 'OK' }).click({ waitForAnimations: false });
-
-    cy.findByLabelText(labelStartTime)
-      .find('input')
-      .should('have.value', expectedFinalInputValue);
-
-    openCalendar(labelStartTime);
-
-    cy.findByRole('gridcell', { name: '20' }).should(
-      'have.attr',
-      'aria-selected',
-      'true'
-    );
-    cy.findByRole('gridcell', { name: '27' }).should(
-      'have.attr',
-      'aria-current',
-      'date'
-    );
-    cy.makeSnapshot();
-    cy.findByRole('button', { name: 'OK' }).click({ waitForAnimations: false });
-  });
-});
