@@ -82,6 +82,7 @@ const Graph = ({
           resource
         }): JSX.Element => (
           <FederatedComponent
+            displayAdditionalLines
             additionalLinesData={{ additionalLinesProps, resource }}
             path="/anomaly-detection"
           />
@@ -95,18 +96,17 @@ const Graph = ({
 
 const renderChip =
   ({ onClick, label, className }) =>
-  (): JSX.Element =>
-    (
-      <IconButton
-        ariaLabel={label}
-        className={className}
-        size="small"
-        title={label}
-        onClick={onClick}
-      >
-        <IconGraph fontSize="small" />
-      </IconButton>
-    );
+  (): JSX.Element => (
+    <IconButton
+      ariaLabel={label}
+      className={className}
+      size="small"
+      title={label}
+      onClick={onClick}
+    >
+      <IconGraph fontSize="small" />
+    </IconButton>
+  );
 
 const GraphColumn = ({
   onClick
