@@ -27,6 +27,7 @@ import {
   selectedResourcesDetailsAtom
 } from '../Details/detailsAtoms';
 import { ChangeCustomTimePeriodProps } from '../Details/tabs/Graph/models';
+import { resourceDetailsDecoder } from '../decoders';
 
 export interface DetailsState {
   changeCustomTimePeriod: (props: ChangeCustomTimePeriodProps) => void;
@@ -37,8 +38,9 @@ const useLoadDetails = (): DetailsState => {
   const { t } = useTranslation();
 
   const { sendRequest } = useRequest<ResourceDetails>({
+    decoder: resourceDetailsDecoder,
     getErrorMessage: ifElse(
-      pathEq(['response', 'status'], 404),
+      pathEq(404, ['response', 'status']),
       always(t(labelNoResourceFound)),
       pathOr(t(labelSomethingWentWrong), ['response', 'data', 'message'])
     ),
