@@ -151,7 +151,7 @@ export const labelName = 'Name';
 export const labelFilterCreated = 'Filter created';
 export const labelFilterSaved = 'Filter saved';
 export const labelMyFilters = 'My filters';
-export const labelEditFilters = 'Edit filters';
+export const labelManageFilters = 'Manage filters';
 export const labelRename = 'Rename';
 export const labelDelete = 'Delete';
 export const labelAskDelete = 'Delete filter?';
@@ -217,8 +217,6 @@ export const labelCalculationType = 'Calculation type';
 export const labelSelectAtLeastOneColumn =
   'At least one column must be selected';
 export const labelMaxDuration1Year = 'The duration must be less than a year';
-export const labelMediumSize = 'Medium size';
-export const labelSmallSize = 'Small size';
 export const labelSearchOptions = 'Filter options';
 export const labelDisplayCompleteGraph = 'Display the complete graph';
 export const labelActionNotPermitted = 'Action not permitted';
@@ -262,9 +260,10 @@ export const labelHostSeverityLevel = 'Host severity level';
 export const labelServiceSeverityLevel = 'Service severity level';
 export const labelCSV = 'CSV';
 export const labelExport = 'Export';
-export const labelAsDisplayed = 'As displayed';
-export const labelAsMediumSize = 'Medium size';
-export const labelAsSmallSize = 'Small size';
+export const labelExportAs = 'Export as';
+export const labelPNGAsDisplayed = 'PNG (as displayed)';
+export const labelPNGMediumSize = 'PNG (medium size)';
+export const labelPNGSmallSize = 'PNG (small size)';
 export const labelEditAnomalyDetectionData = 'Edit anomaly detection data';
 export const labelAnomalyDetection = 'Anomaly detection';
 export const labelPerformanceGraphAD = 'Edit anomaly detection data';
@@ -299,3 +298,13 @@ export const labelDisplayView = 'Display view:';
 export const labelViewAllResources = 'View all resources';
 export const labelViewByHost = 'View by host';
 export const labelViewByService = 'View by service';
+export const labelResourceDetailsForcedCheckCommandSent =
+  'Forced check command sent !';
+export const labelResourceDetailsCheckCommandSent = 'Check command sent !';
+
+export const labelResourceDetailsCheckDescription =
+  'Check this resource only within configured check period';
+export const labelResourceDetailsForcedCheckDescription =
+  'Check this resource even outside configured check period';
+
+export const labelYourCommentSent = 'Your comment has been saved.';
