@@ -41,6 +41,7 @@ const dashboardDecoder = JsonDecoder.object<DashboardRolesAndPermissions>(
 export const userDecoder = JsonDecoder.object<User>(
   {
     alias: JsonDecoder.string,
+    canManageApiTokens: JsonDecoder.boolean,
     dashboard: JsonDecoder.failover(
       null,
       JsonDecoder.optional(JsonDecoder.nullable(dashboardDecoder))
@@ -48,6 +49,8 @@ export const userDecoder = JsonDecoder.object<User>(
     default_page: JsonDecoder.optional(
       JsonDecoder.nullable(JsonDecoder.string)
     ),
+    id: JsonDecoder.number,
+    isAdmin: JsonDecoder.optional(JsonDecoder.boolean),
     isExportButtonEnabled: JsonDecoder.boolean,
     locale: JsonDecoder.string,
     name: JsonDecoder.string,
@@ -63,6 +66,8 @@ export const userDecoder = JsonDecoder.object<User>(
   },
   'User parameters',
   {
+    canManageApiTokens: 'can_manage_api_tokens',
+    isAdmin: 'is_admin',
     isExportButtonEnabled: 'is_export_button_enabled',
     themeMode: 'theme'
   }
@@ -95,7 +100,10 @@ export const platformVersionsDecoder = JsonDecoder.object<PlatformVersions>(
   {
     modules: JsonDecoder.dictionary(versionDecoder, 'Modules'),
     web: versionDecoder,
-    widgets: JsonDecoder.dictionary(versionDecoder, 'Widgets')
+    widgets: JsonDecoder.dictionary(
+      JsonDecoder.nullable(versionDecoder),
+      'Widgets'
+    )
   },
   'Platform versions',
   {
@@ -109,6 +117,7 @@ export const featuresFlagDecoder = JsonDecoder.object<FeatureFlags>(
   {
     adExclusionPeriods: JsonDecoder.optional(JsonDecoder.boolean),
     dashboard: JsonDecoder.optional(JsonDecoder.boolean),
+    dashboard_playlist: JsonDecoder.optional(JsonDecoder.boolean),
     notification: JsonDecoder.optional(JsonDecoder.boolean),
     resourceStatusFilterRevamp: JsonDecoder.optional(JsonDecoder.boolean),
     resourceStatusTreeView: JsonDecoder.optional(JsonDecoder.boolean),
