@@ -1,27 +1,40 @@
 <?php
 
 /*
- * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
+ * Copyright 2005-2020 Centreon
+ * Centreon is developed by : Julien Mathis and Romain Le Merlus under
+ * GPL Licence 2.0.
  *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation ; either version 2 of the License.
  *
- * https://www.apache.org/licenses/LICENSE-2.0
+ * This program is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * You should have received a copy of the GNU General Public License along with
+ * this program; if not, see <http://www.gnu.org/licenses>.
+ *
+ * Linking this program statically or dynamically with other modules is making a
+ * combined work based on this program. Thus, the terms and conditions of the GNU
+ * General Public License cover the whole combination.
+ *
+ * As a special exception, the copyright holders of this program give Centreon
+ * permission to link this program with independent modules to produce an executable,
+ * regardless of the license terms of these independent modules, and to copy and
+ * distribute the resulting executable under terms of Centreon choice, provided that
+ * Centreon also meet, for each linked independent module, the terms  and conditions
+ * of the license of that module. An independent module is a module which is not
+ * derived from this program. If you modify this program, you may extend this
+ * exception to your version of the program, but you are not obliged to do so. If you
+ * do not wish to do so, delete this exception statement from your version.
  *
  * For more information : contact@centreon.com
  *
  */
 
-use Adaptation\Log\LoggerPassword;
-
-if (! isset($centreon)) {
+if (!isset($centreon)) {
     exit();
 }
 
@@ -102,10 +115,7 @@ if ($cct['contact_auth_type'] === 'local') {
     $form->addElement('text', 'contact_alias', _("Alias / Login"), $attrsText)->freeze();
     $form->addElement('text', 'contact_email', _("Email"), $attrsText)->freeze();
 }
-$form->addElement('text', 'contact_pager', _('Pager'), $attrsText);
-
-// Password Management
-
+$form->addElement('text', 'contact_pager', _("Pager"), $attrsText);
 if ($cct['contact_auth_type'] === 'local') {
     $form->addFormRule('validatePasswordModification');
     $statement = $pearDB->prepare(
@@ -130,19 +140,6 @@ if ($cct['contact_auth_type'] === 'local') {
             }
         }
     }
-
-    // Password Management
-
-    $form->addElement(
-        'password',
-        'current_password',
-        _('Current password'),
-        [
-            'size' => '30',
-            'autocomplete' => 'off',
-            'id' => 'current_password',
-        ]
-    );
     $form->addElement(
         'password',
         'contact_passwd',
@@ -161,44 +158,38 @@ if ($cct['contact_auth_type'] === 'local') {
         _("Generate"),
         ['onclick' => "generatePassword('passwd', '$encodedPasswordPolicy');", 'class' => 'btc bt_info']
     );
-
-    // Autologin Key Management
-
-    $form->addElement('text', 'contact_autologin_key', _('Autologin Key'), ['size' => '30', 'id' => 'aKey']);
-
-    $form->addElement(
-        'button',
-        'contact_gen_akey',
-        _('Generate'),
-        ['onclick' => "generatePassword('aKey', '{$encodedPasswordPolicy}');",
-            'class' => 'btc bt_info',
-            'id' => 'generateAutologinKeyButton',
-            'data-testid' => _('Generate')]
-    );
+}
+$form->addElement('text', 'contact_autologin_key', _("Autologin Key"), ["size" => "30", "id" => "aKey"]);
+$form->addElement(
+    'button',
+    'contact_gen_akey',
+    _("Generate"),
+    ['onclick' => "generatePassword('aKey', '$encodedPasswordPolicy');",
+    'class' => 'btc bt_info',
+    "id" => "generateAutologinKeyButton",
+    "data-testid" => _("Generate")]
+);
+$form->addElement('select', 'contact_lang', _("Language"), $langs);
+if (!isCloudPlatform()) {
+    $form->addElement('checkbox', 'show_deprecated_pages', _("Use deprecated pages"), null, $attrsText);
 }
 
-// Preferences
 
-$form->addElement('select', 'contact_lang', _('Language'), $langs);
-if (! isCloudPlatform()) {
-    $form->addElement('checkbox', 'show_deprecated_pages', _('Use deprecated pages'), null, $attrsText);
-}
-
-// ------------------------ Topology ----------------------------
+/* ------------------------ Topoogy ---------------------------- */
 $pages = [];
 $aclUser = $centreon->user->lcaTStr;
 if (!empty($aclUser)) {
     $acls = array_flip(explode(',', $aclUser));
     /**
-     * Transform [1, 2, 101, 202, 10101, 20201] to :
-     *
-     * 1
-     *   101
-     *     10101
-     * 2
-     *   202
-     *     20201
-     */
+    * Transform [1, 2, 101, 202, 10101, 20201] to :
+    *
+    * 1
+    *   101
+    *     10101
+    * 2
+    *   202
+    *     20201
+    */
     $createTopologyTree = function (array $topologies): array {
         ksort($topologies, \SORT_ASC);
         $parentsLvl = [];
@@ -397,13 +388,12 @@ if ($cct['contact_auth_type'] === 'local') {
 $form->registerRule('exist', 'callback', 'testExistence');
 $form->addRule('contact_name', _("Name already in use"), 'exist');
 $form->registerRule('existAlias', 'callback', 'testAliasExistence');
-$form->addRule('contact_alias', _('Name already in use'), 'existAlias');
-$form->setRequiredNote("<span style='color: red;'>*</span>" . _('Required fields'));
+$form->addRule('contact_alias', _("Name already in use"), 'existAlias');
+$form->setRequiredNote("<font style='color: red;'>*</font>" . _("Required fields"));
 $form->addFormRule('checkAutologinValue');
 
-// Smarty template Init
-$tpl = new Smarty();
-$tpl = initSmartyTpl($path, $tpl);
+// Smarty template initialization
+$tpl = SmartyBC::createSmartyTemplate($path);
 
 $form->setDefaults($defaultFeatures);
 
@@ -454,40 +444,30 @@ if ($form->validate()) {
         $form->getSubmitValue("contact_lang") !== $cct['contact_lang']
         || $showDeprecatedPages !== $cct['show_deprecated_pages']
     ) {
-        /** @var Centreon $centreon */
-        $centreon = $_SESSION['centreon'];
-        $centreon->user->set_lang($form->getSubmitValue('contact_lang'));
-        $centreon->user->setShowDeprecatedPages((bool) $showDeprecatedPages);
-        $_SESSION['centreon'] = $centreon;
+        $contactStatement = $pearDB->prepare(
+            'SELECT * FROM contact WHERE contact_id = :contact_id'
+        );
+        $contactStatement->bindValue(':contact_id', $centreon->user->get_id(), \PDO::PARAM_INT);
+        $contactStatement->execute();
+        if ($contact = $contactStatement->fetch()) {
+            $_SESSION['centreon'] = new \Centreon($contact);
+        }
         $_SESSION[$sessionKeyFreeze] = true;
         echo '<script>parent.location.href = "main.php?p=' . $p . '&o=c";</script>';
         exit;
     } elseif (array_key_exists($sessionKeyFreeze, $_SESSION)) {
         unset($_SESSION[$sessionKeyFreeze]);
     }
-} else {
-    if (
-        $form->getElementError('contact_passwd') === _('Passwords do not match')
-        || $form->getElementError('contact_passwd2') === _('Passwords do not match')
-    ) {
-        LoggerPassword::create()->warning(
-            reason: 'password confirmation does not match',
-            initiatorId: $centreon->user->get_id(),
-            targetId: $centreon->user->get_id(),
-        );
-    }
-
-    if (array_key_exists($sessionKeyFreeze, $_SESSION) && $_SESSION[$sessionKeyFreeze] === true) {
-        unset($_SESSION[$sessionKeyFreeze]);
-        $o = null;
-        $form->addElement(
-            'button',
-            'change',
-            _('Modify'),
-            ['onClick' => "javascript:window.location.href='?p=" . $p . "&o=c'", 'class' => 'btc bt_info']
-        );
-        $form->freeze();
-    }
+} elseif (array_key_exists($sessionKeyFreeze, $_SESSION) && $_SESSION[$sessionKeyFreeze] === true) {
+    unset($_SESSION[$sessionKeyFreeze]);
+    $o = null;
+    $form->addElement(
+        "button",
+        "change",
+        _("Modify"),
+        ["onClick" => "javascript:window.location.href='?p=" . $p . "&o=c'", 'class' => 'btc bt_info']
+    );
+    $form->freeze();
 }
 
 //Apply a template definition
@@ -530,4 +510,3 @@ $tpl->display("formMyAccount.ihtml");
         });
     });
 </script>
-
