@@ -137,6 +137,12 @@ function is_writable_file_if_exist($path = null)
     return false;
 }
 
+function isGreaterThan($value, $minValue) 
+{
+    return is_numeric($value) && $value >= $minValue;
+}
+
+
 /**
  * rule to check the session duration value chosen by the user
  * @param int $value
@@ -420,6 +426,13 @@ function updateDebugConfigData($gopt_id = null)
         "debug_centreontrapd",
         isset($ret["debug_centreontrapd"]) && $ret['debug_centreontrapd'] ? 1 : 0
     );
+    updateOption(
+        $pearDB,
+        "debug_level",
+        $ret['debug_level']
+    );
+
+    enableApplicationDebug((int) $ret['debug_level']);
 
     $centreon->initOptGen($pearDB);
 }
@@ -950,3 +963,20 @@ function updateRemoteAccessCredentials($db, $form, $centreonEncryption): void
         }
     }
 }
+
+/**
+ * Add or remove the debug level from environments files.
+ *
+ * @param bool $enable
+ * @param int $level
+ */
+function enableApplicationDebug(int $level = 100) {
+    $env = new \Utility\EnvironmentFileManager(_CENTREON_PATH_);
+    $env->load();
+    if ($level !== 0) {
+        $env->add('DEBUG_LEVEL', $level);
+    } else {
+        $env->delete('DEBUG_LEVEL');
+    }
+    $env->save();
+}
\ No newline at end of file
