@@ -66,15 +66,16 @@ while ($opt = $dbResult->fetch()) {
         $gopt[$opt["key"]] = myDecode($opt["value"]);
     }
 }
-$gopt['proxy_password'] = CentreonAuth::PWS_OCCULTATION;
 
 /*
  * Style
  */
-$attrsText = array("size" => "40");
-$attrsText2 = array("size" => "5");
+$attrsText = ['size' => '40'];
+$attrsText2 = ['size' => '5'];
 $attrsAdvSelect = null;
 
+$autocompleteOff = ['autocomplete' => 'new-password'];
+
 /*
  * Form begin
  */
@@ -193,8 +194,8 @@ $form->addElement(
     array("class" => "btc bt_success", "onClick" => "javascript:checkProxyConf()")
 );
 $form->addElement('text', 'proxy_port', _("Proxy port"), $attrsText2);
-$form->addElement('text', 'proxy_user', _("Proxy user"), $attrsText);
-$form->addElement('password', 'proxy_password', _("Proxy password"), $attrsText);
+$form->addElement('text', 'proxy_user', _("Proxy user"), array_merge($attrsText, $autocompleteOff));
+$form->addElement('password', 'proxy_password', _("Proxy password"), array_merge($attrsText, $autocompleteOff));
 
 /**
  * Charts options
@@ -233,12 +234,20 @@ $form->registerRule('is_executable_binary', 'callback', 'is_executable_binary');
 $form->registerRule('is_writable_path', 'callback', 'is_writable_path');
 $form->registerRule('is_writable_file', 'callback', 'is_writable_file');
 $form->registerRule('is_writable_file_if_exist', 'callback', 'is_writable_file_if_exist');
+$form->registerRule('greaterthan', 'callback', 'isGreaterThan');
+
 $form->addRule('oreon_path', _('Mandatory field'), 'required');
 $form->addRule('oreon_path', _("Can't write in directory"), 'is_valid_path');
+
 $form->addRule('AjaxTimeReloadMonitoring', _('Mandatory field'), 'required');
 $form->addRule('AjaxTimeReloadMonitoring', _('Must be a number'), 'numeric');
+$form->addRule('AjaxTimeReloadMonitoring', _('The minimum allowed value is 10'), 'greaterthan', 10);
+
 $form->addRule('AjaxTimeReloadStatistic', _('Mandatory field'), 'required');
 $form->addRule('AjaxTimeReloadStatistic', _('Must be a number'), 'numeric');
+$form->addRule('AjaxTimeReloadStatistic', _('The minimum allowed value is 10'), 'greaterthan', 10);
+
+
 $form->addRule('selectPaginationSize', _('Mandatory field'), 'required');
 $form->addRule('selectPaginationSize', _('Must be a number'), 'numeric');
 $form->addRule('maxGraphPerformances', _('Mandatory field'), 'required');
@@ -256,11 +265,8 @@ $form->addRule(
     'isSessionDurationValid'
 );
 
-/*
- * Smarty template Init
- */
-$tpl = new Smarty();
-$tpl = initSmartyTpl($path . 'general/', $tpl);
+// Smarty template initialization
+$tpl = SmartyBC::createSmartyTemplate($path . 'general/');
 
 $form->setDefaults($gopt);
 
