@@ -187,42 +187,46 @@ function tidySearchKey($search, $advanced_search)
 #
 
 /**
+ * NOT REMOVE THIS FUNCTION - Used in centreon-modules
+ *
  * Allows to load Smarty's configuration in relation to a path
  *
- * @param null|string $path
- * @param null|object $tpl
- * @param null|string $subDir
+ * @param string|null $path   [$path=null] Path to the default template directory
+ * @param object|null $tpl    [$tpl=null] A Smarty instance
+ * @param string|null $subDir [$subDir=null] A subdirectory of path
  *
- * @throws \SmartyException
+ * @return SmartyBC
  *
- * @return SmartyCentreon A Smarty instance with configuration parameters
+ * @throws SmartyException
  *
- * @see        SmartyCentreon::createSmartyTemplate()
- * @deprecated Instead use {@see SmartyCentreon::createSmartyTemplate()}
+ * @deprecated Instead use {@see SmartyBC::createSmartyTemplate()}
+ * @see        SmartyBC::createSmartyTemplate()
  */
-function initSmartyTpl($path = null, &$tpl = null, $subDir = null): SmartyCentreon
+function initSmartyTpl(?string $path = null, ?object &$tpl = null, ?string $subDir = null): SmartyBC
 {
-    return SmartyCentreon::createSmartyTemplate($path, $subDir);
+    return SmartyBC::createSmartyTemplate($path, $subDir);
 }
 
 /**
+ * NOT REMOVE THIS FUNCTION - Used in centreon-modules
+ *
  * This function is mainly used in widgets
  *
- * @param null|string $path
- * @param null|object $tpl
- * @param null|string $subDir
- * @param null|string $centreonPath
+ * @param string|null $path
+ * @param object|null $tpl
+ * @param string|null $subDir
+ * @param string|null $centreonPath
  *
- * @throws \SmartyException
+ * @return SmartyBC
  *
- * @return SmartyCentreon A Smarty instance with configuration parameters
+ * @throws SmartyException
  *
- * @see        SmartyCentreon::createSmartyTemplate()
- * @deprecated Instead use {@see SmartyCentreon::createSmartyTemplate()}
+ * @deprecated Instead use {@see SmartyBC::createSmartyTemplate()}
+ * @see        SmartyBC::createSmartyTemplate()
  */
-function initSmartyTplForPopup($path = null, $tpl = null, $subDir = null, $centreonPath = null): SmartyCentreon
+function initSmartyTplForPopup(?string $path = null, ?object $tpl = null, ?string $subDir = null, ?string $centreonPath = null): SmartyBC
 {
-    return initSmartyTpl($path, $tpl, $subDir);
+    return SmartyBC::createSmartyTemplate($path, $subDir);
 }
 
 /*
@@ -510,11 +514,11 @@ function getMyHostExtendedInfoImage($host_id, $field, $flag1stLevel = null, $ant
         $htStatement->bindValue(':host_host_id', (int) $host_id, \PDO::PARAM_INT);
         $htStatement->execute();
         $rq2 = "SELECT `" . $field . "` " .
-            "FROM extended_host_information ehi " .
-            "WHERE ehi.host_host_id = :host_host_id LIMIT 1";
+               "FROM extended_host_information ehi " .
+               "WHERE ehi.host_host_id = :host_host_id LIMIT 1";
         $ehiStatement = $pearDB->prepare($rq2);
         $query = "SELECT img_path, dir_alias FROM view_img vi, view_img_dir vid, view_img_dir_relation vidr " .
-            "WHERE vi.img_id = :img_id 
+                 "WHERE vi.img_id = :img_id 
                  AND vidr.img_img_id = vi.img_id AND vid.dir_id = vidr.dir_dir_parent_id LIMIT 1";
         $imgStatement = $pearDB->prepare($query);
         while ($row = $htStatement->fetch(\PDO::FETCH_ASSOC)) {
@@ -1389,7 +1393,7 @@ function GetMyHostPoller($pearDB, $host_name = null)
     if (!isset($host_name)) {
         return 0;
     }
-    $statement = $pearDB->prepare("SELECT `id` FROM nagios_server, ns_host_relation, host " .
+     $statement = $pearDB->prepare("SELECT `id` FROM nagios_server, ns_host_relation, host " .
         "WHERE host.host_name = :host_name AND host.host_id = ns_host_relation.host_host_id " .
         "AND ns_host_relation.nagios_server_id = nagios_server.id LIMIT 1");
     $statement->bindValue(':host_name', $host_name, \PDO::PARAM_STR);
@@ -1428,7 +1432,7 @@ function check_session($sid, $pearDB)
 
 function db2str($string)
 {
-    $string = str_replace('#BR#', "\\n", $string);
+    $string = str_replace('#BR#', "\\n", $string ?? '');
     $string = str_replace('#T#', "\\t", $string);
     $string = str_replace('#R#', "\\r", $string);
     $string = str_replace('#S#', "/", $string);
