@@ -34,7 +34,7 @@
  *
  */
 
- use Core\ActionLog\Domain\Model\ActionLog;
+use Core\ActionLog\Domain\Model\ActionLog;
 
 if (!isset($centreon)) {
     exit();
@@ -43,7 +43,7 @@ if (!isset($centreon)) {
 if (!function_exists("myDecodeCommand")) {
     function myDecodeCommand($arg)
     {
-        $arg = str_replace('#BR#', "\\n", $arg);
+        $arg = str_replace('#BR#', "\\n", $arg ?? '');
         $arg = str_replace('#T#', "\\t", $arg);
         $arg = str_replace('#R#', "\\r", $arg);
         $arg = str_replace('#S#', "/", $arg);
@@ -246,7 +246,7 @@ function insertCommandInDB($ret = array())
 
 function insertCommand($ret = array())
 {
-    global $form, $pearDB, $centreon;
+    global $form, $pearDB, $centreon, $isCloudPlatform;
 
     if (!count($ret)) {
         $ret = $form->getSubmitValues();
@@ -257,6 +257,8 @@ function insertCommand($ret = array())
         $ret['enable_shell'] = 0;
     }
 
+    $commandType = $isCloudPlatform ? $ret['type'] : $ret["command_type"]["command_type"];
+
     /*
      * Insert
      */
@@ -267,12 +269,13 @@ function insertCommand($ret = array())
             '" . $pearDB->escape($ret["command_line"]) . "',
             " . (int)$ret['enable_shell'] . ",
             '" . $pearDB->escape($ret["command_example"]) . "',
-            " . (int)$ret["command_type"]["command_type"] . ",
+            " . (int) $commandType . ",
             " . (!empty($ret["graph_id"]) ? (int)$ret['graph_id'] : "NULL") . ",
             " . (!empty($ret["connectors"]) ? (int)$ret['connectors'] : "NULL") . ",
             '" . $pearDB->escape($ret["command_comment"]) . "',
             '" . $pearDB->escape($ret["command_activate"]["command_activate"]) . "'";
     $rq .= ")";
+
     $pearDB->query($rq);
 
     /*
