@@ -35,8 +35,8 @@
 require_once dirname(__FILE__) . "/formConnectorFunction.php";
 
 try {
-    $tpl = new Smarty();
-    $tpl = initSmartyTpl($path, $tpl);
+    // Smarty template initialization
+    $tpl = SmartyBC::createSmartyTemplate($path);
     
     $cnt = array();
     if (($o == "c" || $o == "w") && isset($connector_id)) {
@@ -62,9 +62,9 @@ try {
      * Resource Macro
      */
     $resource = array();
-    $DBRESULT = $pearDB->query("SELECT DISTINCT `resource_name`, `resource_comment` 
-                                FROM `cfg_resource` 
-                                ORDER BY `resource_line`");
+    $DBRESULT = $pearDB->query("SELECT DISTINCT `resource_name`, `resource_comment`
+                                FROM `cfg_resource`
+                                ORDER BY `resource_name`");
     while ($row = $DBRESULT->fetchRow()) {
         $resource[$row["resource_name"]] = $row["resource_name"];
         if (isset($row["resource_comment"]) && $row["resource_comment"] != "") {
@@ -170,9 +170,9 @@ try {
     if ($form->validate()) {
         $cntObj = new CentreonConnector($pearDB);
         $tab = $form->getSubmitValues();
-        $connectorValues = [];
-        $connectorValues['name'] = $tab['connector_name'];
-        $connectorValues['description'] = $tab['connector_description'];
+        $connectorValues = array();
+        $connectorValues['name'] = \HtmlAnalyzer::sanitizeAndRemoveTags($tab['connector_name']);
+        $connectorValues['description'] = \HtmlAnalyzer::sanitizeAndRemoveTags($tab['connector_description']);
         $connectorValues['enabled'] = $tab['connector_status']['connector_status'] === '0' ? 0 : 1;
         $connectorValues['command_id'] = isset($tab['command_id']) ? $tab['command_id'] : null;
         $connectorValues['command_line'] = $tab['command_line'];
