@@ -1,29 +1,39 @@
 <?php
 
 /*
- * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
+ * Copyright 2005-2021 Centreon
+ * Centreon is developed by : Julien Mathis and Romain Le Merlus under
+ * GPL Licence 2.0.
  *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation ; either version 2 of the License.
  *
- * https://www.apache.org/licenses/LICENSE-2.0
+ * This program is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * You should have received a copy of the GNU General Public License along with
+ * this program; if not, see <http://www.gnu.org/licenses>.
+ *
+ * Linking this program statically or dynamically with other modules is making a
+ * combined work based on this program. Thus, the terms and conditions of the GNU
+ * General Public License cover the whole combination.
+ *
+ * As a special exception, the copyright holders of this program give Centreon
+ * permission to link this program with independent modules to produce an executable,
+ * regardless of the license terms of these independent modules, and to copy and
+ * distribute the resulting executable under terms of Centreon choice, provided that
+ * Centreon also meet, for each linked independent module, the terms  and conditions
+ * of the license of that module. An independent module is a module which is not
+ * derived from this program. If you modify this program, you may extend this
+ * exception to your version of the program, but you are not obliged to do so. If you
+ * do not wish to do so, delete this exception statement from your version.
  *
  * For more information : contact@centreon.com
  *
  */
 
-use Adaptation\Database\Connection\Collection\QueryParameters;
-use Adaptation\Database\Connection\ValueObject\QueryParameter;
-use Adaptation\Log\LoggerPassword;
-use Core\Common\Domain\Exception\RepositoryException;
-
 if (!isset($centreon)) {
     exit();
 }
@@ -538,13 +548,8 @@ function multipleContactInDB($contacts = array(), $nbrDup = array())
 /**
  * @param null $contact_id
  * @param bool $from_MC
- * @param bool $isRemote
- *
- * @throws InvalidArgumentException
- * @throws PDOException
- * @throws RepositoryException
  */
-function updateContactInDB($contact_id = null, $from_MC = false): void
+function updateContactInDB($contact_id = null, $from_MC = false, bool $isRemote = false)
 {
     global $form;
 
@@ -585,12 +590,14 @@ function updateContactInDB($contact_id = null, $from_MC = false): void
     # 1 - MC with deletion of existing cg
     # 2 - MC with addition of new cg
     # 3 - Normal update
-    if (isset($ret["mc_mod_cg"]["mc_mod_cg"]) && $ret["mc_mod_cg"]["mc_mod_cg"]) {
-        updateContactContactGroup($contact_id);
-    } elseif (isset($ret["mc_mod_cg"]["mc_mod_cg"]) && !$ret["mc_mod_cg"]["mc_mod_cg"]) {
-        updateContactContactGroup_MC($contact_id);
-    } else {
-        updateContactContactGroup($contact_id);
+    if (! $isRemote) {
+        if (isset($ret["mc_mod_cg"]["mc_mod_cg"]) && $ret["mc_mod_cg"]["mc_mod_cg"]) {
+            updateContactContactGroup($contact_id);
+        } elseif (isset($ret["mc_mod_cg"]["mc_mod_cg"]) && !$ret["mc_mod_cg"]["mc_mod_cg"]) {
+            updateContactContactGroup_MC($contact_id);
+        } else {
+            updateContactContactGroup($contact_id);
+        }
     }
 
     /**
@@ -631,6 +638,9 @@ function insertContact($ret = array())
         $ret = $form->getSubmitValues();
     }
     $ret["contact_name"] = $centreon->checkIllegalChar($ret["contact_name"]);
+    if (isset($ret['contact_oreon']['contact_oreon']) && $ret['contact_oreon']['contact_oreon'] === '1') {
+        $ret['reach_api_rt']['reach_api_rt'] = '1';
+    }
     // Filter fields to only include whitelisted fields for non-admin users
     if (! $centreon->user->admin) {
         $ret = filterNonAdminFields($ret);
@@ -678,13 +688,9 @@ function insertContact($ret = array())
 }
 
 /**
- * @param null $contactId
- *
- * @throws InvalidArgumentException
- * @throws PDOException
- * @throws RepositoryException
+ * @param int|null $contactId
  */
-function updateContact($contactId = null): void
+function updateContact($contactId = null)
 {
     global $form, $pearDB, $centreon, $encryptType, $dependencyInjector;
     if (!$contactId) {
@@ -725,27 +731,8 @@ function updateContact($contactId = null): void
         $ret["contact_passwd"] = password_hash($ret["contact_passwd"], \CentreonAuth::PASSWORD_HASH_ALGORITHM);
         $ret["contact_passwd2"] = $ret["contact_passwd"];
 
-        try {
-            $contact = new \CentreonContact($pearDB);
-            $contact->renewPasswordByContactId($contactId, $ret['contact_passwd']);
-
-            LoggerPassword::create()->success(
-                initiatorId: (int) $centreon->user->get_id(),
-                targetId: (int) $contactId,
-            );
-        } catch (PDOException $e) {
-            LoggerPassword::create()->warning(
-                reason: 'password update failed',
-                initiatorId: (int) $centreon->user->get_id(),
-                targetId: (int) $contactId,
-                exception: $e,
-            );
-
-            throw new RepositoryException(
-                message: 'Unable to update password for contact id ' . $contactId,
-                previous: $e
-            );
-        }
+        $contact = new \CentreonContact($pearDB);
+        $contact->renewPasswordByContactId($contactId, $ret["contact_passwd"]);
     }
 
     /* Prepare value for changelog */
@@ -823,10 +810,12 @@ function updateContactHostCommands($contactId = null, $fields = [])
     }
 
     try {
-        $pearDB->delete(
-            'DELETE FROM contact_hostcommands_relation WHERE contact_contact_id = :contact_id',
-            QueryParameters::create([QueryParameter::int('contact_id', $contactId)])
-        );
+        $query = "DELETE FROM contact_hostcommands_relation WHERE contact_contact_id = :contact_id";
+        $successDelete = $pearDB->executePreparedQuery($pearDB->prepare($query), ['contact_id' => $contactId]);
+
+        if (!$successDelete) {
+            return;
+        }
 
         $hostCommandIdsFromForm = $fields["contact_hostNotifCmds"] ?? $form->getSubmitValue("contact_hostNotifCmds");
 
@@ -835,16 +824,14 @@ function updateContactHostCommands($contactId = null, $fields = [])
         }
 
         $query = "INSERT INTO contact_hostcommands_relation(contact_contact_id, command_command_id) VALUES(:contact_id, :command_id)";
+        $pdoSth = $pearDB->prepareQuery($query);
         foreach ($hostCommandIdsFromForm as $hostCommandIdFromForm) {
-            $pearDB->insert(
-                $query,
-                QueryParameters::create([
-                    QueryParameter::int('contact_id', $contactId),
-                    QueryParameter::int('command_id', (int)$hostCommandIdFromForm)
-                ])
+            $pearDB->executePreparedQuery(
+                $pdoSth,
+                ['contact_id' => $contactId, 'command_id' => (int)$hostCommandIdFromForm]
             );
         }
-    } catch (\Throwable $e) {
+    } catch (CentreonDbException $e) {
         CentreonLog::create()->error(
             CentreonLog::TYPE_SQL,
             "Error while updating the relationship between contacts and host commands",
@@ -1213,8 +1200,9 @@ function insertLdapContactInDB($tmpContacts = array())
 
             // Insert the relation between contact and contactgroups
             $query = <<<SQL
-                        INSERT INTO contactgroup_contact_relation (contactgroup_cg_id, contact_contact_id) VALUES (:contactgroup_cg_id, :contact_contact_id)
-                      SQL;
+                INSERT INTO contactgroup_contact_relation (contactgroup_cg_id, contact_contact_id)
+                VALUES (:contactgroup_cg_id, :contact_contact_id)
+                SQL;
             $statement = $pearDB->prepare($query);
             while ($row = $res->fetch()) {
                 $statement->bindValue(':contactgroup_cg_id', (int) $row['cg_id'], \PDO::PARAM_INT);
@@ -1519,10 +1507,9 @@ function sanitizeFormContactParameters(array $ret): array
  * Validate password creation using defined security policy.
  *
  * @param array $fields
- *
- * @return array|true
+ * @return mixed
  */
-function validatePasswordCreation(array $fields): bool|array
+function validatePasswordCreation(array $fields)
 {
     global $pearDB;
     $errors = [];
@@ -1536,15 +1523,8 @@ function validatePasswordCreation(array $fields): bool|array
     try {
         $contact = new \CentreonContact($pearDB);
         $contact->respectPasswordPolicyOrFail($password, null);
-    } catch (\Exception $e) {
+    } catch (\Throwable $e) {
         $errors['contact_passwd'] = $e->getMessage();
-
-        LoggerPassword::create()->warning(
-            reason: 'new password does not respect the password policy',
-            initiatorId: $fields['contact_id'] ?? 'unknown',
-            targetId: $fields['contact_id'] ?? 'unknown',
-            exception: $e,
-        );
     }
 
     return count($errors) > 0 ? $errors : true;
@@ -1554,81 +1534,28 @@ function validatePasswordCreation(array $fields): bool|array
  * Validate password creation using defined security policy.
  *
  * @param array<string,mixed> $fields
- *
- * @return array<string,string>|true
+ * @return mixed
  */
-function validatePasswordModification(array $fields): array|bool
+function validatePasswordModification(array $fields)
 {
-    global $pearDB, $centreon;
-    $newPassword = $fields['contact_passwd'];
-    $confirmPassword = $fields['contact_passwd2'];
-    $currentPassword = $fields['current_password'];
+    global $pearDB;
+    $errors = [];
+
+    if (empty($fields['contact_passwd'])) {
+        return true;
+    }
+
+    $password = $fields['contact_passwd'];
     $contactId = $fields['contact_id'];
 
-    // If the user does not want to change his password, we do not need to check it
-    if (empty($newPassword) && empty($confirmPassword) && empty($currentPassword)) {
-        return true;
-    }
-
-    // If the user only provided a confirmation password, he must provide a new password and a current password
-    if (empty($newPassword) && ! empty($confirmPassword) && empty($currentPassword)) {
-        LoggerPassword::create()->warning(
-            reason: 'new password or current password not provided',
-            initiatorId: (int) $centreon->user->get_id(),
-            targetId: (int) $contactId,
-        );
-
-        return ['contact_passwd2' => _('Please fill in all password fields')];
-    }
-
-    // If the user only provided his current password, he must provide a new password
-    if (empty($newPassword) && ! empty($currentPassword)) {
-        LoggerPassword::create()->warning(
-            reason: 'new password not provided',
-            initiatorId: (int) $centreon->user->get_id(),
-            targetId: (int) $contactId,
-        );
-
-        return ['current_password' => _('Please fill in all password fields')];
-    }
-
-    // If the user wants to change his password, he must provide his current password
-    if (! empty($newPassword) && empty($currentPassword)) {
-        LoggerPassword::create()->warning(
-            reason: 'current password not provided',
-            initiatorId: (int) $centreon->user->get_id(),
-            targetId: (int) $contactId,
-        );
-
-        return ['current_password' => _('Please fill in all password fields')];
-    }
-
-    // If the user provided a current password, we check if it matches the one in the database
-    if (! empty($currentPassword) && password_verify($currentPassword, $centreon->user->passwd) === false) {
-        LoggerPassword::create()->warning(
-            reason: 'current password wrong',
-            initiatorId: (int) $centreon->user->get_id(),
-            targetId: (int) $contactId,
-        );
-
-        return ['current_password' => _('Authentication failed')];
-    }
-
     try {
-        $contact = new CentreonContact($pearDB);
-        $contact->respectPasswordPolicyOrFail($newPassword, $contactId);
-
-        return true;
-    } catch (Exception $e) {
-        LoggerPassword::create()->warning(
-            reason: 'new password does not respect the password policy',
-            initiatorId: (int) $centreon->user->get_id(),
-            targetId: (int) $contactId,
-            exception: $e,
-        );
-
-        return ['contact_passwd' => $e->getMessage()];
+        $contact = new \CentreonContact($pearDB);
+        $contact->respectPasswordPolicyOrFail($password, $contactId);
+    } catch (\Throwable $e) {
+        $errors['contact_passwd'] = $e->getMessage();
     }
+
+    return count($errors) > 0 ? $errors : true;
 }
 
 /**
@@ -1661,12 +1588,6 @@ function validateAutologin(array $fields)
                 $errors['contact_autologin_key'] = _(
                     'Your autologin key must be different than your current password'
                 );
-
-                LoggerPassword::create()->warning(
-                    reason: 'autologin key is the same as current password',
-                    initiatorId: (int) $fields['contact_id'],
-                    targetId: (int) $fields['contact_id'],
-                );
             }
         }
         if (
@@ -1676,16 +1597,10 @@ function validateAutologin(array $fields)
             $errorMessage = 'Your password and autologin key should be different';
             $errors['contact_passwd'] = _($errorMessage);
             $errors['contact_autologin_key'] = _($errorMessage);
-
-            LoggerPassword::create()->warning(
-                reason: 'autologin key is the same as new password',
-                initiatorId: (int) $fields['contact_id'],
-                targetId: (int) $fields['contact_id'],
-            );
         }
     }
 
-    return $errors !== [] ? $errors : true;
+    return count($errors) > 0 ? $errors : true;
 }
 
 /**
