@@ -1,26 +1,40 @@
 <?php
 
 /*
- * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
+ * Copyright 2005-2019 Centreon
+ * Centreon is developed by : Julien Mathis and Romain Le Merlus under
+ * GPL Licence 2.0.
  *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation ; either version 2 of the License.
  *
- * https://www.apache.org/licenses/LICENSE-2.0
+ * This program is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * You should have received a copy of the GNU General Public License along with
+ * this program; if not, see <http://www.gnu.org/licenses>.
+ *
+ * Linking this program statically or dynamically with other modules is making a
+ * combined work based on this program. Thus, the terms and conditions of the GNU
+ * General Public License cover the whole combination.
+ *
+ * As a special exception, the copyright holders of this program give Centreon
+ * permission to link this program with independent modules to produce an executable,
+ * regardless of the license terms of these independent modules, and to copy and
+ * distribute the resulting executable under terms of Centreon choice, provided that
+ * Centreon also meet, for each linked independent module, the terms  and conditions
+ * of the license of that module. An independent module is a module which is not
+ * derived from this program. If you modify this program, you may extend this
+ * exception to your version of the program, but you are not obliged to do so. If you
+ * do not wish to do so, delete this exception statement from your version.
  *
  * For more information : contact@centreon.com
  *
  */
 require_once __DIR__ . '/../../../../class/centreonContact.class.php';
 
-use Adaptation\Log\LoggerPassword;
 use Centreon\Infrastructure\Event\EventDispatcher;
 
 if (!isset($centreon)) {
@@ -76,14 +90,8 @@ $dbResult->closeCursor();
  */
 try {
     $passwordSecurityPolicy = (new CentreonContact($pearDB))->getPasswordSecurityPolicy();
-    $encodedPasswordPolicy = json_encode($passwordSecurityPolicy, JSON_THROW_ON_ERROR);
-} catch (PDOException|JsonException $e) {
-    CentreonLog::create()->error(
-        logTypeId: CentreonLog::TYPE_BUSINESS_LOG,
-        message: 'Error while retrieving password security policy: ' . $e->getMessage(),
-        exception: $e
-    );
-
+    $encodedPasswordPolicy = json_encode($passwordSecurityPolicy);
+} catch (\PDOException $e) {
     return false;
 }
 
@@ -233,18 +241,13 @@ $attrAclgroups = array(
 );
 
 $form = new HTML_QuickFormCustom('Form', 'post', "?p=" . $p);
-/**
- * Smarty template Init
- */
-$tpl = new Smarty();
-$tpl = initSmartyTpl($path, $tpl);
 
-// Auth type of the user connected
-$authTypeConnectedUser = $centreon->user->authType;
-$tpl->assign('authTypeConnectedUser', $authTypeConnectedUser);
-// Auth type of the contact edited
-$authTypeContact = $cct['contact_auth_type'] ?? null;
-$tpl->assign('authTypeContact', $authTypeContact);
+// Smarty template initialization
+$tpl = SmartyBC::createSmartyTemplate($path);
+
+/**
+ * @var $moduleFormManager \Centreon\Domain\Service\ModuleFormManager
+ */
 
 if ($o == ADD_CONTACT) {
     $form->addElement('header', 'title', _("Add a User"));
@@ -326,13 +329,32 @@ if ($o != MASSIVE_CHANGE) {
     $attrsText["data-testid"] = "contact_alias";
     $form->addElement('text', 'contact_alias', _("Alias / Login"), $attrsText);
 
+    $form->addElement(
+        'text',
+        'contact_autologin_key',
+        _("Autologin Key"),
+        [
+            "size" => "90",
+            "id" => "aKey",
+            "data-testid" => "aKey"
+        ]
+    );
+    $form->addElement(
+        'button',
+        'contact_gen_akey',
+        _("Generate"),
+        [
+            'onclick' => "generatePassword('aKey', '$encodedPasswordPolicy');",
+            "id" => "generateAutologinKeyButton",
+            "data-testid" => "generateAutologinKeyButton"
+        ]
+    );
     /**
      * Contact email attributes
      */
-    $attrsTextMail['id'] = 'contact_email';
-    $attrsTextMail['data-testid'] = 'contact_email';
-    $form->addElement('text', 'contact_email', _('Email'), $attrsTextMail);
-
+    $attrsTextMail["id"] = "contact_email";
+    $attrsTextMail["data-testid"] = "contact_email";
+    $form->addElement('text', 'contact_email', _("Email"), $attrsTextMail);
     /**
      * Contact Pager attributes
      */
@@ -418,25 +440,7 @@ $tab[] = $form->createElement(
 );
 $form->addGroup($tab, 'contact_oreon', _("Reach Centreon Front-end"), '&nbsp;');
 
-if (
-    $o !== MASSIVE_CHANGE
-    && $authTypeConnectedUser === CentreonAuth::AUTH_TYPE_LOCAL
-    && $authTypeContact !== CentreonAuth::AUTH_TYPE_LDAP
-) {
-
-    // Password Management
-
-    $form->addElement(
-        'password',
-        'current_password',
-        _('Your current password'),
-        [
-            'size' => '30',
-            'autocomplete' => 'off',
-            'id' => 'current_password',
-        ]
-    );
-
+if ($o !== MASSIVE_CHANGE) {
     $form->addElement(
         'password',
         'contact_passwd',
@@ -449,7 +453,6 @@ if (
             "onkeypress" => "resetPwdType(this);"
         ]
     );
-
     $form->addElement(
         'password',
         'contact_passwd2',
@@ -462,7 +465,6 @@ if (
             "onkeypress" => "resetPwdType(this);"
         ]
     );
-
     $form->addElement(
         'button',
         'contact_gen_passwd',
@@ -473,30 +475,6 @@ if (
             "data-testid" => "contact_gen_passwd"
         ]
     );
-
-    // Autologin Management
-
-    $form->addElement(
-        'text',
-        'contact_autologin_key',
-        _('Autologin Key'),
-        [
-            'size' => '90',
-            'id' => 'aKey',
-            'data-testid' => 'aKey',
-        ]
-    );
-
-    $form->addElement(
-        'button',
-        'contact_gen_akey',
-        _('Generate'),
-        [
-            'onclick' => "generatePassword('aKey', '{$encodedPasswordPolicy}');",
-            'id' => 'generateAutologinKeyButton',
-            'data-testid' => 'generateAutologinKeyButton',
-        ]
-    );
 }
 
 /* ------------------------ Topoogy ---------------------------- */
@@ -766,11 +744,15 @@ $form->addElement(
     $attrTimezones
 );
 
-$contactAuthTypeSelect = $o != MASSIVE_CHANGE ? [] : [null => null];
+if ($o != MASSIVE_CHANGE) {
+    $auth_type = array();
+} else {
+    $auth_type = array(null => null);
+}
 
-$contactAuthTypeSelect['local'] = 'Centreon';
+$auth_type["local"] = "Centreon";
 if ($centreon->optGen['ldap_auth_enable'] == 1) {
-    $contactAuthTypeSelect['ldap'] = 'LDAP';
+    $auth_type["ldap"] = "LDAP";
     /**
      * LDAP Distinguished Name attributes
      */
@@ -792,8 +774,8 @@ if ($o != MASSIVE_CHANGE) {
 $form->addElement(
     'select',
     'contact_auth_type',
-    _('Authentication Source'),
-    $contactAuthTypeSelect,
+    _("Authentication Source"),
+    $auth_type,
     [
         "id" => "contact_auth_type",
         "data-testid" => "contact_auth_type"
@@ -1122,14 +1104,7 @@ if ($o != MASSIVE_CHANGE) {
         }
     }
 
-    if (
-        $o !== MASSIVE_CHANGE
-        && $authTypeConnectedUser === CentreonAuth::AUTH_TYPE_LOCAL
-        && $authTypeContact !== CentreonAuth::AUTH_TYPE_LDAP
-    ) {
-        $form->addRule(array('contact_passwd', 'contact_passwd2'), _("Passwords do not match"), 'compare');
-    }
-
+    $form->addRule(array('contact_passwd', 'contact_passwd2'), _("Passwords do not match"), 'compare');
     if ($o === ADD_CONTACT || $o === MODIFY_CONTACT) {
         $form->addFormRule('validatePasswordCreation');
         $form->addFormRule('validateAutologin');
@@ -1229,7 +1204,10 @@ if ($form->validate() && $from_list_menu == false) {
             ]
         );
     } elseif ($form->getSubmitValue("submitC")) {
-        updateContactInDB($cctObj->getValue());
+        updateContactInDB(
+            contact_id:$cctObj->getValue(),
+            isRemote: $isRemote
+        );
 
         $eventDispatcher->notify(
             'contact.form',
@@ -1243,7 +1221,7 @@ if ($form->validate() && $from_list_menu == false) {
         $select = explode(",", $select);
         foreach ($select as $key => $selectedContactId) {
             if ($selectedContactId) {
-                updateContactInDB($selectedContactId, true);
+                updateContactInDB($selectedContactId, true, $isRemote);
 
                 $eventDispatcher->notify(
                     'contact.form',
@@ -1263,19 +1241,10 @@ if ($form->validate() && $from_list_menu == false) {
 if ($valid) {
     require_once($path . "listContact.php");
 } else {
-    // Password does not match
-    if (
-        $form->getElementError('contact_passwd') === _('Passwords do not match')
-        || $form->getElementError('contact_passwd2') === _('Passwords do not match')
-    ) {
-        LoggerPassword::create()->warning(
-            reason: 'password confirmation does not match',
-            initiatorId: $centreon->user->get_id(),
-            targetId: $centreon->user->get_id(),
-        );
-    }
-    // Apply a template definition
-    $contactAuthType = $cct['contact_auth_type'] ?? null;
+    /*
+     * Apply a template definition
+     */
+    $contactAuthType = isset($cct['contact_auth_type']) ? $cct['contact_auth_type'] : null;
     $renderer = new HTML_QuickForm_Renderer_ArraySmarty($tpl, true);
     $renderer->setRequiredTemplate('{$label}&nbsp;<font color="red" size="1">*</font>');
     $renderer->setErrorTemplate('<font color="red">{$error}</font><br />{$html}');
@@ -1287,7 +1256,7 @@ if ($valid) {
     if ($centreon->optGen['ldap_auth_enable']) {
         $tpl->assign('ldap', $centreon->optGen['ldap_auth_enable']);
     }
-    $tpl->assign('contactAuthType', $contactAuthType);
+    $tpl->assign('auth_type', $contactAuthType);
 
     if ($isRemote === false) {
         $tpl->display("formContact.ihtml");
