@@ -105,12 +105,11 @@ $centreon->template = $template;
 
 // Status Filter
 $statusFilter = array(1 => _("Disabled"), 2 => _("Enabled"));
-$sqlFilterCase = '';
-if ($status == 2) {
-    $sqlFilterCase = " AND host_activate = '1' ";
-} elseif ($status == 1) {
-    $sqlFilterCase = " AND host_activate = '0' ";
-}
+$sqlFilterCase = match((int) $status) {
+    2 => " AND host_activate = '1' ",
+    1 => " AND host_activate = '0' ",
+    default => '',
+};
 
 /*
  * Search active
@@ -138,9 +137,8 @@ if ($template) {
     $mainQueryParameters[':host_tpl_id'] = [\PDO::PARAM_INT => $template];
 }
 
-// Smarty template Init
-$tpl = new Smarty();
-$tpl = initSmartyTpl($path, $tpl);
+// Smarty template initialization
+$tpl = SmartyBC::createSmartyTemplate($path);
 
 $lvl_access = ($centreon->user->access->page($p) == 1) ? 'w' : 'r';
 
@@ -274,7 +272,7 @@ if ($hostgroup) {
         $mainQueryParameters[':poller_id'] = [\PDO::PARAM_INT => $poller];
 
         $request = <<<SQL
-            SELECT SQL_CALC_FOUND_ROWS DISTINCT
+            SELECT SQL_CALC_FOUND_ROWS DISTINCT 
                 h.host_id, h.host_name, host_alias, host_address, host_activate, host_template_model_htm_id
             FROM host h
             INNER JOIN ns_host_relation nshr
@@ -325,7 +323,7 @@ if ($hostgroup) {
                 h.host_register = '1'
                 $sqlFilterCase
             ORDER BY h.host_name
-            LIMIT :offset, :limit
+            LIMIT :offset, :limit 
             SQL;
     } else {
         $request = <<<SQL
@@ -338,7 +336,7 @@ if ($hostgroup) {
                 host_register = '1'
                 $sqlFilterCase
             ORDER BY h.host_name
-            LIMIT :offset, :limit
+            LIMIT :offset, :limit 
             SQL;
     }
 }
@@ -362,7 +360,7 @@ $search = tidySearchKey($search, $advanced_search);
 
 // Fill a tab with a multidimensional Array we put in $tpl
 $elemArr = array();
-$search = str_replace('\_', "_", $search);
+$search = str_replace('\_', "_", $search ?? '');
 
 
 $centreonToken = createCSRFToken();
@@ -411,7 +409,6 @@ for ($i = 0; $host = $dbResult->fetch(); $i++) {
         if (count($tplArr)) {
             $firstTpl = 1;
             foreach ($tplArr as $key => $value) {
-                $value = htmlspecialchars($value, ENT_QUOTES, 'UTF-8');
                 if ($firstTpl) {
                     $tplStr .= "<a href='main.php?p=60103&o=c&host_id=$key'>$value</a>";
                     $firstTpl = 0;
@@ -446,23 +443,25 @@ for ($i = 0; $host = $dbResult->fetch(); $i++) {
         }
 
         // Create Array Data for template list
-        $elemArr[$i] = [
-            'MenuClass' => 'list_' . $style,
-            'RowMenu_select' => $selectedElements->toHtml(),
-            'RowMenu_name' => $host['host_name'],
-            'RowMenu_name_link' => HtmlAnalyzer::sanitizeAndRemoveTags($host['host_name']),
-            'RowMenu_id' => $host['host_id'],
-            'RowMenu_icone' => $host_icone,
-            'RowMenu_link' => 'main.php?p=' . $p . '&o=c&host_id=' . $host['host_id'],
-            'RowMenu_desc' => $host['host_alias'],
-            'RowMenu_address' => $host['host_address'],
-            'RowMenu_poller' => $tab_relation[$host['host_id']] ?? '',
-            'RowMenu_parent' => $tplStr,
-            'RowMenu_status' => $host['host_activate'] ? _('Enabled') : _('Disabled'),
-            'RowMenu_badge' => $host['host_activate'] ? 'service_ok' : 'service_critical',
-            'RowMenu_options' => $moptions,
-            'isSvgFile' => $isSvgFile,
-        ];
+        $elemArr[$i] = array(
+            "MenuClass" => "list_" . $style,
+            "RowMenu_select" => $selectedElements->toHtml(),
+            "RowMenu_name" => $host["host_name"],
+            "RowMenu_name_link" => HtmlAnalyzer::sanitizeAndRemoveTags($host["host_name"]),
+            "RowMenu_id" => $host["host_id"],
+            "RowMenu_icone" => $host_icone,
+            "RowMenu_link" => "main.php?p=" . $p . "&o=c&host_id=" . $host['host_id'],
+            "RowMenu_desc" => CentreonUtils::escapeSecure($host["host_alias"]),
+            "RowMenu_address" => CentreonUtils::escapeSecure($host["host_address"]),
+            "RowMenu_poller" => isset($tab_relation[$host["host_id"]])
+                ? $tab_relation[$host["host_id"]]
+                : "",
+            "RowMenu_parent" => CentreonUtils::escapeSecure($tplStr),
+            "RowMenu_status" => $host["host_activate"] ? _("Enabled") : _("Disabled"),
+            "RowMenu_badge" => $host["host_activate"] ? "service_ok" : "service_critical",
+            "RowMenu_options" => $moptions,
+            "isSvgFile" => $isSvgFile
+        );
 
         $style != "two"
             ? $style = "two"
