@@ -34,7 +34,7 @@
  *
  */
 
-use Core\ActionLog\Domain\Model\ActionLog;
+ use Core\ActionLog\Domain\Model\ActionLog;
 
 if (!isset($oreon)) {
     exit();
@@ -52,7 +52,7 @@ function checkSeverity($fields)
     if (isset($fields['sc_type']) && $fields['sc_severity_icon'] == "") {
         $arr['sc_severity_icon'] = "Severity icon is required";
     }
-    if ($arr !== []) {
+    if (count($arr)) {
         return $arr;
     }
     return true;
@@ -109,8 +109,7 @@ function multipleServiceCategorieInDB($sc = [], $nbrDup = [])
                 switch ($key2) {
                     case 'sc_name':
                         $value2 = \HtmlAnalyzer::sanitizeAndRemoveTags($value2);
-                        $sc_name = $value2 . "_" . $i;
-                        $value2 = $value2 . "_" . $i;
+                        $sc_name = $value2 = $value2 . "_" . $i;
                         $bindParams[':sc_name'] = [
                             \PDO::PARAM_STR => $value2
                         ];
@@ -144,7 +143,7 @@ function multipleServiceCategorieInDB($sc = [], $nbrDup = [])
                     ? $val .= ($value2 != null ? (", '" . $value2 . "'") : ", NULL")
                     : $val .= ($value2 != null ? ("'" . $value2 . "'") : "NULL");
 
-                if ($key2 != "sc_id") {
+                    if ($key2 != "sc_id") {
                     $fields[$key2] = $value2;
                 }
             }
@@ -167,7 +166,6 @@ function multipleServiceCategorieInDB($sc = [], $nbrDup = [])
                 $statement->execute();
                 $statement = $pearDB->query("SELECT MAX(sc_id) as maxid FROM `service_categories`");
                 $maxId = $statement->fetch();
-
                 if (isset($maxId['maxid'])) {
                     $scAcl[$maxId['maxid']] = $scId;
                     try {
@@ -195,7 +193,6 @@ function multipleServiceCategorieInDB($sc = [], $nbrDup = [])
                         if (! empty($foundServiceIds)) {
                             $fields["sc_services"] = implode(", ", $foundServiceIds);
                         }
-
                         $centreon->CentreonLogAction->insertLog(
                             object_type: ActionLog::OBJECT_TYPE_SERVICECATEGORIES,
                             object_id: $maxId['maxid'],
@@ -210,7 +207,6 @@ function multipleServiceCategorieInDB($sc = [], $nbrDup = [])
                             customContext: ['service_category_id' => $scId],
                             exception: $ex,
                         );
-
                         throw $ex;
                     }
                 }
@@ -223,7 +219,6 @@ function multipleServiceCategorieInDB($sc = [], $nbrDup = [])
 
 function enableServiceCategorieInDB(?int $serviceCategoryId = null, array $serviceCategories = [])
 {
-
     if (! $serviceCategoryId && empty($serviceCategories)) {
         return;
     }
@@ -232,7 +227,6 @@ function enableServiceCategorieInDB(?int $serviceCategoryId = null, array $servi
     if ($serviceCategoryId) {
         $serviceCategories = [$serviceCategoryId => "1"];
     }
-
     try {
         $updateStatement = $pearDB->prepareQuery(
             <<<SQL
@@ -281,7 +275,6 @@ function disableServiceCategorieInDB(?int $serviceCategoryId = null, array $serv
     if ($serviceCategoryId) {
         $serviceCategories = [$serviceCategoryId => "1"];
     }
-
     try {
         $updateStatement = $pearDB->prepareQuery(
             <<<SQL
@@ -450,7 +443,6 @@ function deleteServiceCategorieInDB($serviceCategoryIds = null)
     if (is_null($serviceCategoryIds)) {
         return;
     }
-
     try {
         $deleteStatement = $pearDB->prepareQuery(
             <<<SQL
@@ -516,4 +508,4 @@ function updateServiceCategoriesServices(int $sc_id)
             $statement->execute();
         }
     }
-}
\ No newline at end of file
+}
