@@ -48,7 +48,6 @@ require_once __DIR__ . '/../Paginator.php';
 require_once __DIR__ . '/PaginationRenderer.php';
 require_once __DIR__ . '/../../../class/centreonLog.class.php';
 require_once __DIR__ . '/../../../class/exceptions/CentreonDbException.php';
-require_once __DIR__ . '/../../common/sqlCommonFunction.php';
 
 // Connect to DB
 $pearDB = $dependencyInjector['configuration_db'];
@@ -270,6 +269,7 @@ if ($engine == "true") {
     $down = "false";
     $warning = "false";
     $critical = "false";
+    $acknowledgement = "false";
     $oh = "false";
     $alert = "false";
 }
@@ -346,7 +346,8 @@ $tab_status_service = array(
     "0" => "OK",
     "1" => "WARNING",
     "2" => "CRITICAL",
-    "3" => "UNKNOWN"
+    "3" => "UNKNOWN",
+    "5" => "ACKNOWLEDGEMENT"
 );
 $acknowlegementMessageType = [
     'badgeColor' => 'ack',
@@ -369,7 +370,7 @@ if ($export) {
         CentreonLog::create()->error(
             CentreonLog::TYPE_BUSINESS_LOG,
             'Error while fetching hosts',
-            $e->getContext()
+            $e->getOptions()
         );
     }
 }
@@ -393,6 +394,7 @@ $buffer->writeElement("ok", $ok);
 $buffer->writeElement("warning", $warning);
 $buffer->writeElement("critical", $critical);
 $buffer->writeElement("unknown", $unknown);
+$buffer->writeElement("acknowledgement", $acknowledgement);
 $buffer->writeElement("oh", $oh);
 $buffer->writeElement("search_H", $search_H);
 $buffer->writeElement("search_S", $search_S);
@@ -715,7 +717,7 @@ try {
     CentreonLog::create()->error(
         CentreonLog::TYPE_BUSINESS_LOG,
         'Error while fetching logs',
-        $e->getContext()
+        $e->getOptions()
     );
 }
 
@@ -823,7 +825,7 @@ foreach (array_slice($logs, 0, $limit) as $log) {
                 CentreonLog::create()->error(
                     CentreonLog::TYPE_BUSINESS_LOG,
                     'Error while fetching meta_services',
-                    $e->getContext()
+                    $e->getOptions()
                 );
             }
         } else {
