@@ -82,7 +82,16 @@ switch ($o) {
         } else {
             unvalidFormMessage();
         }
-        require_once($path . "listDowntime.php");
+        try {
+            require_once($path . "listDowntime.php");
+        } catch (Exception $ex) {
+            CentreonLog::create()->error(
+                logTypeId: CentreonLog::TYPE_BUSINESS_LOG,
+                message: 'Error while listing downtime: ' . $ex->getMessage(),
+                exception: $ex
+            );
+            throw $ex;
+        }
         break;
     case "cs":
         purgeOutdatedCSRFTokens();
@@ -108,6 +117,15 @@ switch ($o) {
     case "vs":
     case "vh":
     default:
-        require_once($path . "listDowntime.php");
+        try {
+            require_once($path . "listDowntime.php");
+        } catch (Exception $ex) {
+            CentreonLog::create()->error(
+                logTypeId: CentreonLog::TYPE_BUSINESS_LOG,
+                message: 'Error while listing downtime: ' . $ex->getMessage(),
+                exception: $ex
+            );
+            throw $ex;
+        }
         break;
 }
