@@ -75,10 +75,8 @@ $rows = $pearDB->query("SELECT FOUND_ROWS()")->fetchColumn();
 
 include("./include/common/checkPagination.php");
 
-/* Smarty template Init */
-
-$tpl = new Smarty();
-$tpl = initSmartyTpl(__DIR__, $tpl);
+// Smarty template initialization
+$tpl = SmartyBC::createSmartyTemplate(__DIR__);
 
 /* start header menu */
 
@@ -112,21 +110,22 @@ for ($i = 0; $topo = $statement->fetchRow(); $i++) {
             "'><img src='img/icons/enabled.png' class='ico-14 margin_right' " .
             "border='0' alt='" . _("Enabled") . "'></a>&nbsp;&nbsp;";
     }
-    $moptions .= '&nbsp;';
-    $moptions .= '<input onKeypress="if(event.keyCode > 31 && (event.keyCode < 45 || event.keyCode > 57)) '
-        . 'event.returnValue = false; if(event.which > 31 && (event.which < 45 || event.which > 57)) '
-        . "return false;\" maxlength=\"3\" size=\"3\" value='1' style=\"margin-bottom:0px;\" name='dupNbr["
-        . $topo['acl_action_id'] . "]' />";
-    // Contacts
-    $elemArr[$i] = [
-        'MenuClass' => 'list_' . $style,
-        'RowMenu_select' => $selectedElements->toHtml(),
-        'RowMenu_name' => $topo['acl_action_name'],
-        'RowMenu_link' => 'main.php?p=' . $p . '&o=c&acl_action_id=' . $topo['acl_action_id'],
-        'RowMenu_alias' => $topo['acl_action_description'],
-        'RowMenu_status' => $topo['acl_action_activate'] ? _('Enabled') : _('Disabled'),
-        'RowMenu_badge' => $topo['acl_action_activate'] ? 'service_ok' : 'service_critical',
-        'RowMenu_options' => $moptions];
+    $moptions .= "&nbsp;";
+    $moptions .= "<input onKeypress=\"if(event.keyCode > 31 && (event.keyCode < 45 || event.keyCode > 57)) " .
+        "event.returnValue = false; if(event.which > 31 && (event.which < 45 || event.which > 57)) " .
+        "return false;\" maxlength=\"3\" size=\"3\" value='1' style=\"margin-bottom:0px;\" name='dupNbr[" .
+        $topo['acl_action_id'] . "]' />";
+    /* Contacts */
+    $elemArr[$i] = array(
+        "MenuClass" => "list_" . $style,
+        "RowMenu_select" => $selectedElements->toHtml(),
+        "RowMenu_name" => $topo["acl_action_name"],
+        "RowMenu_link" => "main.php?p=" . $p . "&o=c&acl_action_id=" . $topo['acl_action_id'],
+        "RowMenu_alias" => myDecode($topo["acl_action_description"]),
+        "RowMenu_status" => $topo["acl_action_activate"] ? _("Enabled") : _("Disabled"),
+        "RowMenu_badge" => $topo["acl_action_activate"] ? "service_ok" : "service_critical",
+        "RowMenu_options" => $moptions
+    );
 
     $style != "two" ? $style = "two" : $style = "one";
 }
