@@ -74,7 +74,7 @@ $stmt->closeCursor();
  */
 $dataSources = [];
 $stmt = $pearDBO->query(
-    'SELECT 1 AS REALTIME, `metric_name`, `unit_name` FROM `metrics` GROUP BY `metric_name` ORDER BY `metric_name`'
+    'SELECT 1 AS REALTIME, `metric_name`, `unit_name` FROM `metrics` GROUP BY `metric_name`, `unit_name` ORDER BY `metric_name`'
 );
 while ($row = $stmt->fetch(\PDO::FETCH_ASSOC)) {
     $dataSources[$row['metric_name']] = $row['metric_name'];
@@ -289,11 +289,8 @@ $form->addRule('ds_color_area_crit', _('Bad Format: start color by #'), 'checkCo
 
 $form->setRequiredNote("<font style='color: red;'>*</font>&nbsp;" . _('Required fields'));
 
-/*
- * Smarty template Init
- */
-$tpl = new Smarty();
-$tpl = initSmartyTpl($path, $tpl);
+// Smarty template initialization
+$tpl = SmartyBC::createSmartyTemplate($path);
 
 if ($o === WATCH_COMPONENT_TEMPLATE) {
     // Just watch
