@@ -9,4 +9,4 @@ export interface FormThreshold {
 
 export type ValueFormat = 'human' | 'raw';
 
-export type SingleMetricGraphyType = 'text' | 'gauge' | 'bar';
+export type SingleMetricGraphType = 'text' | 'gauge' | 'bar';
